@@ -8,10 +8,11 @@ OC.L10N.register(
     "Sending…" : "Lähetetään…",
     "Email sent" : "Sähköposti lähetetty",
     "Private" : "Yksityinen",
-    "Don't synchronize to servers" : "Älä synkronoi palvelimille",
-    "Trusted" : "Luotettu",
+    "Local" : "Paikallinen",
+    "Only visible to people on this instance and guests" : "Vain näkyvissä tämän instanssin ihmisille ja vieraille",
+    "Federated" : "Federoitu",
     "Only synchronize to trusted servers" : "Synkronoi vain luotetulle palvelimelle",
-    "Public" : "Julkinen",
+    "Published" : "Julkaistu",
     "Verify" : "Vahvista",
     "Verifying …" : "Vahvistetaan…",
     "Unable to change password" : "Salasanan vaihto ei onnistunut",
@@ -64,7 +65,6 @@ OC.L10N.register(
     "Please provide an admin recovery password; otherwise, all user data will be lost." : "Anna ylläpitäjän palautussalasana; muuten kaikki käyttäjien data menetetään.",
     "Wrong admin recovery password. Please check the password and try again." : "Väärä ylläpitäjän salasana. Tarkista salasana ja yritä uudelleen.",
     "Backend doesn't support password change, but the user's encryption key was updated." : "Taustaosa ei tue salasanan vaihtamista, mutta käyttäjän salausavain päivitettiin.",
-    "installing and updating apps via the app store or Federated Cloud Sharing" : "Sovellusten asennus tai päivitys sovelluskaupasta tai federoidusta pilvijaosta",
     "Federated Cloud Sharing" : "Federoitu pilvijakaminen",
     "cURL is using an outdated %1$s version (%2$s). Please update your operating system or features such as %3$s will not work reliably." : "cURL käyttää vanhentunutta %1$s versiota (%2$s). Päivitä käyttöjärjestelmäsi tai toiminnot, kuten %3$s, eivät toimi luotettavasti.",
     "Invalid SMTP password." : "Virheellinen SMTP-salasana.",
@@ -73,11 +73,14 @@ OC.L10N.register(
     "If you received this email, the email configuration seems to be correct." : "Jos vastaanotit tämän viestin, sähköpostimääritykset vaikuttavat olevan kunnossa.",
     "Email could not be sent. Check your mail server log" : "Sähköpostia ei voitu lähettää. Tarkista sähköpostipalvelimen lokitiedosto",
     "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Sähköpostia lähettäessä tapahtui virhe. Tarkista asetukset. (Virhe: %s)",
-    "You need to set your user email before being able to send test emails." : "Aseta sähköpostiosoite, jotta voit testata sähköpostin toimivuutta.",
+    "Invalid user" : "Virheellinen käyttäjä",
     "Invalid mail address" : "Virheellinen sähköpostiosoite",
     "Settings saved" : "Asetukset tallennettu",
     "Unable to change full name" : "Koko nimen muuttaminen epäonnistui",
     "Unable to change email address" : "Sähköpostiosoitteen vaihtaminen ei onnistunut",
+    "Unable to set invalid phone number" : "Virheellisen puhelinnumeron asettaminen ei onnistu",
+    "Unable to set invalid website" : "Virheellisen verkkosivun asettaminen ei onnistu",
+    "Some account data was invalid" : "Jokin tilidata oli virheellistä",
     "In order to verify your Twitter account, post the following tweet on Twitter (please make sure to post it without any line breaks):" : "Jotta Twitter-tilisi on mahdollista vahvistaa, twiittaa seuraava viesti (varmista että lähetät viestin sellaisenaan ilman rivivaihtoja):",
     "In order to verify your Website, store the following content in your web-root at '.well-known/CloudIdVerificationCode.txt' (please make sure that the complete text is in one line):" : "Jotta verkkosivustosi on mahdollista vahvistaa, aseta seuraava sisältö verkkosivustosi juureen '.well-known/CloudIdVerificationCode.txt' (varmista että koko teksti on yhdellä rivillä):",
     "Your password on %s was changed." : "Salasanasi osoitteessa %s on muutettu.",
@@ -110,6 +113,9 @@ OC.L10N.register(
     "Sharing" : "Jakaminen",
     "Personal info" : "Henkilökohtaiset tiedot",
     "Mobile & desktop" : "Mobiili ja työpöytä",
+    "Email server" : "Sähköpostipalvelin",
+    "Security & setup warnings" : "Turvallisuus- ja asetusvaroitukset",
+    "Background jobs" : "Taustatyöt",
     "Create" : "Luo",
     "Change" : "Muuta",
     "Delete" : "Poista",
@@ -118,6 +124,9 @@ OC.L10N.register(
     "Verifying" : "Vahvistetaan",
     "The old server-side-encryption format is enabled. We recommend disabling this." : "Vanha palvelinpuolen salausmenetelmä on käytössä. Suosittelemme sen ottamista pois käytöstä.",
     "Nextcloud settings" : "Nextcloud-asetukset",
+    "Administration privileges" : "Ylläpitäjän oikeudet",
+    "None" : "Ei mitään",
+    "Unable to modify setting" : "Asetuksen muokkaaminen ei onnistu",
     "Two-factor authentication can be enforced for all users and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "Kaksivaiheinen tunnistautuminen voidaan pakottaa kaikille käyttäjille ja halutuille ryhmille. Mikäli heillä ei ole kaksivaiheista tunnistautumistapaa määriteltynä, he eivät pysty kirjautumaan järjestelmään.",
     "Enforce two-factor authentication" : "Pakota kaksivaiheinen tunnistautuminen",
     "Limit to groups" : "Rajoita ryhmiin",
@@ -168,10 +177,10 @@ OC.L10N.register(
     "Google Chrome for Android" : "Google Chrome Android-laitteelle",
     "iPhone" : "iPhone",
     "iPad" : "iPad",
-    "Nextcloud iOS app" : "Nextcloudin iOS-sovellus",
-    "Nextcloud Android app" : "Nextcloudin Android-sovellus",
-    "Nextcloud Talk for iOS" : "Nextcloud Talk iOS:ille",
-    "Nextcloud Talk for Android" : "Nextcloud Talk Androidille",
+    "{productName} iOS app" : "{productName} iOS-sovellus",
+    "{productName} Android app" : "{productName} Android-sovellus",
+    "{productName} Talk for iOS" : "{productName} Talk iOS:lle",
+    "{productName} Talk for Android" : "{productName} Talk Androidille",
     "Sync client - {os}" : "Synkronointisovellus - {os}",
     "This session" : "Tämä istunto",
     "Device" : "Laite",
@@ -195,18 +204,44 @@ OC.L10N.register(
     "Copied!" : "Kopioitu!",
     "Copy" : "Kopioi",
     "Could not copy app password. Please copy it manually." : "Sovellussalasanaa ei voitu kopioida. Kopioi se manuaalisesti.",
+    "Remove group" : "Poista ryhmä",
+    "You are about to remove the group {group}. The users will NOT be deleted." : "Olet aikeissa poistaa ryhmän {group}. Käyttäjiä EI poisteta!",
+    "Please confirm the group removal " : "Vahvista ryhmän poistaminen",
+    "Your full name" : "Koko nimesi",
+    "Unable to update full name" : "Koko nimeä ei voi päivittää",
+    "No full name set" : "Koko nimeä ei ole asetettu",
+    "Email options" : "Sähköpostiasetukset",
+    "Primary email for password reset and notifications" : "Ensisijainen sähköposti salasanan nollaamista ja ilmoituksia varten",
+    "Remove primary email" : "Poista ensisijainen sähköpostiosoite",
+    "Delete email" : "Poista sähköposti",
+    "This address is not confirmed" : "Tätä osoitetta ei ole vahvistettu",
+    "Set as primary email" : "Aseta ensisijaiseksi sähköpostiosoitteeksi",
+    "Your email address" : "Sähköpostiosoitteesi",
+    "Additional email address {index}" : "Lisäsähköpostiosoite {index}",
+    "No email address set" : "Sähköpostiosoitetta ei ole asetettu",
+    "Language" : "Kieli",
+    "Help translate" : "Auta kääntämisessä",
+    "Unable to update language" : "Kieltä ei voi päivittää",
+    "No language set" : "Kieltä ei ole asetettu",
+    "Your organisation" : "Organisaatiosi",
+    "Unable to update organisation" : "Organisaatiota ei voi päivittää",
+    "Edit your Profile visibility" : "Muokkaa profiilisi näkyvyyttä",
+    "Enable Profile" : "Käytä profiilia",
+    "Your role" : "Roolisi",
+    "Unable to update role" : "Roolin päivittäminen ei onnistu",
+    "Add" : "Lisää",
     "You do not have permissions to see the details of this user" : "Käyttöoikeutesi eivät riitä tämän käyttäjän tietojen näkemiseen",
     "Add new password" : "Lisää uusi salasana",
     "Add new email address" : "Lisää uusi sähköpostiosoite",
-    "Add user in group" : "Lisää käyttäjä ryhmään",
+    "Add user to group" : "Lisää käyttäjä ryhmään",
     "Set user as admin for" : "Aseta käyttäjä järjestelmänvalvojaksi kohteelle",
     "Select user quota" : "Valitse käyttäjäkiintiö",
-    "No language set" : "Kieltä ei ole asetettu",
     "Delete user" : "Poista käyttäjä",
     "Wipe all devices" : "Tyhjennä kaikki laitteet",
     "Disable user" : "Poista käyttäjä käytöstä",
     "Enable user" : "Ota käyttäjä käyttöön",
     "Resend welcome email" : "Lähetä uudelleen tervetuloviesti",
+    "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "Laitteen kadotessa tai organisaatiosta poistuessa voidaan käyttäjälle {userid} Nextcloudiin yhdistetyistä laitteista pyyhkiä  tiedot. Toimii vain laitteiden ollessa yhteydessä Internetiin.",
     "Remote wipe of devices" : "Laitteiden etätyhjennys",
     "Wipe {userid}'s devices" : "Tyhjennä käyttäjän {userid} laitteet",
     "Cancel" : "Peru",
@@ -216,28 +251,28 @@ OC.L10N.register(
     "Welcome mail sent!" : "Tervetuloviesti lähetetty!",
     "Edit User" : "Muokkaa käyttäjää",
     "{size} used" : "{size} käytetty",
+    "New user" : "Uusi käyttäjä",
     "Will be autogenerated" : "Luodaan automaattisesti",
     "Display name" : "Näyttönimi",
     "Email" : "Sähköpostiosoite",
     "Default language" : "Oletuskieli",
     "Add a new user" : "Lisää uusi käyttäjä",
-    "Close" : "Sulje",
     "Group admin for" : "Ryhmäylläpitäjä ryhmille",
     "Quota" : "Kiintiö",
-    "Language" : "Kieli",
     "User backend" : "Käyttäjätaustaosa",
     "Storage location" : "Tallennustilan sijainti",
     "Last login" : "Viimeisin kirjautuminen",
     "No users in here" : "Täällä ei ole käyttäjiä",
     "Default quota" : "Oletuskiintiö",
     "Common languages" : "Yleiset kielet",
-    "All languages" : "Kaikki kielet",
+    "Other languages" : "Muut kielet",
     "Passwordless authentication requires a secure connection." : "Tunnistautuminen ilman salasanaa vaatii salatun yhteyden.",
     "Add WebAuthn device" : "Lisää WebAuthn-laite",
     "Please authorize your WebAuthn device." : "Valtuuta WebAuthn-laitteesi.",
     "Name your device" : "Nimeä laitteesi",
-    "Add" : "Lisää",
     "Adding your device …" : "Lisätään laitettasi…",
+    "Server error while trying to add WebAuthn device" : "Palvelinvirhe kun yritettiin lisätä WebAuthn-laitetta",
+    "Server error while trying to complete WebAuthn device registration" : "Palvelinvirhe kun yritettiin suorittaa WebAuthn-laitteen rekisteröintiä",
     "Unnamed device" : "Nimetön laite",
     "Passwordless Authentication" : "Tunnistautuminen ilman salasanaa",
     "Set up your account for passwordless authentication following the FIDO2 standard." : "Aseta tilillesi tunnistautuminen ilman salasanaa FIDO2-standardia seuraten.",
@@ -254,13 +289,11 @@ OC.L10N.register(
     "Details" : "Yksityiskohdat",
     "Changelog" : "Muutosloki",
     "by {author}\n{license}" : "tekijä {author}\n{license}",
-    "New user" : "Uusi käyttäjä",
     "Enter group name" : "Kirjoita ryhmän nimi",
     "Add group" : "Lisää ryhmä",
-    "Everyone" : "Kaikki",
+    "Active users" : "Aktiiviset käyttäjät",
     "Admins" : "Ylläpitäjät",
     "Disabled users" : "Käytöstä poistetut käyttäjät",
-    "Remove group" : "Poista ryhmä",
     "Default quota:" : "Oletuskiintiö:",
     "Select default quota" : "Valitse oletuskiintiö",
     "Show Languages" : "Näytä kielet",
@@ -268,34 +301,43 @@ OC.L10N.register(
     "Show user backend" : "Näytä käyttäjätaustaosa",
     "Show storage path" : "Näytä tallennustilan polku",
     "Send email to new user" : "Lähetä sähköpostia uudelle käyttäjälle",
-    "You are about to remove the group {group}. The users will NOT be deleted." : "Olet aikeissa poistaa ryhmän {group}. Käyttäjiä EI poisteta!",
-    "Please confirm the group removal " : "Vahvista ryhmän poistaminen",
+    "Address" : "Osoite",
+    "About" : "Tietoja",
+    "Full name" : "Koko nimi",
+    "Organisation" : "Organisaatio",
+    "Phone number" : "Puhelinnumero",
+    "Profile" : "Profiili",
+    "Role" : "Rooli",
+    "Twitter" : "Twitter",
+    "Website" : "Verkkosivusto",
+    "Profile visibility" : "Profiilin näkyvyys",
+    "Show to everyone" : "Näytä kaikille",
+    "Show to logged in users only" : "Näytä vain sisäänkirjautuneille käyttäjille",
+    "Hide" : "Piilota",
     "Download and enable" : "Lataa ja ota käyttöön",
     "Enable" : "Käytä",
     "Enable untested app" : "Ota käyttöön testaamaton sovellus",
-    "The app will be downloaded from the app store" : "Sovellus ladataan sovelluskaupasta",
+    "The app will be downloaded from the App Store" : "Sovellus ladataan sovelluskaupasta",
+    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Sovellusta ei ole merkattu yhteensopivaksi Nextcloud-versiosi kanssa. Voit kuitenkin jatkaa ja asentaa sovelluksen. Huomioi, että sovellus ei välttämättä toimi odotetusti.",
     "Never" : "Ei koskaan",
     "An error occured during the request. Unable to proceed." : "Pyynnön aikana tapahtui virhe. Jatkaminen ei onnistu.",
     "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Sovellus on käytössä, mutta se tulee päivittää. Sinut ohjataan sovelluksen päivityssivulle viiden sekunnin kuluttua.",
     "App update" : "Sovelluspäivitys",
-    "Error: This app can not be enabled because it makes the server unstable" : "Virhe: tätä sovellusta ei voi ottaa käyttöön, koska se tekee palvelimesta epävakaan",
+    "Error: This app cannot be enabled because it makes the server unstable" : "Virhe: Sovellusta ei voida ottaa käyttöön, koska se aiheuttaa palvelimen epävakauden",
     "Administrator documentation" : "Ylläpidon dokumentaatio",
     "Documentation" : "Dokumentaatio",
     "Forum" : "Keskustelupalsta",
-    "None" : "Ei mitään",
     "Login" : "Kirjaudu",
     "Plain" : "Plain",
     "NT LAN Manager" : "NT LAN Manager",
     "SSL/TLS" : "SSL/TLS",
     "STARTTLS" : "STARTTLS",
-    "Email server" : "Sähköpostipalvelin",
     "Open documentation" : "Avaa dokumentaatio",
     "It is important to set up this server to be able to send emails, like for password reset and notifications." : "On tärkeää määrittää sähköpostipalvelinasetukset, jotta voidaan lähettää muun muassa salasanan palautus- ja ilmoitussähköpostiviestejä.",
     "Send mode" : "Lähetystila",
     "Encryption" : "Salaus",
     "Sendmail mode" : "Sendmail-tila",
     "From address" : "Lähettäjän osoite",
-    "mail" : "posti",
     "Authentication method" : "Tunnistautumistapa",
     "Authentication required" : "Tunnistautuminen vaaditaan",
     "Server address" : "Palvelimen osoite",
@@ -304,9 +346,8 @@ OC.L10N.register(
     "SMTP Username" : "SMTP-käyttäjätunnus",
     "SMTP Password" : "SMTP-salasana",
     "Save" : "Tallenna",
-    "Test email settings" : "Testaa sähköpostiasetukset",
     "Send email" : "Lähetä sähköpostiviesti",
-    "Security & setup warnings" : "Turvallisuus- ja asetusvaroitukset",
+    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Turvallisuuden ja suorituskyvyn vuoksi on tärkeää, että palvelimen asetukset ovat määritetty oikein. Apuna on joitain automaattisia tarkistuksia. Lue lisätietoja linkitetystä dokumentaatiosta.",
     "All checks passed." : "Läpäistiin kaikki tarkistukset.",
     "There are some errors regarding your setup." : "Asetuksiin liittyen on muutamia virheitä.",
     "There are some warnings regarding your setup." : "Asetuksiin liittyen on muutamia varoituksia.",
@@ -316,8 +357,10 @@ OC.L10N.register(
     "Version" : "Versio",
     "Two-Factor Authentication" : "Kaksivaiheinen tunnistautuminen",
     "Server-side encryption" : "Palvelinpään salaus",
+    "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "Palvelimelle ladatut tiedostot voidaan salata. Salaus aiheuttaa mm. palvelimen suorituskyvyn laskua, joten joten ota se käyttöön vain tarvittaessa.",
     "Enable server-side encryption" : "Käytä palvelinpään salausta",
     "Please read carefully before activating server-side encryption: " : "Lue tarkasti, ennen kuin otat palvelinpään salauksen käyttöön:",
+    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Kun salaus on otettu käyttöön, käyttöönoton jälkeen palvelimelle ladatut tiedostot salataan palvelimen ollessa lepotilassa. Salauksen ottaminen pois päältä myöhemmin on mahdollista vain, jos aktiivinen salausmoduuli tukee toiminta ja kaikki muut vaatimukset (kuten palautusavaimen asettaminen) täyttyvät.",
     "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "Salaus sellaisenaan ei takaa järjestelmäsi turvallisuutta. Tutustu dokumentaation saadaksesi lisätietoja, miten salaussovellus toimii ja nähdäksesi tuettuja käyttötapauksia.",
     "Be aware that encryption always increases the file size." : "Ota huomioon, että salaus kasvattaa aina tiedostojen kokoa.",
     "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Säännöllisten varmuuskopioiden ottaminen on erittäin tärkeää. Jos olet ottanut salauksen käyttöön, huolehdi salausavainten varmuuskopioinnista.",
@@ -328,7 +371,6 @@ OC.L10N.register(
     "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "Sinun täytyy siirtää salausavaimet vanhasta salaustekniikasta (ownCloud <= 8.0) uuteen. Ota \"Default encryption module\" käyttöön ja suorita komento 'occ encryption:migrate'",
     "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "Sinun täytyy siirtää salausavaimet vanhasta salaustekniikasta (ownCloud <= 8.0) uuteen.",
     "Start migration" : "Käynnistä migraatio",
-    "Background jobs" : "Taustatyöt",
     "Last job execution ran %s. Something seems wrong." : "Viimeisin cron-työn suoritus %s. Jokin vaikuttaa menneen pieleen.",
     "Some jobs haven’t been executed since %s. Please consider increasing the execution frequency." : "Jotkin tehtävät on suoritettu viimeksi %s jälkeen. Harkitse suoritustiheyden nopeuttamista.",
     "Some jobs didn’t execute since %s. Please consider switching to system cron." : "Joidenkin tehtävien suoritukset ovat onnistuneet viimeksi %s. Harkitse vaihtoa järjestelmän cron-palveluun.",
@@ -344,21 +386,21 @@ OC.L10N.register(
     "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Ylläpitäjänä voit hienosäätää jakamista. Katso dokumentaatiosta lisätietoa.",
     "Allow apps to use the Share API" : "Salli sovellusten käyttää jakamisen ohjelmointirajapintaa",
     "Set default expiration date for shares" : "Aseta oletusarvoinen vanhenemispäivä jaoille",
-    "Expire after " : "Vanhenna",
-    "days" : "päivän jälkeen",
+    "Expire after" : "Lopeta jako, kun on kulunut",
+    "day(s)" : "päivä(ä)",
     "Enforce expiration date" : "Pakota vanhenemispäivä",
-    "Allow users to share via link" : "Salli käyttäjien jakaa linkkien kautta",
+    "Set default expiration date for shares to other servers" : "Aseta oletuspäivä muille palvelimille tehtyjen jakojen lopettamiselle",
     "Allow public uploads" : "Salli julkiset lähetykset",
     "Always ask for a password" : "Kysy aina salasanaa",
     "Enforce password protection" : "Pakota salasanasuojaus",
-    "Set default expiration date for link shares" : "Aseta oletusarvoinen vanhenemispäivä linkkijaoille",
+    "Set default expiration date" : "Aseta lopettamispäivän oletus",
     "Allow resharing" : "Salli uudelleenjakaminen",
     "Allow sharing with groups" : "Salli jakaminen ryhmien kanssa",
     "Restrict users to only share with users in their groups" : "Salli käyttäjien jakaa vain omassa ryhmässä olevien henkilöiden kesken",
     "Exclude groups from sharing" : "Kiellä ryhmiä jakamasta",
     "These groups will still be able to receive shares, but not to initiate them." : "Nämä ryhmät kykenevät vastaanottamaan jakoja, mutta eivät kuitenkaan itse pysty luoda jakoja.",
-    "Allow username autocompletion in share dialog (if this is disabled the full username or email address needs to be entered)" : "Salli käyttäjänimen automaattinen täydentäminen jakemisikkunassa (jos tämä on pois käytöstä, tulee koko käyttäjänimi tai sähköpostiosoite kirjoittaa)",
-    "Restrict username autocompletion to users within the same groups" : "Rajoita käyttäjänimen automaattista täydentämistä samoihin ryhmiin kuuluviin käyttäjiin",
+    "Allow username autocompletion in share dialog" : "Ota käyttöön käyttäjänimen automaattitäyttö jakolomakkeessa",
+    "Allow username autocompletion to users within the same groups" : "Ota käyttöön käyttäjänimen automaattitäyttö saman ryhmän käyttäjille",
     "This text will be shown on the public link upload page when the file list is hidden." : "Tämä teksti näytetään julkisen linkin lähetyssivulla, kun tiedostolista on piilotettu.",
     "Default share permissions" : "Oletusjako-oikeudet",
     "Reasons to use Nextcloud in your organization" : "Nextcloudin käytön edut organisaatiossasi",
@@ -369,6 +411,7 @@ OC.L10N.register(
     "Check out our blog" : "Lue blogia",
     "Subscribe to our newsletter" : "Tilaa uutiskirje",
     "Profile picture" : "Profiilikuva",
+    "Change privacy level of profile picture" : "Muuta profiilikuvan yksityisyystasoa",
     "Upload new" : "Lähetä uusi",
     "Select from Files" : "Valitse tiedostosovelluksesta",
     "Remove image" : "Poista kuva",
@@ -378,44 +421,48 @@ OC.L10N.register(
     "You are a member of the following groups:" : "Olet seuraavien ryhmien jäsen:",
     "You are using <strong>%s</strong>" : "Käytössäsi on <strong>%s</strong>",
     "You are using <strong>%1$s</strong> of <strong>%2$s</strong> (<strong>%3$s %%</strong>)" : "Käytössäsi on <strong>%1$s</strong> / <strong>%2$s</strong> (<strong>%3$s %%</strong>)",
-    "Full name" : "Koko nimi",
-    "No display name set" : "Näyttönimeä ei ole asetettu",
-    "Your email address" : "Sähköpostiosoitteesi",
-    "No email address set" : "Sähköpostiosoitetta ei ole asetettu",
-    "For password reset and notifications" : "Salasanan nollausta ja ilmoituksia varten",
-    "Phone number" : "Puhelinnumero",
+    "Change privacy level of phone number" : "Muuta puhelinnumeron yksityisyystasoa",
     "Your phone number" : "Puhelinnumerosi",
-    "Address" : "Osoite",
+    "Change privacy level of address" : "Muuta osoitteen yksityisyystasoa",
     "Your postal address" : "Postiosoitteesi",
-    "Website" : "Verkkosivusto",
+    "Change privacy level of website" : "Muuta verkkosivuston yksityisyystasoa",
     "It can take up to 24 hours before the account is displayed as verified." : "Saattaa kestää jopa 24 tuntia, ennen kuin tili näytetään vahvistettuna.",
     "Link https://…" : "Linkki https://…",
-    "Twitter" : "Twitter",
+    "Change privacy level of Twitter profile" : "Muuta Twitter-tunnuksen yksityisyystasoa",
     "Twitter handle @…" : "Twitter-tunnus @…",
-    "Help translate" : "Auta kääntämisessä",
     "Locale" : "Aluekohtainen asetus",
     "Current password" : "Nykyinen salasana",
     "New password" : "Uusi salasana",
     "Change password" : "Vaihda salasana",
     "Use a second factor besides your password to increase security for your account." : "Käytä toista vaihetta salasanasi lisäksi parantaaksesi tilisi tietoturvaa.",
     "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "Jos yhdistät kolmannen osapuolen ohjelmia Nextcloudiin, määritä niille sovellussalasanat ennen kaksiosaisen todentamismenetelmän käyttöönottoa.",
-    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Tapahtu virhe. Lähetä ASCII-koodattu PEM-varmenne.",
-    "Valid until {date}" : "Kelvollinen {date} asti",
-    "Local" : "Paikallinen",
-    "Only visible to local users" : "Näkyvillä vain paikallisille käyttäjille",
-    "Only visible to you" : "Näkyvillä vain sinulle",
-    "Contacts" : "Yhteystiedot",
-    "Visible to local users and to trusted servers" : "Näkyvillä vain paikallisille käyttäjille ja luotetuille palvelimille",
-    "Will be synced to a global and public address book" : "Synkronoidaan maailmanlaajuiseen ja julkiseen osoitekirjaan",
-    "by" : " Kirjoittaja:",
-    "SSL Root Certificates" : "SSL-juurivarmenteet",
-    "Common Name" : "Yleinen nimi",
-    "Valid until" : "Kelvollinen",
-    "Issued By" : " Myöntänyt",
-    "Valid until %s" : "Kelvollinen %s asti",
-    "Import root certificate" : "Tuo juurivarmenne",
-    "Execute one task with each page loaded" : "Suorita yksi tehtävä jokaista ladattua sivua kohden",
-    "Allow username autocompletion in share dialog. If this is disabled the full username or email address needs to be entered." : "Salli käyttäjätunnusten automaattinen täydentäminen jakoikkunassa. Jos tämä asetus on pois käytöstä, tulee käyttäjän kirjoittaa käyttäjätunnus tai sähköpostiosoite kokonaan.",
-    "Show disclaimer text on the public link upload page. (Only shown when the file list is hidden.)" : "Näytä vastuuvapauslauseke julkisen linkin lähetyssivulla. (Näytetään vain, kun tiedostolista on piilotettu.)"
+    "Don't synchronize to servers" : "Älä synkronoi palvelimille",
+    "Trusted" : "Luotettu",
+    "Public" : "Julkinen",
+    "installing and updating apps via the app store or Federated Cloud Sharing" : "Sovellusten asennus tai päivitys sovelluskaupasta tai federoidusta pilvijaosta",
+    "You need to set your user email before being able to send test emails." : "Aseta sähköpostiosoite, jotta voit testata sähköpostin toimivuutta.",
+    "Nextcloud iOS app" : "Nextcloudin iOS-sovellus",
+    "Nextcloud Android app" : "Nextcloudin Android-sovellus",
+    "Nextcloud Talk for iOS" : "Nextcloud Talk iOS:ille",
+    "Nextcloud Talk for Android" : "Nextcloud Talk Androidille",
+    "Add user in group" : "Lisää käyttäjä ryhmään",
+    "Close" : "Sulje",
+    "All languages" : "Kaikki kielet",
+    "Everyone" : "Kaikki",
+    "The app will be downloaded from the app store" : "Sovellus ladataan sovelluskaupasta",
+    "Error: This app can not be enabled because it makes the server unstable" : "Virhe: tätä sovellusta ei voi ottaa käyttöön, koska se tekee palvelimesta epävakaan",
+    "mail" : "posti",
+    "Test email settings" : "Testaa sähköpostiasetukset",
+    "Expire after " : "Vanhenna",
+    "days" : "päivän jälkeen",
+    "Allow users to share via link" : "Salli käyttäjien jakaa linkkien kautta",
+    "Set default expiration date for link shares" : "Aseta oletusarvoinen vanhenemispäivä linkkijaoille",
+    "Allow username autocompletion in share dialog (if this is disabled the full username or email address needs to be entered)" : "Salli käyttäjänimen automaattinen täydentäminen jakemisikkunassa (jos tämä on pois käytöstä, tulee koko käyttäjänimi tai sähköpostiosoite kirjoittaa)",
+    "Restrict username autocompletion to users within the same groups" : "Rajoita käyttäjänimen automaattista täydentämistä samoihin ryhmiin kuuluviin käyttäjiin",
+    "No display name set" : "Näyttönimeä ei ole asetettu",
+    "For password reset and notifications" : "Salasanan nollausta ja ilmoituksia varten",
+    "Change privacy level of full name" : "Muuta koko nimen yksityisyystasoa",
+    "Change privacy level of email" : "Muuta sähköpostin yksityisyystasoa",
+    "Set as primary mail" : "Aseta ensisijaiseksi sähköpostiosoitteeksi"
 },
 "nplurals=2; plural=(n != 1);");
