@@ -8,7 +8,7 @@ OC.L10N.register(
     "Sending…" : "იგზავნება…",
     "Email sent" : "ელ-წერილი გაიგზავნა",
     "Private" : "პირადი",
-    "Public" : "ღია",
+    "Local" : "ლოკალური",
     "Verify" : "დამოწმება",
     "Verifying …" : "მოწმდება …",
     "Unable to change password" : "პაროლის ცვილება შეუძლებელია",
@@ -37,7 +37,6 @@ OC.L10N.register(
     "Please provide an admin recovery password; otherwise, all user data will be lost." : "გთხოვთ მოგვაწოდოთ ადმინისტრატორის აღდგენის პაროლი; სხვა შემთხვევაში ყველა მონაცემი დაიკარგება.",
     "Wrong admin recovery password. Please check the password and try again." : "ადმინისტრატორის აღდგენის არასწორი პაროლი. გთხოვთ გადაამოწმოთ პაროლი და სცადოთ ახლიდან.",
     "Backend doesn't support password change, but the user's encryption key was updated." : "ბექენდს არ აქვს პაროლის ცვლილების მხარდაჭერა, თუმცა მომხმარებლის შიფრაციის გასაღები განახლდა.",
-    "installing and updating apps via the app store or Federated Cloud Sharing" : "აპლიკაციების app store-იდან დაყენება და განახლება ან ფედერალური ქლაუდ გაზიარება",
     "Federated Cloud Sharing" : "ფედერალური ქლაუდ გაზიარება",
     "Invalid SMTP password." : "არასწორი SMTP პაროლი.",
     "Email setting test" : "ელ-ფოსტის დაყენების შემოწმება",
@@ -45,7 +44,6 @@ OC.L10N.register(
     "If you received this email, the email configuration seems to be correct." : "იმ შემთხვევაში თუ მიიღეთ ეს ელ-წერილი, ელ-ფოსტის კონფიგურაცია კარგად უნდა იყოს.",
     "Email could not be sent. Check your mail server log" : "ელ-წერილი ვერ იგზავნება. გთხოვთ შეამოწმოთ მეილ-სერვერის ლოგი",
     "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "ელ-წერილის გაგზავნისას წარმოიშვა შეცდომა. გთხოვთ გადახედოთ თქვენს პარამეტრებს. (შეცდომა: %s)",
-    "You need to set your user email before being able to send test emails." : "შემოწმების წერილების გაგზავნამდე, უნდა დააყენოთ თქვენი მომხმარებლის ელ-ფოსტა.",
     "Invalid mail address" : "არასწორი საფოსტო მისამართი",
     "Settings saved" : "პარამეტრები შენახულია",
     "Unable to change full name" : "სრული სახელის ცვლილება ვერ ხერხდება",
@@ -77,14 +75,20 @@ OC.L10N.register(
     "Personal" : "პირადი",
     "Administration" : "ადმინისტრაცია",
     "Additional settings" : "დამატებითი პარამეტრები",
+    "Overview" : "ზოგადი მიმოხილვა",
     "Basic settings" : "ძირითადი პარამეტრები",
     "Sharing" : "გაზიარება",
     "Personal info" : "პირადი ინფორმაცია",
+    "Mobile & desktop" : "მობილური და დესკტოპი",
+    "Email server" : "საფოსტო სერვერი",
+    "Security & setup warnings" : "უსაფრთხოების და მოწყობის გაფრთხილებები",
+    "Background jobs" : "ფონური საქმეები",
     "Create" : "შექმნა",
     "Change" : "შეცვლა",
     "Delete" : "წაშლა",
     "Unlimited" : "ულიმიტო",
     "Verifying" : "მოწმდება",
+    "None" : "არც ერთი",
     "Limit to groups" : "ლიმიტი ჯგუფებზე",
     "Save changes" : "ცვილებების შენახვა",
     "All" : "ყველა",
@@ -101,6 +105,7 @@ OC.L10N.register(
     "User documentation" : "მომხმარებლის დოკუმენტაცია",
     "Admin documentation" : "ადმინისტრატორის დოკუმენტაცია",
     "Developer documentation" : "დეველოპერის დოკუმენტაცია",
+    "Supported" : "მხარდაჭერილია",
     "Featured" : "გამორჩეულები",
     "No apps found for your version" : "აპლიკაციები თქვენი ვერსიისთვის ვერ იქნა ნაპოვნი",
     "Enable all" : "ყველას ამოქმედება",
@@ -129,20 +134,21 @@ OC.L10N.register(
     "Done" : "დასრულებულია",
     "Copied!" : "კოპირებულია",
     "Copy" : "კოპირება",
+    "Your email address" : "თქვენი ელ-ფოსტის მისამართი",
+    "No email address set" : "ელ-ფოსტის მისამართი არაა დაყენებული",
+    "Language" : "ენა",
+    "Help translate" : "თარგმნის დახმარება",
+    "Add" : "დამატება",
     "Cancel" : "უარყოფა",
     "{size} used" : "მოხმარებულია {size}",
     "Display name" : "დისპლეი სახელი",
     "Email" : "ელ-ფოსტა",
-    "Close" : "დახურვა",
     "Group admin for" : "ადმინისტრატორის შეჯგუფება",
     "Quota" : "ქვოტა",
-    "Language" : "ენა",
     "User backend" : "მომხმარებელის ბექენდი",
     "Storage location" : "საცავის ადგილმდებარეობა",
     "Last login" : "ბოლო ავტორიზაცია",
     "Default quota" : "საწყისი კვოტა",
-    "All languages" : "ყველა ენა",
-    "Add" : "დამატება",
     "Unnamed device" : "უსახელო მოწყობილობა",
     "Your apps" : "თქვენი აპლიკაციები",
     "Disabled apps" : "არამოქმედი აპლიკაციები",
@@ -151,33 +157,32 @@ OC.L10N.register(
     "Details" : "დეტალები",
     "Changelog" : "ცვლილებების ლოგი",
     "Add group" : "ჯგუფის დამატება",
-    "Everyone" : "ყველა",
     "Admins" : "ადმინისტრატორები",
     "Show last login" : "ბოლო ავტორიზაციის ჩვენება",
     "Show user backend" : "მომხმარებლის ბექენდის ჩვენება",
     "Send email to new user" : "გაუგზავნეთ ელ-წერილი ახალ მომხმარებელს",
+    "Address" : "მისამართი",
+    "Full name" : "სრული სახელი",
+    "Phone number" : "ტელეფონის ნომერი",
+    "Twitter" : "Twitter-ი",
+    "Website" : "ვებ-საიტი",
     "Enable" : "ჩართვა",
-    "The app will be downloaded from the app store" : "აპლიკაცია გადმოწერილ იქნება app store-იდან",
     "Never" : "არასდროს",
     "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "აპლიკაცია ამოქმედდა, თუმცა საჭიროებს განახლებას. 5 წამში გადამისამართდებით განახლების გვერდზე.",
     "App update" : "აპლიკაციის განახლება",
-    "Error: This app can not be enabled because it makes the server unstable" : "შეცდომა: ეს აპლიკაცია ვერ მოქმედდება რადგანაც სერვერს ხდის არასტაბილურს",
     "Administrator documentation" : "ადმინისტრატორის დოკუმენტაცია",
     "Documentation" : "დოკუმენტაცია",
     "Forum" : "ფორუმი",
-    "None" : "არც ერთი",
     "Login" : "ლოგინი",
     "Plain" : "ჩვეულებრივი",
     "NT LAN Manager" : "NT LAN მენეჯერი",
     "SSL/TLS" : "SSL/TLS",
     "STARTTLS" : "STARTTLS",
-    "Email server" : "საფოსტო სერვერი",
     "Open documentation" : "ღია დოკუმენტაცია",
     "It is important to set up this server to be able to send emails, like for password reset and notifications." : "ამ სერვერის მოწყობა ელ-წერილების გასაგზვნად მნიშვნელოვანია, მაგ. პაროლის აღსადგენად და შეტყობინებების მისაღებად.",
     "Send mode" : "გაგზავნის რეჟიმი",
     "Encryption" : "შიფრაცია",
     "From address" : "მისამართიდან",
-    "mail" : "წერილი",
     "Authentication method" : "აუტენტიფიკაციის მეთოდი",
     "Authentication required" : "აუტენტიფიკაცია საჭიროებს",
     "Server address" : "სერვერის მისამართი",
@@ -186,9 +191,7 @@ OC.L10N.register(
     "SMTP Username" : "SMTP მოხმარებლის სახელი",
     "SMTP Password" : "SMTP მომხმარებლის პაროლი",
     "Save" : "შენახვა",
-    "Test email settings" : "ელ-ფოსტის პარამეტრების შემომება",
     "Send email" : "ელ-წერილის გაგზავნა",
-    "Security & setup warnings" : "უსაფრთხოების და მოწყობის გაფრთხილებები",
     "All checks passed." : "ყველა შემოწმებამ ჩაიარა დადებითად.",
     "Version" : "ვერსია",
     "Server-side encryption" : "სერვერული-მხარის შიფრაცია",
@@ -206,7 +209,6 @@ OC.L10N.register(
     "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "საჭიროა შიფრაციის გასაღებების მიგრაცია (ownCloud <= 8.0) ახალებზე. გთხოვთ აამოქმედოთ \"საწყისი მიგრაციის მოდული\" და გაუშვათ 'occ encryption:migrate'",
     "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "საჭიროა შიფრაციის ძველი გასაღებების მიგრაცია (ownCloud <= 8.0) ახალებზე.",
     "Start migration" : "მიგრაციის დაწყება",
-    "Background jobs" : "ფონური საქმეები",
     "Last job execution ran %s. Something seems wrong." : "ბოლო საქმე გაიშვა %s. რაღაც არასწორია.",
     "Last job ran %s." : "ბოლო საქმის გაშვება - %s.",
     "Background job didn’t run yet!" : "ფონური საქმე ჯერ არ გაშვებულა!",
@@ -215,10 +217,7 @@ OC.L10N.register(
     "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "ამის გასაშვებად საჭიროა გქონდეთ PHP POSIX გაფართოება. მეტი დეტალებისთვის იხილეთ {linkstart}PHP დოკუმენტაცია{linkend}. ",
     "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "როგორც ადმინისტრატორს შეგიძლიათ გაზიარების ქცევის კორექტირება. დამატებითი ინფორმაციისთვის იხილეთ დოკუმენტაცია.",
     "Allow apps to use the Share API" : "დაუშვი აპლიკაციების უფლება  Share API –ზე",
-    "Expire after " : "ვადის ამოწურვა",
-    "days" : "დღე",
     "Enforce expiration date" : "ვადის ამოწურვის თარიღის იძულება",
-    "Allow users to share via link" : "მიეცით მოხმარებლებს ბმულით გაზიარების უფლება",
     "Allow public uploads" : "საქვეყნო ატვირთების დაშვება",
     "Always ask for a password" : "ყოველთვის მოხდეს პაროლის მოთხოვნა",
     "Enforce password protection" : "პროლით დაცვის იძულება",
@@ -241,45 +240,28 @@ OC.L10N.register(
     "png or jpg, max. 20 MB" : "png ან jpg, მაქს. 20 მბ",
     "Picture provided by original account" : "სურათი ორიგინალი ანგარიშიდან",
     "Choose as profile picture" : "აირჩიეთ პროფილის სურათად",
-    "Full name" : "სრული სახელი",
-    "No display name set" : "დისპლეი სახელი არაა დაყენებული",
-    "Your email address" : "თქვენი ელ-ფოსტის მისამართი",
-    "No email address set" : "ელ-ფოსტის მისამართი არაა დაყენებული",
-    "For password reset and notifications" : "პაროლის აღდგენისთვის და შეტყობინებებისთვის",
-    "Phone number" : "ტელეფონის ნომერი",
     "Your phone number" : "თქვენი ტელეფონის ნომერი",
-    "Address" : "მისამართი",
     "Your postal address" : "თქვენი საფოსტო მისამართი",
-    "Website" : "ვებ-საიტი",
     "It can take up to 24 hours before the account is displayed as verified." : "თქვენი ანგარიშის ვერიფიცირებულად გამოჩენამ შეიძლება გასტანოს 24 საათი.",
     "Link https://…" : "ბმული https://…",
-    "Twitter" : "Twitter-ი",
     "Twitter handle @…" : "Twitter @…",
-    "Help translate" : "თარგმნის დახმარება",
     "Current password" : "მიმდინარე პაროლი",
     "New password" : "ახალი პაროლი",
     "Change password" : "პაროლის შეცვლა",
-    "Share" : "გაზიარება",
-    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "წარმოიქმნა შეცდომა. გთხოვთ ატვირთოთ ASCII-თ კოდირებული PEM სერტიფიკატი.",
-    "Valid until {date}" : "ვარგისია {date}-მდე",
-    "Local" : "ლოკალური",
-    "Only visible to local users" : "გამოჩნდება მხოლოდ ლოკალურ მომხმარებლებთან",
-    "Only visible to you" : "გამოჩნდება მხოლოდ თქვენთან",
-    "Contacts" : "კონტაქტები",
-    "Visible to local users and to trusted servers" : "გამოჩნდება ლოკალურ მომხმარებლებთან და სანდო სერვერებთან",
-    "Will be synced to a global and public address book" : "სინქრონიზაცია მოხდება გლობალურ და ღია მისამართების წიგნში",
-    "Official apps are developed by and within the community. They offer central functionality and are ready for production use." : "ოფიციალური აპლიკაციები განვითარებულია და მოქცეულია ჩვენს საზოგადოებაში. ისინი გთავაზობენ ცენტრალურ ფუნქციონირებას და საწარმოო გამოყენებისათვის მზადყოფნაში არიან.",
-    "Official" : "ოფიციალური",
-    "by" : "სუბიექტი:",
-    "SSL Root Certificates" : "SSL Root სერტიფიკატები",
-    "Common Name" : "საზოგადო სახელი",
-    "Valid until" : "ვარგისია",
-    "Issued By" : "განაცხადა",
-    "Valid until %s" : "ვარგისია %s-მდე",
-    "Import root certificate" : "Root სერტიფიკატის იმპორტი",
-    "Execute one task with each page loaded" : "გაუშვი თითო მოქმედება ყველა ჩატვირთულ გვერდზე",
-    "Set default expiration date" : "დააყენეთ საწყისი ვადის ამოწურვის თარიღი",
-    "Allow username autocompletion in share dialog. If this is disabled the full username or email address needs to be entered." : "მიეცით მომხმარებლებს ავტოდასრულების უფლება გაზიარების დიალოგებში. იმ შემთხვევაში თუ ეს ფუნქცია არაა მოქმედი, საჭირო იქნება სრული მომხმარებლის სახელის ან ელ-ფოსტის მისამართის შეყვანა.",
-    "Show disclaimer text on the public link upload page. (Only shown when the file list is hidden.)" : "პასუხისმგებლობის შეზღუდვის ტექსტის ჩვენება ღია ბმულის ატვირთვის გვერდზე. (ჩანს მხოლოდ მაშინ, როდესაც ფაილების სია დამალულია.)"
+    "Public" : "ღია",
+    "installing and updating apps via the app store or Federated Cloud Sharing" : "აპლიკაციების app store-იდან დაყენება და განახლება ან ფედერალური ქლაუდ გაზიარება",
+    "You need to set your user email before being able to send test emails." : "შემოწმების წერილების გაგზავნამდე, უნდა დააყენოთ თქვენი მომხმარებლის ელ-ფოსტა.",
+    "Close" : "დახურვა",
+    "All languages" : "ყველა ენა",
+    "Everyone" : "ყველა",
+    "The app will be downloaded from the app store" : "აპლიკაცია გადმოწერილ იქნება app store-იდან",
+    "Error: This app can not be enabled because it makes the server unstable" : "შეცდომა: ეს აპლიკაცია ვერ მოქმედდება რადგანაც სერვერს ხდის არასტაბილურს",
+    "mail" : "წერილი",
+    "Test email settings" : "ელ-ფოსტის პარამეტრების შემომება",
+    "Expire after " : "ვადის ამოწურვა",
+    "days" : "დღე",
+    "Allow users to share via link" : "მიეცით მოხმარებლებს ბმულით გაზიარების უფლება",
+    "No display name set" : "დისპლეი სახელი არაა დაყენებული",
+    "For password reset and notifications" : "პაროლის აღდგენისთვის და შეტყობინებებისთვის"
 },
 "nplurals=2; plural=(n!=1);");
