@@ -57,7 +57,6 @@ OC.L10N.register(
     "Please provide an admin recovery password; otherwise, all user data will be lost." : "관리자 복구 암호를 입력하십시오. 그렇지 않으면 모든 사용자 데이이터가 초기화됩니다다.",
     "Wrong admin recovery password. Please check the password and try again." : "관리자 복구 암호가 잘못되었습니다. 암호를 다시 확인하십시오.",
     "Backend doesn't support password change, but the user's encryption key was updated." : "백엔드에서 암호 변경을 지원하지 않지만 사용자의 암호화 키는 업데이트되었습니다.",
-    "installing and updating apps via the app store or Federated Cloud Sharing" : "앱 스토어 및 연합 클라우드 공유로 앱 설치 및 업데이트",
     "Federated Cloud Sharing" : "클라우드 연합 공유",
     "Invalid SMTP password." : "SMTP 암호가 잘못되었습니다.",
     "Email setting test" : "이메일 설정 시험",
@@ -65,7 +64,6 @@ OC.L10N.register(
     "If you received this email, the email configuration seems to be correct." : "이 이메일을 받으셨다면 이메일 설정이 올바릅니다.",
     "Email could not be sent. Check your mail server log" : "이메일을 보낼 수 없습니다. 메일 서버 로그를 확인하십시오.",
     "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "이메일을 보내는 중 오류가 발생했습니다. 설정을 확인하십시오.(오류: %s)",
-    "You need to set your user email before being able to send test emails." : "테스트 이메일을 보내기 전 내 주소를 설정해야 합니다.",
     "Invalid mail address" : "잘못된 이메일 주소",
     "Settings saved" : "설정 저장됨",
     "Unable to change full name" : "전체 이름을 변경할 수 없음",
@@ -102,6 +100,9 @@ OC.L10N.register(
     "Sharing" : "공유",
     "Personal info" : "개인 정보",
     "Mobile & desktop" : "모바일 & 데스크톱",
+    "Email server" : "이메일 서버",
+    "Security & setup warnings" : "보안 및 설치 경고",
+    "Background jobs" : "배경 작업",
     "Create" : "생성",
     "Change" : "변경",
     "Delete" : "삭제",
@@ -109,6 +110,7 @@ OC.L10N.register(
     "Unlimited" : "무제한",
     "Verifying" : "검사",
     "Nextcloud settings" : "Nextcloud 환경설정",
+    "None" : "없음",
     "Enforce two-factor authentication" : "2단계 인증 강제하기",
     "Limit to groups" : "그룹으로 제한",
     "Enforcement of two-factor authentication can be set for certain groups only." : "2단계 인증 강제는 특정 그룹에게만 적용됩니다.",
@@ -169,10 +171,17 @@ OC.L10N.register(
     "Copied!" : "복사 성공!",
     "Copy" : "복사",
     "Could not copy app password. Please copy it manually." : "앱 비밀번호를 복사할 수 없습니다.  직접 옮겨 적으십시오.",
+    "Remove group" : "그룹 지우기",
+    "You are about to remove the group {group}. The users will NOT be deleted." : "당신은 {group} 그룹을 지우려고 합니다. 그룹의 사용자들은 삭제되지 않습니다.",
+    "Please confirm the group removal " : "그룹 지우기를 확인해주세요.",
+    "Your email address" : "이메일 주소",
+    "No email address set" : "이메일 주소가 설정되지 않음",
+    "Language" : "언어",
+    "Help translate" : "번역 돕기",
+    "Add" : "추가",
     "You do not have permissions to see the details of this user" : "사용자의 상세정보를 볼 권한이 없습니다",
     "Add new password" : "새로운 비밀번호를 입력하시오",
     "Add new email address" : "새로운 이메일 추가하기",
-    "Add user in group" : "그룹에 사용자 추가",
     "Delete user" : "유저 지우기",
     "Disable user" : "유저 비활성화하기",
     "Enable user" : "유저 활성화하기",
@@ -183,22 +192,19 @@ OC.L10N.register(
     "Delete {userid}'s account" : "{userid}의 계정 삭제",
     "Welcome mail sent!" : "환영 메일을 보냈습니다!",
     "{size} used" : "{size} 사용됨",
+    "New user" : "새 사용자",
     "Display name" : "표시 이름",
     "Email" : "이메일",
     "Default language" : "기본 언어",
     "Add a new user" : "새 사용자 추가",
-    "Close" : "닫기",
     "Group admin for" : "다음 그룹의 관리자:",
     "Quota" : "할당량",
-    "Language" : "언어",
     "User backend" : "사용자 백엔드",
     "Storage location" : "저장소 위치",
     "Last login" : "마지막 로그인",
     "No users in here" : "사용자가 이곳에 없습니다.",
     "Default quota" : "기본 할당량",
-    "All languages" : "모든 언어",
     "Name your device" : "장치 이름 설정",
-    "Add" : "추가",
     "Adding your device …" : "장치 추가 중 …",
     "Unnamed device" : "이름 없는 장치",
     "Your browser does not support WebAuthn." : "WebAuthn이 현재 브라우저를 지원하지 않습니다.",
@@ -210,12 +216,9 @@ OC.L10N.register(
     "{license}-licensed" : "{license} 라이선스",
     "Details" : "자세히",
     "Changelog" : "변경 기록",
-    "New user" : "새 사용자",
     "Add group" : "그룹 추가",
-    "Everyone" : "모두",
     "Admins" : "관리자",
     "Disabled users" : "비활성화된 유저",
-    "Remove group" : "그룹 지우기",
     "Default quota:" : "기본 할당량:",
     "Select default quota" : "기본 할당량 설정",
     "Show Languages" : "언어 보이기",
@@ -223,33 +226,31 @@ OC.L10N.register(
     "Show user backend" : "사용자 백엔드 보이기",
     "Show storage path" : "스토리지 경로 보이기",
     "Send email to new user" : "새 사용자에게 이메일 보내기",
-    "You are about to remove the group {group}. The users will NOT be deleted." : "당신은 {group} 그룹을 지우려고 합니다. 그룹의 사용자들은 삭제되지 않습니다.",
-    "Please confirm the group removal " : "그룹 지우기를 확인해주세요.",
+    "Address" : "주소",
+    "Full name" : "전체 이름",
+    "Phone number" : "휴대폰 번호",
+    "Twitter" : "트위터",
+    "Website" : "웹사이트",
     "Enable" : "사용함",
-    "The app will be downloaded from the app store" : "이 앱을 앱 스토어에서 다운로드합니다",
     "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "이 앱은 현재 Nextcloud 버젼과 호환되지 않습니다.  이 앱을 설치하면, 제대로 작동하지 않을 수 있습니다.",
     "Never" : "하지 않음",
     "An error occured during the request. Unable to proceed." : "요청을 보내는 도중 에러가 발생하였습니다. 더 이상 진행할 수 없습니다.",
     "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "앱이 활성화되었지만, 앱을 업데이트해야 합니다. 5초 후 앱 업데이트 페이지로 넘어갑니다.",
     "App update" : "앱 업데이트",
-    "Error: This app can not be enabled because it makes the server unstable" : "오류: 이 앱은 서버를 불안정하게 만들 수 있어서 활성화할 수 없습니다",
     "Administrator documentation" : "관리자 문서",
     "Documentation" : "문서",
     "Forum" : "포럼",
-    "None" : "없음",
     "Login" : "로그인",
     "Plain" : "일반",
     "NT LAN Manager" : "NT LAN 관리자",
     "SSL/TLS" : "SSL/TLS",
     "STARTTLS" : "STARTTLS",
-    "Email server" : "이메일 서버",
     "Open documentation" : "문서 열기",
     "It is important to set up this server to be able to send emails, like for password reset and notifications." : "암호 초기화 및 알림 이메일을 보내려면 이메일 서버를 설정해야 합니다.",
     "Send mode" : "보내기 모드",
     "Encryption" : "암호화",
     "Sendmail mode" : "Sendmail 모드",
     "From address" : "보낸 사람 주소",
-    "mail" : "메일",
     "Authentication method" : "인증 방법",
     "Authentication required" : "인증 필요함",
     "Server address" : "서버 주소",
@@ -258,9 +259,7 @@ OC.L10N.register(
     "SMTP Username" : "SMTP 사용자 이름",
     "SMTP Password" : "SMTP 암호",
     "Save" : "저장",
-    "Test email settings" : "이메일 설정 시험",
     "Send email" : "이메일 보내기",
-    "Security & setup warnings" : "보안 및 설치 경고",
     "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "당신의 인스턴스의 보안과 성능을 위해서는 모든 것이 정확하게 설정되어야 합니다. 그러기 위해서 자동적으로 몇 가지를 확인하겠습니다. 더 자세한 정보를 위해서 링크된 문서를 참고하세요.",
     "All checks passed." : "모든 검사를 통과했습니다.",
     "There are some errors regarding your setup." : "설정을 살펴본 결과 몇 가지 에러가 있습니다.",
@@ -285,7 +284,6 @@ OC.L10N.register(
     "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "과거에 사용하였던(ownCloud <= 8.0) 암호화된 데이터에서 키를 이전해야 합니다. \"기본 암호화 모듈\"을 활성화한 다음 'occ encryption:migrate'를 실행하십시오",
     "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "ownCloud 8.0 이하에서 사용한 이전 암호화 키를 새 키로 이전해야 합니다.",
     "Start migration" : "이전 시작",
-    "Background jobs" : "배경 작업",
     "Last job execution ran %s. Something seems wrong." : "마지막 작업이 %s에 실행되었습니다. 무언가 잘못된 것 같습니다.",
     "Last job ran %s." : "마지막 작업이 %s에 실행되었습니다.",
     "Background job didn’t run yet!" : "배경 작업이 아직 실행되지 않았습니다!",
@@ -294,8 +292,6 @@ OC.L10N.register(
     "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "이 항목을 실행하려면 PHP POSIX 확장이 필요합니다. 자세한 사항은 {linkstart}PHP 문서{linkend}를 참조하십시오.",
     "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "관리자로 공유 행동을 미세 조정할 수 있습니다. 더 많은 정보를 보려면 문서를 참조하십시오.",
     "Allow apps to use the Share API" : "앱에서 공유 API를 사용할 수 있도록 허용",
-    "Expire after " : "다음 날짜 후 만료",
-    "days" : "일",
     "Enforce expiration date" : "만료 날짜 강제",
     "Allow public uploads" : "공개 업로드 허용",
     "Always ask for a password" : "항상 암호 묻기",
@@ -322,44 +318,31 @@ OC.L10N.register(
     "You are a member of the following groups:" : "당신은 다음 그룹의 멤버입니다:",
     "You are using <strong>%s</strong>" : "현재 <strong>%s</strong>를 사용하고 있습니다.",
     "You are using <strong>%1$s</strong> of <strong>%2$s</strong> (<strong>%3$s %%</strong>)" : "현재 <strong>%2$s</strong> /%1$s</strong>(<strong>%3$s%%</strong>)를 사용하고 있습니다",
-    "Full name" : "전체 이름",
-    "No display name set" : "표시 이름이 설정되지 않음",
-    "Your email address" : "이메일 주소",
-    "No email address set" : "이메일 주소가 설정되지 않음",
-    "For password reset and notifications" : "암호 초기화 및 알림에 사용",
-    "Phone number" : "휴대폰 번호",
     "Your phone number" : "내 휴대폰 번호",
-    "Address" : "주소",
     "Your postal address" : "내 우편 주소",
-    "Website" : "웹사이트",
     "It can take up to 24 hours before the account is displayed as verified." : "계정이 확인된 것으로 표시될 때까지 최대 24시간이 걸릴 수 있습니다",
     "Link https://…" : "링크 https://…",
-    "Twitter" : "트위터",
     "Twitter handle @…" : "트위터 핸들 @…",
-    "Help translate" : "번역 돕기",
     "Locale" : "지역",
     "Current password" : "현재 암호",
     "New password" : "새 암호",
     "Change password" : "암호 변경",
     "Use a second factor besides your password to increase security for your account." : "사용자의 계정을 더욱 안전하게 보호하기 위해 암호와 함께 2단계 인증을 사용하세요.",
-    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "오류가 발생했습니다. ASCII로 인코딩된 PEM 인증서를 업로드하십시오.",
-    "Valid until {date}" : "{date}까지 유효함",
-    "Only visible to local users" : "로컬 사용자만 보임",
-    "Only visible to you" : "나만 보임",
-    "Contacts" : "연락처",
-    "Visible to local users and to trusted servers" : "로컬 사용자와 신뢰된 서버에게 보이기",
     "Public" : "공개",
-    "Will be synced to a global and public address book" : "공개 및 전역 주소록으로 동기화됨",
-    "by" : "by",
-    "SSL Root Certificates" : "SSL 루트 인증서",
-    "Common Name" : "공통 이름",
-    "Valid until" : "만료 기간:",
-    "Issued By" : "발급자:",
-    "Valid until %s" : "%s까지 유효함",
-    "Import root certificate" : "루트 인증서 가져오기",
-    "Execute one task with each page loaded" : "개별 페이지를 불러올 때마다 실행",
+    "installing and updating apps via the app store or Federated Cloud Sharing" : "앱 스토어 및 연합 클라우드 공유로 앱 설치 및 업데이트",
+    "You need to set your user email before being able to send test emails." : "테스트 이메일을 보내기 전 내 주소를 설정해야 합니다.",
+    "Add user in group" : "그룹에 사용자 추가",
+    "Close" : "닫기",
+    "All languages" : "모든 언어",
+    "Everyone" : "모두",
+    "The app will be downloaded from the app store" : "이 앱을 앱 스토어에서 다운로드합니다",
+    "Error: This app can not be enabled because it makes the server unstable" : "오류: 이 앱은 서버를 불안정하게 만들 수 있어서 활성화할 수 없습니다",
+    "mail" : "메일",
+    "Test email settings" : "이메일 설정 시험",
+    "Expire after " : "다음 날짜 후 만료",
+    "days" : "일",
     "Allow users to share via link" : "사용자별 링크 공유 허용",
-    "Allow username autocompletion in share dialog. If this is disabled the full username or email address needs to be entered." : "공유 대화 상자에서 사용자 이름을 자동으로 완성합니다. 이 설정을 사용하지 않으면 전체 사용자 이름이나 이메일 주소를 입력해야 합니다.",
-    "Show disclaimer text on the public link upload page. (Only shown when the file list is hidden.)" : "공개 링크 업로드 페이지에 고지 사항 텍스트를 표시합니다.(파일 목록이 숨겨져 있는 경우에만 표시합니다.)"
+    "No display name set" : "표시 이름이 설정되지 않음",
+    "For password reset and notifications" : "암호 초기화 및 알림에 사용"
 },
 "nplurals=1; plural=0;");
