@@ -7,17 +7,8 @@ OC.L10N.register(
     "Not saved" : "Nuk u ruajt",
     "Sending…" : "dërgim",
     "Email sent" : "Email-i u dërgua",
-    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Ndodhi një gabim. Ju lutemi, ngarkoni një dëshmi PEM të koduar me ASCII.",
-    "Valid until {date}" : "E vlefshme deri më {date}",
-    "Delete" : "Fshij",
-    "Local" : "Lokale",
     "Private" : "Private",
-    "Only visible to local users" : "E dukshme vetëm për përdoruesit lokal",
-    "Only visible to you" : "E dukshme vetëm për ju",
-    "Contacts" : "Kontaktet",
-    "Visible to local users and to trusted servers" : "E dukshme për përdoruesit lokal dhe serverat e besuar",
-    "Public" : "Publiku",
-    "Will be synced to a global and public address book" : "Do të sinkronizohet te një libër adresash publik dhe global",
+    "Local" : "Lokale",
     "Verify" : "Verifiko",
     "Verifying …" : "Duke verifikuar ...",
     "Unable to change password" : "S’arrin të ndryshojë fjalëkalimin",
@@ -46,7 +37,6 @@ OC.L10N.register(
     "Please provide an admin recovery password; otherwise, all user data will be lost." : "Ju lutemi siguro një fjalëkalim të rikuperueshëm admini; përndryshe, të gjithë të dhënat e përdoruesit do të humbasin ",
     "Wrong admin recovery password. Please check the password and try again." : "Fjalëkalim i gabuar rikthimesh për përgjegjësin. Ju lutemi, kontrolloni fjalëkalimin dhe provoni përsëri.",
     "Backend doesn't support password change, but the user's encryption key was updated." : "Programi klient s’mbulon ndryshime fjalëkalimi, por kyçi i përdoruesi për fshehtëzime u përditësua me sukses.",
-    "installing and updating apps via the app store or Federated Cloud Sharing" : "instalim dhe përditësim aplikacionesh përmes shitores së aplikacioneve ose Federated Cloud Sharing",
     "Federated Cloud Sharing" : "Ndarje Në Re të Federuar ",
     "Invalid SMTP password." : "Fjalëkalim SMTP i pavlefshëm",
     "Email setting test" : "Test i konfigurimeve të Email-it",
@@ -54,7 +44,6 @@ OC.L10N.register(
     "If you received this email, the email configuration seems to be correct." : "Nëse keni marrë këtë email, konfigurimi i email-it duket të jetë i saktë.",
     "Email could not be sent. Check your mail server log" : "Email nuk mund të dërgohej. Kontrolloni logun e serverit tuaj të postës",
     "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Ndodhi një gabim gjatë dërgimit të email-it. Ju lutemi, rishikoni rregullimet tuaja. (Error: %s)",
-    "You need to set your user email before being able to send test emails." : "Lypset të caktoni email-in tuaj si përdorues, përpara se të jeni në gjendje të dërgoni email-e provë.",
     "Invalid mail address" : "Adresë email e pavlefshme",
     "Settings saved" : "Konfigurimet u ruajtën",
     "Unable to change full name" : "S’arrin të ndryshojë emrin e plotë",
@@ -79,23 +68,29 @@ OC.L10N.register(
     "Set your password" : "Vendos fjalëkalimin tënd",
     "Go to %s" : "Shko tek %s",
     "Install Client" : "Instalo Klient",
+    "Apps" : "Aplikacione",
+    "Settings" : "Rregullimet",
+    "Personal" : "Personale",
     "Additional settings" : "Konfigurime shtesë",
     "Basic settings" : "Konfigurime bazike",
     "Sharing" : "Ndarje me të tjerët",
     "Personal info" : "Informacion personal",
+    "Email server" : "Shërbyes email-esh",
+    "Security & setup warnings" : "Sinjalizime sigurie & rregullimi",
+    "Background jobs" : "Punët në background",
     "Create" : "Krijo",
     "Change" : "Ndrysho",
+    "Delete" : "Fshij",
     "Unlimited" : "E pakufizuar",
     "Verifying" : "Duke verifikuar",
+    "None" : "Asnjë",
     "Limit to groups" : "Kufizo grupet",
     "Save changes" : "Ruaj ndryshimet",
-    "Featured" : "I paraqitur",
-    "by" : "nga",
+    "All" : "Krejt",
+    "No results" : "Asnjë rezultat",
     "Update to {version}" : "Përditëso në {version}",
     "Remove" : "Hiqe",
     "Disable" : "Çaktivizoje",
-    "All" : "Krejt",
-    "No results" : "Asnjë rezultat",
     "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Ky aplikacion nuk ka të caktuar një minimum versioni të Nextcloud. Ky do të jetë një gabim në të ardhmen.",
     "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Ky aplikacion nuk ka të caktuar një maksimum versioni të Nextcloud. Ky do të jetë një gabim në të ardhmen.",
     "This app cannot be installed because the following dependencies are not fulfilled:" : "Ky aplikacion s’mund të instalohet, ngaqë për të nuk plotësohen varësitë vijuese:",
@@ -105,10 +100,9 @@ OC.L10N.register(
     "User documentation" : "Dokumentim për përdoruesit",
     "Admin documentation" : "Dokumentim për përgjegjësit",
     "Developer documentation" : "Dokumentim për zhvillues",
+    "Featured" : "I paraqitur",
     "No apps found for your version" : "S’u gjetën aplikacione për versionin tuaj",
     "Enable all" : "Aktivizoi të gjitha",
-    "Enable" : "Aktivizoje",
-    "The app will be downloaded from the app store" : "Aplikacioni do të shkarkohet nga shitorja e aplikacioneve",
     "Allow filesystem access" : "Lejo aksesin e sistemit të skedarëve",
     "Rename" : "Rename",
     "Revoke" : "Anulo",
@@ -135,21 +129,24 @@ OC.L10N.register(
     "Done" : "U bë",
     "Copied!" : "U kopjua!",
     "Copy" : "Kopjo",
+    "Remove group" : "Hiq grupin",
+    "Your email address" : "Adresa juaj email",
+    "No email address set" : "S’është caktuar adresë email",
+    "Language" : "Gjuhë",
+    "Help translate" : "Ndihmoni në përkthim",
+    "Add" : "Shto",
     "Cancel" : "Anuloje",
     "{size} used" : "{madhësia} e përdorur",
+    "New user" : "Përdorues i ri",
     "Display name" : "Shfaq emrin",
     "Email" : "Email",
-    "Close" : "Mbylleni",
     "Group admin for" : "Administratori i  grupit për",
     "Quota" : "Kuota",
-    "Language" : "Gjuhë",
     "User backend" : "Program klient i përdoruesit",
     "Storage location" : "Vendndodhje Depozite",
     "Last login" : "Hyrja e fundit",
     "Default quota" : "Kuota Parazgjedhje",
-    "All languages" : "Të gjitha gjuhët",
     "Name your device" : "Emërtoni pajisjen tuaj",
-    "Add" : "Shto",
     "Adding your device …" : "Shtoni pajisjen tuaj ...",
     "Unnamed device" : "Paisje pa emër",
     "Your apps" : "Aplikacionet tuaja ",
@@ -157,41 +154,36 @@ OC.L10N.register(
     "Disabled apps" : "Aplikacionet pa aftësi ",
     "Updates" : "Përditësime",
     "App bundles" : "Pako e aplikacionit ",
-    "New user" : "Përdorues i ri",
+    "Details" : "Detaje",
+    "Changelog" : "Katalogu i ndryshimeve",
     "Add group" : "Shto grup",
-    "Everyone" : "Kushdo",
     "Admins" : "Administratorë",
     "Disabled users" : "Përdoruesit të çaktivizuar",
-    "Remove group" : "Hiq grupin",
     "Show last login" : "Shfaq hyrjen e fundit",
     "Show user backend" : "Shfaq programin klient të përdoruesit",
     "Send email to new user" : "Dërgo email përdoruesi të ri",
+    "Address" : "Adresa",
+    "Full name" : "Emër i plotë",
+    "Phone number" : "Numri i telefonit",
+    "Twitter" : "Twitter",
+    "Website" : "Faqe web-i",
+    "Enable" : "Aktivizoje",
     "Never" : "Kurrë",
     "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Aplikacioni është aktivizuar, por lyp të përditësohet. Do të ridrejtoheni te faqja e përditësimeve brenda 5 sekondash.",
     "App update" : "Përditësim aplikacioni",
-    "Error: This app can not be enabled because it makes the server unstable" : "Gabim: Ky aplikacion s’u aktivizua dot, ngaqë e bën shërbyesin të paqëndrueshëm.",
-    "SSL Root Certificates" : "Dëshmi SSL Rrënjë",
-    "Common Name" : "Emër i Rëndomtë",
-    "Valid until" : "E vlefshme deri më",
-    "Issued By" : "Lëshuar Nga",
-    "Valid until %s" : "E vlefshme deri më %s",
-    "Import root certificate" : "Importoni dëshmi rrënjë",
     "Administrator documentation" : "Dokumentim për përgjegjës",
     "Documentation" : "Dokumentacioni",
     "Forum" : "Forum",
-    "None" : "Asnjë",
     "Login" : "Hyrje",
     "Plain" : "E thjeshtë",
     "NT LAN Manager" : "Përgjegjës Rrjeti NT",
     "SSL/TLS" : "SSL/TLS",
     "STARTTLS" : "STARTTLS",
-    "Email server" : "Shërbyes email-esh",
     "Open documentation" : "Hapni dokumentimin",
     "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Është e rëndësishme të ngrini këtë server për të qenë në gjendje të dërgoni email, si për rivendosjen e fjalëkalimeve dhe për njoftimet.",
     "Send mode" : "Mënyrë dërgimi",
     "Encryption" : "Fshehtëzim",
     "From address" : "Nga adresa",
-    "mail" : "email",
     "Authentication method" : "Metodë mirëfilltësimi",
     "Authentication required" : "Lypset mirëfilltësim",
     "Server address" : "Adresë shërbyesi",
@@ -200,9 +192,7 @@ OC.L10N.register(
     "SMTP Username" : "Emër përdoruesi SMTP",
     "SMTP Password" : "Fjalëkalim SMTP",
     "Save" : "Ruaj",
-    "Test email settings" : "Testoni rregullimet e email-it",
     "Send email" : "Dërgo email",
-    "Security & setup warnings" : "Sinjalizime sigurie & rregullimi",
     "All checks passed." : "I kaloi krejt kontrollet.",
     "Version" : "Version",
     "Server-side encryption" : "Fshehtëzim më anë shërbyesi",
@@ -220,20 +210,15 @@ OC.L10N.register(
     "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "Lypset të migroni kyçet tuaj të fshehtëzimit nga fshehtëzimi i vjetër (ownCloud <= 8.0) te i riu. Ju lutemi, aktivizoni \"Modul parazgjedhje fshehtëzimesh\" dhe ekzekutoni 'occ encryption:migrate'",
     "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "Lypset të migroni kyçet tuaj të fshehtëzimit nga fshehtëzimi i vjetër (ownCloud <= 8.0) te i riu.",
     "Start migration" : "Fillo migrimin",
-    "Background jobs" : "Punët në background",
     "Last job execution ran %s. Something seems wrong." : "Ekzekutimi i punës së fundit vazhdoi %s. Diçka shkoi keq.",
     "Last job ran %s." : "Puna e fundit vazhdoi %s.",
     "Background job didn’t run yet!" : "Puna ne background nuk ka filluar akoma!",
     "For optimal performance it's important to configure background jobs correctly. For bigger instances 'Cron' is the recommended setting. Please see the documentation for more information." : "Për performancë optimale është e rëndësishme të konfigurosh punë të sfondit në mënyrë korrekte. Për raste më të mëdha 'Cron' është konfigurimi i rekomanduar. Ju lutem shih dokumentacionin për më shumë informacion.",
-    "Execute one task with each page loaded" : "Kryeni vetëm një veprim me secilën prej faqeve të ngarkuara",
     "The cron.php needs to be executed by the system user \"%s\"." : "con.php duhet të ekzekutohet bga përdoruesi i sistemit \"%s\".",
     "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "Për të bërë këtë ekzekutim ju duhet shtesa PHP POSIX. Shikoni {linkstart} dokumentacionin e PHP {linkend} pë më shumë detaje.",
     "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Si admin ju mund të rregulloni mirë sjelljen e ndarjes. Ju lutem shih dokumentacionin për më shumë informacion.",
     "Allow apps to use the Share API" : "Lejoni aplikacionet të përdorin API Share",
-    "Expire after " : "Skadon pas ",
-    "days" : "ditësh",
     "Enforce expiration date" : "Detyro datë skadimi",
-    "Allow users to share via link" : "Lejoji përdoruesit të ndajnë me të tjerët përmes lidhjesh",
     "Allow public uploads" : "Lejo ngarkime publike",
     "Always ask for a password" : "Gjithmonë pyet për një fjalëkalim",
     "Enforce password protection" : "Detyro mbrojtje me fjalëkalim",
@@ -242,9 +227,7 @@ OC.L10N.register(
     "Restrict users to only share with users in their groups" : "Përdoruesve kufizoju të ndajnë gjëra vetëm me përdorues në grupin e tyre",
     "Exclude groups from sharing" : "Përjashtoni grupe nga ndarjet",
     "These groups will still be able to receive shares, but not to initiate them." : "Këto grupe prapë do të jenë në gjendje të marrin ndarje nga të tjerët, por jo të fillojnë të tilla.",
-    "Show disclaimer text on the public link upload page. (Only shown when the file list is hidden.)" : "Shfaqni tekstin e mospranimit në linkun publik të faqes së ngarkuar. (Shfaqet vetëm kur lista e skedarit është e fshehur.)",
     "This text will be shown on the public link upload page when the file list is hidden." : "Ky tekst do të shfaqet në linkun publik të faqes së ngarkuar kur lista e skedarit të jetë e fshehur.",
-    "Personal" : "Personale",
     "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Zhvilluar nga {communityopen}komuniteti Nextcloud {linkclose},  {githubopen}kodi i hapur{linkclose} iështë licensuar sipar {licenseopen}AGPL{linkclose}.",
     "Like our Facebook page" : "Pëlqeni faqen tonë në Facebook",
     "Follow us on Twitter" : "Na ndiqni në Twitter",
@@ -257,37 +240,29 @@ OC.L10N.register(
     "png or jpg, max. 20 MB" : "png ose jpg, maks. 20 MB",
     "Picture provided by original account" : "Foto e prurë nga llogaria origjinale",
     "Choose as profile picture" : "Zgjidhni një foto profili",
-    "Details" : "Detaje",
     "You are using <strong>%s</strong>" : "Ju po përdorni <strong>%s</strong>",
-    "Full name" : "Emër i plotë",
-    "No display name set" : "S’është caktuar emër për në ekran",
-    "Your email address" : "Adresa juaj email",
-    "No email address set" : "S’është caktuar adresë email",
-    "For password reset and notifications" : "Për të rivendosur fjalëkalimin dhe njoftimet",
-    "Phone number" : "Numri i telefonit",
     "Your phone number" : "Numri juaj i telefonit",
-    "Address" : "Adresa",
     "Your postal address" : "Adresa juaj postale",
-    "Website" : "Faqe web-i",
     "It can take up to 24 hours before the account is displayed as verified." : "Kjo mund të marrë mbi 24 orë, përpara se llogaria të shfaqet si e verifikuar.",
     "Link https://…" : "Linku https://…",
-    "Twitter" : "Twitter",
     "Twitter handle @…" : "Përdoruesi i Twitter @ ...",
-    "Help translate" : "Ndihmoni në përkthim",
     "Current password" : "Fjalëkalimi i tanishëm",
     "New password" : "Fjalëkalimi i ri",
     "Change password" : "Ndrysho fjalëkalimin",
-    "Afrikaans" : "Afrikanë",
-    "Bulgarian" : "Bullgarë",
-    "English" : "Anglisht",
-    "Hungarian" : "Hungareze",
-    "Tonga" : "Tonga",
-    "Official apps are developed by and within the community. They offer central functionality and are ready for production use." : "Aplikacionet zyrtare zhvillohen nga komuniteti dhe brenta tij. Ato ofrojnë funksionalitet qëndror dhe janë gati për përdorim.",
-    "Official" : "Zyrtare",
-    "Store credentials" : "Depozitoji kredencialet",
-    "cron.php is registered at a webcron service to call cron.php every 15 minutes over HTTP." : "cron.php është regjistruar në një server webcron për të thirrur cron.php çdo 15 minuta mbi HTTP.",
-    "Use system cron service to call the cron.php file every 15 minutes." : "Përdor shërbimin cron të sistemit për të thirrur skedarin cron.php çdo 15 minuta.",
-    "Set default expiration date" : "Caktoni datë parazgjedhje skadimi",
-    "Share" : "Shpërndaje"
+    "Public" : "Publiku",
+    "installing and updating apps via the app store or Federated Cloud Sharing" : "instalim dhe përditësim aplikacionesh përmes shitores së aplikacioneve ose Federated Cloud Sharing",
+    "You need to set your user email before being able to send test emails." : "Lypset të caktoni email-in tuaj si përdorues, përpara se të jeni në gjendje të dërgoni email-e provë.",
+    "Close" : "Mbylleni",
+    "All languages" : "Të gjitha gjuhët",
+    "Everyone" : "Kushdo",
+    "The app will be downloaded from the app store" : "Aplikacioni do të shkarkohet nga shitorja e aplikacioneve",
+    "Error: This app can not be enabled because it makes the server unstable" : "Gabim: Ky aplikacion s’u aktivizua dot, ngaqë e bën shërbyesin të paqëndrueshëm.",
+    "mail" : "email",
+    "Test email settings" : "Testoni rregullimet e email-it",
+    "Expire after " : "Skadon pas ",
+    "days" : "ditësh",
+    "Allow users to share via link" : "Lejoji përdoruesit të ndajnë me të tjerët përmes lidhjesh",
+    "No display name set" : "S’është caktuar emër për në ekran",
+    "For password reset and notifications" : "Për të rivendosur fjalëkalimin dhe njoftimet"
 },
 "nplurals=2; plural=(n != 1);");
