@@ -8,8 +8,12 @@ OC.L10N.register(
     "Sending…" : "Skickar...",
     "Email sent" : "E-post skickad",
     "Private" : "Privat",
+    "Only visible to people matched via phone number integration through Talk on mobile" : "Endast synlig för personer matchade via telefonnummer integration via Talk i mobilen",
     "Local" : "Lokal",
+    "Only visible to people on this instance and guests" : "Endast synlig för personer på denna instansen och gäster",
+    "Federated" : "Federerad",
     "Only synchronize to trusted servers" : "Synkronisera endast med betrodda servrar",
+    "Published" : "Publicerad",
     "Synchronize to trusted servers and the global and public address book" : "Synkronisera med betrodda servrar och den globala och offentliga adressboken",
     "Verify" : "Verifiera",
     "Verifying …" : "Verifierar ...",
@@ -63,20 +67,24 @@ OC.L10N.register(
     "Please provide an admin recovery password; otherwise, all user data will be lost." : "Vänligen ange ett administratörs återställningslösenord; annars kommer alla användardata att försvinna.",
     "Wrong admin recovery password. Please check the password and try again." : "Felaktigt återställningslösenord för administratör. Vänligen kontrollera lösenordet och prova igen.",
     "Backend doesn't support password change, but the user's encryption key was updated." : "Backend stödjer inte att lösenord ändras men användarens krypteringsnyckel uppdaterades.",
-    "installing and updating apps via the app store or Federated Cloud Sharing" : "installerar och uppdaterar appar via appbutiken eller federerad molndelning",
+    "installing and updating apps via the App Store or Federated Cloud Sharing" : "installera och uppdatera appar via appbutiken eller federerad molndelning",
     "Federated Cloud Sharing" : "Federerad Moln-delning",
     "cURL is using an outdated %1$s version (%2$s). Please update your operating system or features such as %3$s will not work reliably." : "cURL använder en föråldrad %1$s version (%2$s). Uppdatera ditt operativsystem annars kommer inte funktioner som %3$s fungera pålitligt.",
+    "Could not determine if TLS version of cURL is outdated or not because an error happened during the HTTPS request against https://nextcloud.com. Please check the nextcloud log file for more details." : "Kunde inte bestämma om TLS-versionen av cURL är för gammal eller inte för ett fel uppstod under HTTPS-förfrågan mot https://nextcloud.com. Vänligen kontrollera nextcloud loggfilen för fler detaljer.",
     "Invalid SMTP password." : "Ogiltigt SMTP-lösenord.",
     "Email setting test" : "E-postinställningar test",
     "Well done, %s!" : "Bra gjort, %s!",
     "If you received this email, the email configuration seems to be correct." : "Om du får detta e-postmeddelande så har du ställt in e-postinställningarna rätt.",
     "Email could not be sent. Check your mail server log" : "E-post kunde inte skickas. Titta i din e-postserverlogg",
     "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Ett problem uppstod när e-post försökte skickas. Vänligen kontrollera dina inställningar. (Fel: %s)",
-    "You need to set your user email before being able to send test emails." : "Du behöver ställa in din användares e-postadress före du kan skicka test e-post.",
+    "Invalid user" : "Ogiltig användare",
     "Invalid mail address" : "Ogiltig e-postadress",
     "Settings saved" : "Inställningar sparade",
     "Unable to change full name" : "Kunde inte ändra namn",
     "Unable to change email address" : "Kunde inte ändra e-postadress",
+    "Unable to set invalid phone number" : "Kunde inte sätta ogiltigt telefonnummer",
+    "Unable to set invalid website" : "Kunde inte sätta ogiltig webbplats",
+    "Some account data was invalid" : "Någon kontoinformation var ogiltig",
     "In order to verify your Twitter account, post the following tweet on Twitter (please make sure to post it without any line breaks):" : "För att verifiera dit Twitter-konto, posta följande tweet på Twitter (Var säker att det postas utan radbrytningar):",
     "In order to verify your Website, store the following content in your web-root at '.well-known/CloudIdVerificationCode.txt' (please make sure that the complete text is in one line):" : "För att verifiera din webbplats, lagra följande innehåll i din webbrot på '.well-known/CloudIdVerificationCode.txt' (Vänligen säkerställ att hela texten ryms på en rad):",
     "%1$s changed your password on %2$s." : "%1$s ändrade ditt lösenord på %2$s",
@@ -94,7 +102,7 @@ OC.L10N.register(
     "Your %s account was created" : "Ditt %s konto skapades",
     "Welcome aboard" : "Välkommen ombord",
     "Welcome aboard %s" : "Välkommen ombord %s",
-    "Welcome to your %s account, you can add, protect, and share your data." : "Välkommen till ditt %s konto, du kan lägga till, skydda och dela dina data.",
+    "Welcome to your %s account, you can add, protect, and share your data." : "Välkommen till ditt %s konto, du kan lägga till, skydda och dela din data.",
     "Your username is: %s" : "Ditt användarnamn är: %s",
     "Set your password" : "Ställ in ditt lösenord",
     "Go to %s" : "Gå till %s",
@@ -105,12 +113,16 @@ OC.L10N.register(
     "Personal" : "Privat",
     "Administration" : "Administration",
     "Additional settings" : "Övriga inställningar",
+    "Admin privileges" : "Adminprivilegier",
     "Groupware" : "Grupprogram",
     "Overview" : "Översikt",
     "Basic settings" : "Generella inställningar",
     "Sharing" : "Dela",
     "Personal info" : "Personlig information",
     "Mobile & desktop" : "Mobil & skrivbord",
+    "Email server" : "E-postserver",
+    "Security & setup warnings" : "Säkerhet & systemvarningar",
+    "Background jobs" : "Bakgrundsjobb",
     "Create" : "Skapa",
     "Change" : "Ändra",
     "Delete" : "Ta bort",
@@ -118,8 +130,16 @@ OC.L10N.register(
     "Unlimited" : "Obegränsat",
     "Verifying" : "Verifiera",
     "A background job is pending that checks for user imported SSL certificates. Please check back later." : "Ett bakgrundsjobb väntar som söker efter användarimporterade SSL-certifikat. Vänligen kontrollera igen senare.",
+    "There are some user imported SSL certificates present, that are not used anymore with Nextcloud 21. They can be imported on the command line via \"occ security:certificates:import\" command. Their paths inside the data directory are shown below." : "Det finns några användarimporterade SSL-certifikat närvarande som inte längre används med Nextcloud 21. De kan importeras i kommandoraden via \"occ security:certificates:import\". Deras sökvägar inuti data-mappen visas nedanför.",
     "The old server-side-encryption format is enabled. We recommend disabling this." : "Det gamla krypteringsformatet på servern är aktiverat. Vi rekommenderar att du inaktiverar detta.",
+    "MariaDB version \"%s\" is used. Nextcloud 21 will no longer support this version and requires MariaDB 10.2 or higher." : "MariaDB version \"%s\" används. Nextcloud 21 kommer inte längre stödja denna versionen och kräver MariaDB 10.2 eller högre.",
+    "MySQL version \"%s\" is used. Nextcloud 21 will no longer support this version and requires MySQL 8.0 or MariaDB 10.2 or higher." : "MySQL version \"%s\" används. Nextcloud 21 kommer inte längre stödja denna versionen och kräver MySQL 8.0 eller MariaDB 10.2 eller högre.",
+    "PostgreSQL version \"%s\" is used. Nextcloud 21 will no longer support this version and requires PostgreSQL 9.6 or higher." : "PostgreSQL version \"%s\" används. Nextcloud 21 kommer inte längre stödja denna versionen och kräver PostgreSQL 9.6 eller högre.",
     "Nextcloud settings" : "Nextcloud-inställningar",
+    "Administration privileges" : "Administreringsprivilegier",
+    "Here you can decide which group can access certain sections of the administration settings." : "Här kan du bestämma vilken gruppen som har tillgång till vissa delar av administrationsinställningarna.",
+    "None" : "Ingen",
+    "Unable to modify setting" : "Kunde inte ändra inställning.",
     "Two-factor authentication can be enforced for all users and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "Tvåfaktorsautentisering kan påtvingas för alla användare och specifika grupper. Om de inte har en tvåfaktorsleverantör konfigurerad kommer de inte att kunna logga in i systemet.",
     "Enforce two-factor authentication" : "Påtvinga tvåfaktorsautentisering",
     "Limit to groups" : "Begränsa till grupper",
@@ -162,7 +182,6 @@ OC.L10N.register(
     "Rename" : "Byt namn",
     "Revoke" : "Återkalla",
     "Wipe device" : "Rensa enhet",
-    "Revoking this token might prevent the wiping of your device if it hasn't started the wipe yet." : "Återkallning kan förhindra att enheten rensas om inte rensningen redan har startat.",
     "Internet Explorer" : "Internet Explorer",
     "Edge" : "Edge",
     "Firefox" : "Firefox",
@@ -171,17 +190,17 @@ OC.L10N.register(
     "Google Chrome for Android" : "Google Chrome för Android",
     "iPhone" : "iPhone",
     "iPad" : "iPad",
-    "Nextcloud iOS app" : "Nextcloud iOS-app",
-    "Nextcloud Android app" : "Nextcloud Android-app",
-    "Nextcloud Talk for iOS" : "Nextcloud Talk för iOS",
-    "Nextcloud Talk for Android" : "Nextcloud Talk för Android",
+    "{productName} iOS app" : "{productName} iOS app",
+    "{productName} Android app" : "{productName} Android app",
+    "{productName} Talk for iOS" : "{productName} Talk för iOS",
+    "{productName} Talk for Android" : "{productName} Talk för Android",
     "Sync client - {os}" : "Synkroniseringsklient - {os}",
     "This session" : "Denna session ",
     "Device" : "Enhet",
     "Last activity" : "Senaste aktivitet",
     "Devices & sessions" : "Enheter & sessioner",
     "Web, desktop and mobile clients currently logged in to your account." : "Webb-, skrivbords- och mobila klienter som är inloggade på ditt konto just nu.",
-    "Do you really want to wipe your data from this device?" : "Vill du verkligen radera dina data från den här enheten?",
+    "Do you really want to wipe your data from this device?" : "Vill du verkligen radera din data från den här enheten?",
     "Confirm wipe" : "Bekräfta radering",
     "Error while creating device token" : "Fel vid skapande av enhetstoken",
     "Error while updating device token scope" : "Fel vid uppdatering av enhetstokens omfång",
@@ -199,13 +218,52 @@ OC.L10N.register(
     "Copied!" : "Kopierad!",
     "Copy" : "Kopiera",
     "Could not copy app password. Please copy it manually." : "Det gick inte att kopiera applösenordet. Kopiera det manuellt.",
+    "Remove group" : "Ta bort grupp",
+    "You are about to remove the group {group}. The users will NOT be deleted." : "Du håller på att ta bort gruppen {group}. Användarna kommer INTE att raderas.",
+    "Please confirm the group removal " : "Bekräfta borttagning av gruppen",
+    "Your biography" : "Din biografi",
+    "Unable to update biography" : "Kunde inte uppdatera biografi",
+    "Your full name" : "Ditt fullständiga namn",
+    "Unable to update full name" : "Kunde inte uppdatera fullständigt namn",
+    "No full name set" : "Inget fullständigt namn angivet",
+    "Email options" : "E-postinställningar",
+    "Primary email for password reset and notifications" : "Primär e-postadress för notifikationer och återställning av lösenord",
+    "Remove primary email" : "Ta bort primär e-postadress",
+    "Delete email" : "Ta bort e-post",
+    "Unset as primary email" : "Ta bort som primär e-post",
+    "This address is not confirmed" : "Denna adress är inte verifierad",
+    "Set as primary email" : "Välj som primär e-post",
+    "Your email address" : "Din e-postadress",
+    "Additional email address {index}" : "Ytterligare e-postadress {index}",
+    "Unable to delete primary email address" : "Kunde inte ta bort primär e-postadress",
+    "Unable to update primary email address" : "Kunde inte uppdatera primär e-postadress",
+    "Unable to add additional email address" : "Kunde inte lägga till ytterligare e-postadress",
+    "Unable to update additional email address" : "Kunde inte uppdatera ytterligare e-postadress",
+    "Unable to delete additional email address" : "Kunde inte ta bort ytterligare e-postadress",
+    "No email address set" : "Ingen e-postadress angiven",
+    "Additional emails" : "Ytterligare e-postadresser",
+    "Your headline" : "Din rubrik",
+    "Unable to update headline" : "Kunde inte uppdatera rubrik",
+    "Language" : "Språk",
+    "Help translate" : "Hjälp till med översättningarna",
+    "Unable to update language" : "Kunde inte uppdatera språk",
+    "No language set" : "Inget språk angivet",
+    "Your organisation" : "Din organisation",
+    "Unable to update organisation" : "Kunde inte uppdatera organisation",
+    "Edit your Profile visibility" : "Ändra synligheten för din profil",
+    "Enable Profile" : "Aktivera profil",
+    "Unable to update profile enabled state" : "Kunde inte uppdatera profilaktivering",
+    "{displayId}" : "{displayId}",
+    "Unable to update visibility of {displayId}" : "Kunde inte uppdatera synlighet för {displayId}",
+    "Your role" : "Din roll",
+    "Unable to update role" : "Kunde inte uppdatera roll",
+    "Add" : "Lägg till",
     "You do not have permissions to see the details of this user" : "Du har inte behörighet att se detaljerna för den här användaren",
     "Add new password" : "Lägg till nytt lösenord",
     "Add new email address" : "Lägg till ny e-postadress",
-    "Add user in group" : "Lägg till användare i grupp",
+    "Add user to group" : "Lägg till användare i grupp",
     "Set user as admin for" : "Gör användare till admin för",
     "Select user quota" : "Välj användarens quota",
-    "No language set" : "Inget språk angivet",
     "Delete user" : "Ta bort användare",
     "Wipe all devices" : "Rensa alla enheter",
     "Disable user" : "Stäng av användare",
@@ -220,29 +278,28 @@ OC.L10N.register(
     "Delete {userid}'s account" : "Ta bort konto för {userid}",
     "Welcome mail sent!" : "Välkomstmeddelande skickat via e-post!",
     "Edit User" : "Redigera användare",
+    "Toggle user actions menu" : "Växla menyn med användaråtgärder",
     "{size} used" : "{size} använt",
+    "New user" : "Ny användare",
     "Will be autogenerated" : "Kommer att autogenereras",
     "Display name" : "Visningsnamn",
     "Email" : "E-post",
     "Default language" : "Standardspråk",
     "Add a new user" : "Lägg till ny användare",
-    "Close" : "Stäng",
     "Group admin for" : "Gruppadministratör för",
     "Quota" : "Lagringsutrymme",
-    "Language" : "Språk",
     "User backend" : "Användarbackend",
     "Storage location" : "Lagringsplats",
     "Last login" : "Senaste inloggning",
     "No users in here" : "Inga användare här",
     "Default quota" : "Standard kvot",
     "Common languages" : "Vanliga språk",
-    "All languages" : "Alla språk",
+    "Other languages" : "Andra språk",
     "Password change is disabled because the master key is disabled" : "Lösenordsbyte är inaktiverat eftersom huvudnyckeln är inaktiverad",
     "Passwordless authentication requires a secure connection." : "Lösenordsfri autentisering kräver en säker anslutning.",
     "Add WebAuthn device" : "Lägg till WebAuthn-enhet",
     "Please authorize your WebAuthn device." : "Godkänn din WebAuthn-enhet.",
     "Name your device" : "Namnge din enhet",
-    "Add" : "Lägg till",
     "Adding your device …" : "Lägger till din enhet ....",
     "Server error while trying to add WebAuthn device" : "Serverfel när du försökte lägga till en WebAuthn-enhet",
     "Server error while trying to complete WebAuthn device registration" : "Serverfel när du försökte slutföra registreringen av en WebAuthn-enhet",
@@ -261,13 +318,12 @@ OC.L10N.register(
     "{license}-licensed" : "{license}-licensierad",
     "Details" : "Detaljer",
     "Changelog" : "Ändringslogg",
-    "New user" : "Ny användare",
+    "by {author}\n{license}" : "av {author}\n{license}",
     "Enter group name" : "Ange gruppnamn",
     "Add group" : "Lägg till grupp",
-    "Everyone" : "Alla",
+    "Active users" : "Aktiva användare",
     "Admins" : "Administratörer",
     "Disabled users" : "Inaktiva användare",
-    "Remove group" : "Ta bort grupp",
     "Default quota:" : "Standardkvot:",
     "Select default quota" : "Välj standard kvot",
     "Show Languages" : "Visa språk",
@@ -275,35 +331,48 @@ OC.L10N.register(
     "Show user backend" : "Visa användar-backend",
     "Show storage path" : "Visa lagringsväg",
     "Send email to new user" : "Skicka e-post till ny användare",
-    "You are about to remove the group {group}. The users will NOT be deleted." : "Du håller på att ta bort gruppen {group}. Användarna kommer INTE att raderas.",
-    "Please confirm the group removal " : "Bekräfta borttagning av gruppen",
+    "Address" : "Ort/Stad",
+    "Avatar" : "Avatar",
+    "About" : "Om",
+    "Full name" : "Namn",
+    "Additional email" : "Ytterligare e-postadress",
+    "Headline" : "Rubrik",
+    "Organisation" : "Organisation",
+    "Phone number" : "Telefonnummer",
+    "Profile" : "Profil",
+    "Role" : "Roll",
+    "Twitter" : "Twitter",
+    "Website" : "Webbplats",
+    "Profile visibility" : "Profilsynlighet",
+    "Not available as this property is required for core functionality including file sharing and calendar invitations" : "Inte tillgänglig då denna inställning krävs för essentiell funktionalitet såsom fildelning och kalenderinbjudningar",
+    "Not available as publishing user specific data to the lookup server is not allowed, contact your system administrator if you have any questions" : "Inte tillgänglig då publicering av användarspecifik data till lookup-servern inte är tillåten, kontakta din systemadministratör ifall du har frågor",
+    "Show to everyone" : "Visa för alla",
+    "Show to logged in users only" : "Visa endast för inloggade användare",
+    "Hide" : "Dölj",
     "Download and enable" : "Hämta och aktivera",
     "Enable" : "Aktivera",
     "Enable untested app" : "Aktivera otestad app",
-    "The app will be downloaded from the app store" : "Appen kommer hämtas från appbutiken",
+    "The app will be downloaded from the App Store" : "Appen kommer hämtas från appbutiken",
     "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Den här appen är inte markerad som kompatibel med din Nextcloud-version. Om du fortsätter kan du fortfarande installera appen. Observera att appen kanske inte fungerar som förväntat.",
     "Never" : "Aldrig",
     "An error occured during the request. Unable to proceed." : "Ett fel uppstod under förfrågan. Kan inte fortsätta.",
     "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Appen har aktiverats men måste uppdateras. Du kommer att omdirigeras till uppdateringssidan om 5 sekunder.",
     "App update" : "Appuppdatering",
-    "Error: This app can not be enabled because it makes the server unstable" : "Fel: Denna app kan inte aktiveras eftersom det gör servern instabil",
+    "Error: This app cannot be enabled because it makes the server unstable" : "Fel: Denna appen kan inte aktiveras eftersom den gör servern instabil",
     "Administrator documentation" : "Administratörsdokumentation",
     "Documentation" : "Dokumentation",
     "Forum" : "Forum",
-    "None" : "Ingen",
     "Login" : "Logga in",
     "Plain" : "Enkel",
     "NT LAN Manager" : "NT LAN Manager",
     "SSL/TLS" : "SSL/TLS",
     "STARTTLS" : "STARTTLS",
-    "Email server" : "E-postserver",
     "Open documentation" : "Öppna dokumentation",
     "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Det är viktigt att konfigurera den här servern för att kunna skicka e-post, till exempel för återställning av lösenord och aviseringar.",
     "Send mode" : "Sändningsläge",
     "Encryption" : "Kryptering",
     "Sendmail mode" : "Sendmail-läge",
     "From address" : "Från adress",
-    "mail" : "e-post",
     "Authentication method" : "Autentiseringsmetod",
     "Authentication required" : "Autentisering krävs",
     "Server address" : "Serveradress",
@@ -312,9 +381,7 @@ OC.L10N.register(
     "SMTP Username" : "SMTP-användarnamn",
     "SMTP Password" : "SMTP-lösenord",
     "Save" : "Spara",
-    "Test email settings" : "Testa e-postinställningar",
     "Send email" : "Skicka e-post",
-    "Security & setup warnings" : "Säkerhet & systemvarningar",
     "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Det är viktigt för säkerhet och prestanda av din instans att allt är korrekt konfigurerat. För att hjälpa dig med det gör vi några automatiska kontroller. Se den länkade dokumentationen för mer information.",
     "All checks passed." : "Alla kontroller lyckades!",
     "There are some errors regarding your setup." : "Det finns några fel angående din inställning.",
@@ -331,7 +398,7 @@ OC.L10N.register(
     "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "När kryptering är aktiverat, så kommer alla filer som laddas upp till servern från den tidpunkt och framåt bli krypterad på servern. Det kommer bara vara möjligt att inaktivera kryptering vid ett senare tillfälle om krypteringsmodulen stödjer den funktionen och alla förvillkor (exempelvis använder återställningsnyckel) är mötta.",
     "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "Enbart kryptering garanterar inte säkerhet i systemet. Vänligen se dokumentationen för ytterligare information om hur krypteringsappen fungerar, och de supporterade användarfallen.",
     "Be aware that encryption always increases the file size." : "OBS! Observera att kryptering alltid ökar filstorleken",
-    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Det är alltid en god ide att skapa regelbundna säkerhetskopior av dina data, om kryptering används var säker på att även krypteringsnycklarna säkerhetskopieras tillsammans med dina data.",
+    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Det är alltid en god ide att skapa regelbundna säkerhetskopior av din data, om kryptering används var säker på att även krypteringsnycklarna säkerhetskopieras tillsammans med din data.",
     "This is the final warning: Do you really want to enable encryption?" : "Detta är en slutgiltig varning: Vill du verkligen aktivera kryptering?",
     "Enable encryption" : "Aktivera kryptering",
     "No encryption module loaded, please enable an encryption module in the app menu." : "Ingen krypteringsmodul inläst, vänligen aktivera krypteringsmodulen i applikationsmenyn.",
@@ -339,7 +406,6 @@ OC.L10N.register(
     "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "Du behöver migrera dina krypteringsnycklar från den gamla krypteringen (owncloud <= 8.0) till den nya. Vänligen aktivera \"Standard krypteringsmodul\" och kör 'occ encryption:migrate'.",
     "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "Du behöver migrera dina krypteringsnycklar från den gamla krypteringen (owncloud <= 8.0) till den nya.",
     "Start migration" : "Starta migrering",
-    "Background jobs" : "Bakgrundsjobb",
     "Last job execution ran %s. Something seems wrong." : "Sista jobbexekveringen körde %s. Något verkar vara fel.",
     "Some jobs haven’t been executed since %s. Please consider increasing the execution frequency." : "Vissa jobb har inte utförts sedan %s. Överväg att justera tid för exekvering.",
     "Some jobs didn’t execute since %s. Please consider switching to system cron." : "Vissa jobb utfördes inte sedan %s. Överväg att byta till system cron.",
@@ -352,20 +418,31 @@ OC.L10N.register(
     "Use system cron service to call the cron.php file every 5 minutes." : "Använd systemets cron-tjänst för att anropa cron.php var 5: e minut.",
     "The cron.php needs to be executed by the system user \"%s\"." : "Cron.php behöver exekveras av systemanvändaren \"%s\".",
     "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "För att köra detta behöver du PHP POSIX-tillägget. Se {linkstart}PHP dokumentation{linkend} för mer detaljer.",
+    "You need to enable the File sharing App." : "Du måste aktivera fildelnings-appen.",
     "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Som administratör kan du fininställa delningsbeteendet. Vänligen se dokumentationen för mer information.",
     "Allow apps to use the Share API" : "Tillåt applikationer att använda API för delning",
     "Set default expiration date for shares" : "Ställ in standardutgångsdatum för delningar",
-    "Expire after " : "Förfaller efter",
-    "days" : "dagar",
+    "Expire after" : "Utgår efter",
+    "day(s)" : "dag(ar)",
     "Enforce expiration date" : "Tillämpa förfallodatum",
+    "Set default expiration date for shares to other servers" : "Ställ in standardutgångsdatum för delningar",
+    "Allow users to share via link and emails" : "Tillåt användare att dela via länk och e-post",
     "Allow public uploads" : "Tillåt offentlig uppladdning",
     "Always ask for a password" : "Fråga alltid efter lösenord",
     "Enforce password protection" : "Tillämpa lösenordskydd",
+    "Set default expiration date" : "Ställ in standardutgångsdatum",
+    "Exclude groups from creating link shares:" : "Exkludera grupper från att skapa länkdelningar:",
     "Allow resharing" : "Tillåt vidaredelning",
     "Allow sharing with groups" : "Tillåt delning med grupper",
     "Restrict users to only share with users in their groups" : "Begränsa användare till att enbart kunna dela med användare i deras grupper",
     "Exclude groups from sharing" : "Exkludera grupp från att dela",
     "These groups will still be able to receive shares, but not to initiate them." : "Dessa grupper kommer fortfarande kunna ta emot delningar, men inte skapa delningar.",
+    "Allow username autocompletion in share dialog" : "Tillåt autokomplettering av användarnamn i delningsdialogen",
+    "Allow username autocompletion to users within the same groups" : "Tillåt autokomplettering av användarnamn till användare inom samma grupper",
+    "Allow username autocompletion to users based on phone number integration" : "Tillåt autokomplettering av användarnamn till användare baserad på telefonnummerintegration",
+    "If autocompletion \"same group\" and \"phone number integration\" are enabled a match in either is enough to show the user." : "Om komplettering för \"samma grupp\" och \"telefonnummerintegration\" är aktiverade räcker det med en matchning i en av dem för att visa användaren.",
+    "Allow username autocompletion when entering the full name or email address (ignoring missing phonebook match and being in the same group)" : "Tillåt komplettering av användarnamn vid ifyllning av fullständigt namn eller e-postadress (bortser från saknande matchning i telefonboken eller grupptillhörighet i samma grupp)",
+    "Show disclaimer text on the public link upload page (only shown when the file list is hidden)" : "Visa friskrivningstext på offentliga uppladdningssidan (visas endast när fil-listan är gömd)",
     "This text will be shown on the public link upload page when the file list is hidden." : "Denna text kommer att visa på den offentliga uppladdnings-sidan när fil-listan är gömd.",
     "Default share permissions" : "Standardrättigheter för delning",
     "Reasons to use Nextcloud in your organization" : "Anledningar att använda Nextcloud i din organisation",
@@ -375,7 +452,9 @@ OC.L10N.register(
     "Follow us on Mastodon" : "Följ oss på Mastodon",
     "Check out our blog" : "Kolla in vår blogg",
     "Subscribe to our newsletter" : "Prenumerera på vårt nyhetsbrev",
+    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Denna community-release av Nextcloud stöds inte och direktnotifikationer är inte tillgängliga.",
     "Profile picture" : "Profilbild",
+    "Change privacy level of profile picture" : "Ändra hemlighetsnivå för profilbild",
     "Upload new" : "Ladda upp ny",
     "Select from Files" : "Välj från Filer",
     "Remove image" : "Ta bort bild",
@@ -385,48 +464,49 @@ OC.L10N.register(
     "You are a member of the following groups:" : "Du är medlem i följande grupper:",
     "You are using <strong>%s</strong>" : "Du använder <strong>%s</strong>",
     "You are using <strong>%1$s</strong> of <strong>%2$s</strong> (<strong>%3$s %%</strong>)" : "Du använder <strong>%1$s</strong> av <strong>%2$s</strong> (<strong>%3$s %%</strong>)",
-    "Full name" : "Namn",
-    "No display name set" : "Inget visningsnamn angivet",
-    "Your email address" : "Din e-postadress",
-    "No email address set" : "Ingen e-postadress angiven",
-    "For password reset and notifications" : "För lösenordsåterställning och aviseringar",
-    "Phone number" : "Telefonnummer",
+    "Change privacy level of phone number" : "Ända hemlighetsnivå för telefonnummer",
     "Your phone number" : "Ditt telefonnummer",
-    "Address" : "Ort/Stad",
+    "Change privacy level of address" : "Ända hemlighetsnivå för adress",
     "Your postal address" : "Ort/Stad",
-    "Website" : "Webbplats",
+    "Change privacy level of website" : "Ända hemlighetsnivå för hemsida",
     "It can take up to 24 hours before the account is displayed as verified." : "Det kan ta upp till 24 timmar innan kontot visas som verifierat.",
     "Link https://…" : "Länk https://...",
-    "Twitter" : "Twitter",
+    "Change privacy level of Twitter profile" : "Ända hemlighetsnivå för Twitterprofil",
     "Twitter handle @…" : "Twitter handle @…",
-    "Help translate" : "Hjälp till med översättningarna",
     "Locale" : "Plats",
     "Current password" : "Nuvarande lösenord",
     "New password" : "Nytt lösenord",
     "Change password" : "Ändra lösenord",
     "Use a second factor besides your password to increase security for your account." : "Använd en andra faktor förutom ditt lösenord för att öka säkerheten för ditt konto.",
-    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Ett fel uppstod. Vänligen ladda upp ett ASCII-kodad PEM-certifikat.",
-    "Valid until {date}" : "Giltig t.o.m. {date}",
-    "Only visible to local users" : "Endast synlig för lokala användare",
-    "Only visible to you" : "Endast synlig för dig",
-    "Contacts" : "Kontakter",
-    "Visible to local users and to trusted servers" : "Synlig för lokala användare och tillförlitliga servrar",
+    "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "Om du använder tredje-parts applikationer för att ansluta till Nextcloud vänligen skapa och konfigurera ett applösenord för varje innan två-faktor autentisering aktiveras.",
+    "Don't synchronize to servers" : "Synkronisera inte till servrar",
+    "Trusted" : "Betrodd",
     "Public" : "Offentlig",
-    "Will be synced to a global and public address book" : "Kommer att synkroniseras till global och offentlig adressbok",
-    "by" : "av",
-    "SSL Root Certificates" : "SSL Root certifikat",
-    "Common Name" : "Vanligt namn",
-    "Valid until" : "Giltigt till",
-    "Issued By" : "Utfärdat av",
-    "Valid until %s" : "Giltigt till %s",
-    "Import root certificate" : "Importera rotcertifikat",
-    "Execute one task with each page loaded" : "Exekvera en uppgift vid varje sidladdning",
+    "installing and updating apps via the app store or Federated Cloud Sharing" : "installerar och uppdaterar appar via appbutiken eller federerad molndelning",
+    "You need to set your user email before being able to send test emails." : "Du behöver ställa in din användares e-postadress före du kan skicka test e-post.",
+    "Revoking this token might prevent the wiping of your device if it hasn't started the wipe yet." : "Återkallning kan förhindra att enheten rensas om inte rensningen redan har startat.",
+    "Nextcloud iOS app" : "Nextcloud iOS-app",
+    "Nextcloud Android app" : "Nextcloud Android-app",
+    "Nextcloud Talk for iOS" : "Nextcloud Talk för iOS",
+    "Nextcloud Talk for Android" : "Nextcloud Talk för Android",
+    "Add user in group" : "Lägg till användare i grupp",
+    "Close" : "Stäng",
+    "All languages" : "Alla språk",
+    "Everyone" : "Alla",
+    "The app will be downloaded from the app store" : "Appen kommer hämtas från appbutiken",
+    "Error: This app can not be enabled because it makes the server unstable" : "Fel: Denna app kan inte aktiveras eftersom det gör servern instabil",
+    "mail" : "e-post",
+    "Test email settings" : "Testa e-postinställningar",
+    "Expire after " : "Förfaller efter",
+    "days" : "dagar",
     "Allow users to share via link" : "Tillåt användare att dela via länk",
     "Set default expiration date for link shares" : "Ställ in standardutgångsdatum för länkade delningar",
-    "Allow username autocompletion in share dialog. If this is disabled the full username or email address needs to be entered." : "Tillåt autokomplettering av användarnamn i delningsdialogen. Om detta är inaktiverat måste fullständigt användarnamn och epostadress anges.",
+    "Allow username autocompletion in share dialog (if this is disabled the full username or email address needs to be entered)" : "Tillåt autokomplettering av användarnamn i delningsdialogen (om detta är inaktiverat måste fullständigt användarnamn eller e-postadress anges)",
     "Restrict username autocompletion to users within the same groups" : "Begränsa prediktion av användarnamn till användare inom samma grupper.",
-    "Show disclaimer text on the public link upload page. (Only shown when the file list is hidden.)" : "Visa friskrivningstext på offentliga uppladdningssidan. (Visas endast när fil-listan är gömd.)",
-    "Don't synchronize to servers" : "Synkronisera inte till servrar",
-    "Trusted" : "Betrodd"
+    "No display name set" : "Inget visningsnamn angivet",
+    "For password reset and notifications" : "För lösenordsåterställning och aviseringar",
+    "Change privacy level of full name" : "Ändra hemlighetsnivå för helt namn",
+    "Change privacy level of email" : "Ändra hemlighetsnivå för e-post",
+    "Set as primary mail" : "Sätt som primär e-postadress"
 },
 "nplurals=2; plural=(n != 1);");
