@@ -8,10 +8,12 @@ OC.L10N.register(
     "Sending…" : "正在傳送……",
     "Email sent" : "電子郵件已寄出",
     "Private" : "私人",
-    "Don't synchronize to servers" : "不要同步至伺服器",
-    "Trusted" : "受信任",
+    "Only visible to people matched via phone number integration through Talk on mobile" : "僅對透過 Talk 在手提電話上通過電話號碼整合進行匹配的人可見",
+    "Local" : "近端",
+    "Only visible to people on this instance and guests" : "僅對此安裝的人和來賓可見",
+    "Federated" : "已聯盟",
     "Only synchronize to trusted servers" : "僅同步至受信任的伺服器",
-    "Public" : "公開",
+    "Published" : "已發佈",
     "Synchronize to trusted servers and the global and public address book" : "同步到受信任的伺服器以及全域與公開的通訊錄",
     "Verify" : "驗證",
     "Verifying …" : "正在驗證……",
@@ -52,8 +54,8 @@ OC.L10N.register(
     "You granted filesystem access to app password \"{token}\"" : "您授予了應用程式密碼「{token}」檔案系統的存取權限",
     "You revoked filesystem access from app password \"{token}\"" : "您撤銷了應用程式密碼「{token}」檔案系統的存取權限",
     "Security" : "安全性",
-    "You successfully logged in using two-factor authentication (%1$s)" : "你已成功使用兩步驟驗證進行登入 (%1$s)",
-    "A login attempt using two-factor authentication failed (%1$s)" : "使用兩步驟驗證登入失敗 (%1$s)",
+    "You successfully logged in using two-factor authentication (%1$s)" : "你已成功使用雙重認證進行登入（%1$s）",
+    "A login attempt using two-factor authentication failed (%1$s)" : "使用雙重認證登入失敗（%1$s）",
     "Remote wipe was started on %1$s" : "遠端抹除已開始於 %1$s",
     "Remote wipe has finished on %1$s" : "遠端抹除已結束於 %1$s",
     "Your <strong>password</strong> or <strong>email</strong> was modified" : "您的<strong>密碼</strong>或<strong>電子郵件</strong>已修改",
@@ -65,9 +67,9 @@ OC.L10N.register(
     "Please provide an admin recovery password; otherwise, all user data will be lost." : "請提供管理員還原密碼；否則所有用戶資料將會遺失。",
     "Wrong admin recovery password. Please check the password and try again." : "錯誤的管理員還原密碼。請檢查密碼並再試一次。",
     "Backend doesn't support password change, but the user's encryption key was updated." : "後端不支援變更密碼，但用戶加密密鑰已更新。",
-    "installing and updating apps via the app store or Federated Cloud Sharing" : "透過應用程式中心或是聯盟式雲端分享來安裝、更新應用程式",
+    "installing and updating apps via the App Store or Federated Cloud Sharing" : "透過 App Store 或是聯盟式雲端分享來安裝、更新應用程式",
     "Federated Cloud Sharing" : "聯盟式雲端分享",
-    "cURL is using an outdated %1$s version (%2$s). Please update your operating system or features such as %3$s will not work reliably." : "cURL 使用的版本 %1$s 過舊 (%2$s)。請更新您的作業系統，否則如 %3$s 等功能可能無法正常運作。",
+    "cURL is using an outdated %1$s version (%2$s). Please update your operating system or features such as %3$s will not work reliably." : "cURL 使用的版本 %1$s 過舊（%2$s）。請更新您的作業系統，否則如 %3$s 等功能可能無法正常運作。",
     "Could not determine if TLS version of cURL is outdated or not because an error happened during the HTTPS request against https://nextcloud.com. Please check the nextcloud log file for more details." : "對於 https://nextcloud.com 的 HTTPS 請求發生錯誤，因此無法確定 cURL 的 TLS 是否過舊。請檢查 nextcloud 的紀錄檔以取得更多資訊。",
     "Invalid SMTP password." : "無效的 SMTP 密碼",
     "Email setting test" : "測試郵件設定",
@@ -75,15 +77,17 @@ OC.L10N.register(
     "If you received this email, the email configuration seems to be correct." : "如果您收到這封電子郵件，代表電子郵件設定是正確的。",
     "Email could not be sent. Check your mail server log" : "無法傳送郵件。請檢查您的郵件伺服器紀錄檔",
     "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "傳送郵件時發生問題。請檢查您的設定。（錯誤：%s）",
-    "You need to set your user email before being able to send test emails." : "您必須先設定您的使用者電子郵件，然後才能傳送測試郵件。",
+    "You need to set your user email before being able to send test emails. Go to %s for that." : "您必須先設定您的用戶電子郵件，然後才能傳送測試郵件。前往 %s 進行設置。",
+    "Invalid user" : "用戶無效",
     "Invalid mail address" : "無效的電郵地址",
     "Settings saved" : "設定已儲存",
     "Unable to change full name" : "無法更改全名",
     "Unable to change email address" : "無法更改電郵地址",
     "Unable to set invalid phone number" : "無法設定無效的電話號碼",
-    "Some account data was invalid" : "某些帳號資料無效",
-    "In order to verify your Twitter account, post the following tweet on Twitter (please make sure to post it without any line breaks):" : "為了驗證您的推特帳號，請在推特上發佈下列推文（請確認推文內容沒有斷行）：",
-    "In order to verify your Website, store the following content in your web-root at '.well-known/CloudIdVerificationCode.txt' (please make sure that the complete text is in one line):" : "為了驗證您的網站，請將下列內容存至您網站的根目錄下路徑為「.well-known/CloudIdVerificationCode.txt」的檔案（請確保全文以一行的格式儲存）",
+    "Unable to set invalid website" : "無法設定無效的網站",
+    "Some account data was invalid" : "某些賬戶資料無效",
+    "In order to verify your Twitter account, post the following tweet on Twitter (please make sure to post it without any line breaks):" : "為了驗證您的推特賬戶，請在推特上發佈下列推文（請確認推文內容沒有斷行）：",
+    "In order to verify your Website, store the following content in your web-root at '.well-known/CloudIdVerificationCode.txt' (please make sure that the complete text is in one line):" : "為了驗證您的網站，請將下列內容存至您網站的根目錄下路徑為「。well-known/CloudIdVerificationCode。txt」的檔案（請確保全文以一行的格式儲存）",
     "%1$s changed your password on %2$s." : "%1$s 於 %2$s 更改了您的密碼。",
     "Your password on %s was changed." : "你 %s 的密碼已更改。",
     "Your password on %s was reset by an administrator." : "您 %s 的密碼已被管理員重設。",
@@ -96,26 +100,30 @@ OC.L10N.register(
     "Email address for %1$s changed on %2$s" : "%1$s 的電郵地址於 %2$s 已更改",
     "Email address changed for %s" : "%s 的電郵地址已更改",
     "The new email address is %s" : "新的電郵地址為 %s",
-    "Your %s account was created" : "您的 %s 帳號已經建立",
+    "Your %s account was created" : "您的 %s 賬戶已經建立",
     "Welcome aboard" : "歡迎加入",
     "Welcome aboard %s" : "歡迎加入 %s",
-    "Welcome to your %s account, you can add, protect, and share your data." : "歡迎使用您的 %s 帳號，您可以新增、保護並分享您的資料。",
+    "Welcome to your %s account, you can add, protect, and share your data." : "歡迎使用您的 %s 賬戶，您可以新增、保護並分享您的資料。",
     "Your username is: %s" : "您的用戶名稱為：%s",
     "Set your password" : "設定您的密碼",
     "Go to %s" : "前往 %s",
     "Install Client" : "安裝客戶端程式",
-    "Logged in user must be a subadmin" : "登入用戶必須為子管理員",
+    "Logged in user must be a subadmin" : "登入用戶必須為副管理員",
     "Apps" : "應用程式",
     "Settings" : "設定",
     "Personal" : "個人",
     "Administration" : "管理",
     "Additional settings" : "其他設定",
+    "Admin privileges" : "管理員權限",
     "Groupware" : "協作應用程式",
     "Overview" : "概覽",
     "Basic settings" : "基本設定",
     "Sharing" : "分享",
     "Personal info" : "個人資訊",
     "Mobile & desktop" : "手提電話及電腦",
+    "Email server" : "電郵伺服器",
+    "Security & setup warnings" : "安全及設定警示",
+    "Background jobs" : "後台作業",
     "Create" : "建立",
     "Change" : "更改",
     "Delete" : "刪除",
@@ -123,21 +131,26 @@ OC.L10N.register(
     "Unlimited" : "無限制",
     "Verifying" : "正在驗證",
     "A background job is pending that checks for user imported SSL certificates. Please check back later." : "背景作業正在檢查用戶匯入的SSL證書。請稍後再檢查。",
-    "There are some user imported SSL certificates present, that are not used anymore with Nextcloud 21. They can be imported on the command line via \"occ security:certificates:import\" command. Their paths inside the data directory are shown below." : "存在一些用戶匯入的SSL證書，這些在Nextcloud 21中不再使用。可以通過“ occ security:certificates:import”命令在命令行上將其導入。 它們在數據目錄中的路徑如下所示。",
+    "There are some user imported SSL certificates present, that are not used anymore with Nextcloud 21. They can be imported on the command line via \"occ security:certificates:import\" command. Their paths inside the data directory are shown below." : "存在一些用戶匯入的SSL證書，這些在Nextcloud 21中不再使用。可以通過“ occ security:certificates:import”命令在命令行上將其導入。它們在數據目錄中的路徑如下所示。",
+    "Invalid UUIDs of LDAP users or groups have been found. Please review your \"Override UUID detection\" settings in the Expert part of the LDAP configuration and use \"occ ldap:update-uuid\" to update them." : "LDAP 用戶或群組的 UUID 無效。請查看 LDAP 配置專家部分中的“覆蓋 UUID 檢測”設置，並使用“occ ldap:update-uuid”更新它們。",
     "The old server-side-encryption format is enabled. We recommend disabling this." : "啟用了舊的伺服器端加密格式。我們建議停用它。",
     "MariaDB version \"%s\" is used. Nextcloud 21 will no longer support this version and requires MariaDB 10.2 or higher." : "正在使用 MariaDB 版本「%s」。Nextcloud 21 不再支援此版本，並需要 MariaDB 10.2 或更新版本。",
-    "MySQL version \"%s\" is used. Nextcloud 21 will no longer support this version and requires MySQL 8 or higher." : "正在使用 MySQL 版本「%s」。Nextcloud 21 不再支援此版本，並需要 MySQL 8 或更新版本。",
+    "MySQL version \"%s\" is used. Nextcloud 21 will no longer support this version and requires MySQL 8.0 or MariaDB 10.2 or higher." : "正在使用 MySQL 版本「%s」。Nextcloud 21 不再支援此版本，並需要 MySQL 8.0、MariaDB 10.2 或更新版本。",
     "PostgreSQL version \"%s\" is used. Nextcloud 21 will no longer support this version and requires PostgreSQL 9.6 or higher." : "正在使用 PostgreSQL 版本「%s」。Nextcloud 21 不再支援此版本，並需要 PostgreSQL 9.6 或更新版本。",
     "Nextcloud settings" : "Nextcloud 設定",
-    "Two-factor authentication can be enforced for all users and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "可對所有使用者與特定群組強制啟用雙因素驗證。如果他們沒有設定雙因素驗證提供者，那麼他們就會無法登入系統。",
-    "Enforce two-factor authentication" : "強制雙因素驗證",
+    "Administration privileges" : "管理員權限",
+    "Here you can decide which group can access certain sections of the administration settings." : "您可以在此決定哪個群組可以存取哪些管理設定。",
+    "None" : "無",
+    "Unable to modify setting" : "無法修改設定",
+    "Two-factor authentication can be enforced for all users and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "可對所有用戶與特定群組實施雙重認證。如果他們沒有設定雙重認證提供者，那麼他們就會無法登入系統。",
+    "Enforce two-factor authentication" : "強制雙重認證",
     "Limit to groups" : "限制給特定群組",
-    "Enforcement of two-factor authentication can be set for certain groups only." : "強制雙因素驗證可僅為某些群組設定。",
-    "Two-factor authentication is enforced for all members of the following groups." : "對以下群組的所有成員強制開啟雙因素驗證。",
+    "Enforcement of two-factor authentication can be set for certain groups only." : "強制雙重認證可僅為某些群組設定。",
+    "Two-factor authentication is enforced for all members of the following groups." : "對以下群組成員實施雙重認證。",
     "Enforced groups" : "已強制的群組",
-    "Two-factor authentication is not enforced for members of the following groups." : "以下群組的成員不強制開啟雙因素驗證。",
+    "Two-factor authentication is not enforced for members of the following groups." : "不對以下群組成員實施雙重認證。",
     "Excluded groups" : "排除的群組",
-    "When groups are selected/excluded, they use the following logic to determine if a user has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If a user is both in a selected and excluded group, the selected takes precedence and 2FA is enforced." : "選取／排除群組時，其使用以下邏輯來確定使用者是否強制啟用雙因素驗證：如果沒有選取群組，雙因素驗證對所有除了排除群組以外的成員啟用。若選取了群組，則雙因素驗證會對所有該群組的成員啟用。如果某個使用者同時位在選取與排除的群組，則被選取的群組優先程度較高，因此會強制啟用雙因素驗證。",
+    "When groups are selected/excluded, they use the following logic to determine if a user has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If a user is both in a selected and excluded group, the selected takes precedence and 2FA is enforced." : "選擇／排除群組時，其使用以下邏輯來確定用戶是否強制啟用雙因素驗證：如果沒有選擇群組，雙因素驗證對所有除了排除群組以外的成員啟用。若選擇了群組，則雙因素驗證會對所有該群組的成員啟用。如果某個用戶同時位在選擇與排除的群組，則被選擇的群組優先程度較高，因此會強制啟用雙因素驗證。",
     "Save changes" : "儲存變更",
     "All" : "所有",
     "Limit app usage to groups" : "限制特定群組使用應用程式",
@@ -150,7 +163,7 @@ OC.L10N.register(
     "This app cannot be installed because the following dependencies are not fulfilled:" : "無法安裝此應用程式，因為無法滿足下列的依賴關係：",
     "View in store" : "在商店中檢視",
     "Visit website" : "造訪網站",
-    "Report a bug" : "回報錯誤",
+    "Report a bug" : "舉報錯誤",
     "User documentation" : "用戶使用手冊",
     "Admin documentation" : "管理員使用手冊",
     "Developer documentation" : "開發人員使用手冊",
@@ -160,6 +173,7 @@ OC.L10N.register(
     "Featured" : "精選",
     "Update to {update}" : "更新到 {update}",
     "Update all" : "更新全部",
+    "All apps are up-to-date." : "所有應用程式都是最新的。",
     "Results from other categories" : "其他分類的結果",
     "No apps found for your version" : "沒有找到適合您的版本的應用程式",
     "Disable all" : "全部停用",
@@ -171,7 +185,7 @@ OC.L10N.register(
     "Rename" : "重新命名",
     "Revoke" : "撤銷",
     "Wipe device" : "抹除裝置",
-    "Revoking this token might prevent the wiping of your device if it hasn't started the wipe yet." : "如果還沒開始抹除，則撤銷此權杖可能會導致無法抹除您的裝置。",
+    "Revoking this token might prevent the wiping of your device if it has not started the wipe yet." : "如果還沒開始抹除，則撤銷此權杖可能會導致無法抹除您的裝置。",
     "Internet Explorer" : "Internet Explorer",
     "Edge" : "Edge",
     "Firefox" : "Firefox",
@@ -180,16 +194,16 @@ OC.L10N.register(
     "Google Chrome for Android" : "Android 版 Google Chrome",
     "iPhone" : "iPhone",
     "iPad" : "iPad",
-    "Nextcloud iOS app" : "Nextcloud iOS 應用程式",
-    "Nextcloud Android app" : "Nextcloud Android 應用程式",
-    "Nextcloud Talk for iOS" : "iOS 版 Nextcloud Talk",
-    "Nextcloud Talk for Android" : "Android 版 Nextcloud Talk",
+    "{productName} iOS app" : "{productName} iOS 應用程式",
+    "{productName} Android app" : "{productName} Android 應用程式",
+    "{productName} Talk for iOS" : "{productName} Talk - iOS 版",
+    "{productName} Talk for Android" : "{productName} Talk - Android 版",
     "Sync client - {os}" : "同步客戶端 - {os}",
     "This session" : "此節",
     "Device" : "裝置",
     "Last activity" : "上次活動",
     "Devices & sessions" : "裝置和時段",
-    "Web, desktop and mobile clients currently logged in to your account." : "目前登入您帳號的網絡、桌面和流動裝置客戶端。",
+    "Web, desktop and mobile clients currently logged in to your account." : "目前登入您賬戶的網絡、桌面和流動裝置客戶端。",
     "Do you really want to wipe your data from this device?" : "您真的想要從此裝置抹除您的資料嗎？",
     "Confirm wipe" : "確認抹除",
     "Error while creating device token" : "建立裝置權杖時發生錯誤",
@@ -201,20 +215,64 @@ OC.L10N.register(
     "Create new app password" : "建立新的應用程式密碼",
     "Use the credentials below to configure your app or device." : "請使用下方的登入資訊來設定您的應用程式或是裝置",
     "For security reasons this password will only be shown once." : "基於安全性考量，這個密碼只會顯示一次",
-    "Username" : "使用者名稱",
+    "Username" : "用戶名稱",
     "Password" : "密碼",
     "Done" : "完成",
     "Show QR code for mobile apps" : "為行動裝置應用程式顯示 QR code",
     "Copied!" : "已複製！",
     "Copy" : "複製",
     "Could not copy app password. Please copy it manually." : "無法複製應用程式密碼。請手動複製。",
+    "Rename group" : "重新命名群組",
+    "Remove group" : "移除群組",
+    "You are about to remove the group {group}. The users will NOT be deleted." : "您將要移除群組 {group}。用戶將不會被刪除。",
+    "Please confirm the group removal " : "請確認移除群組",
+    "Your biography" : "個人小傳",
+    "Unable to update biography" : "無法更新小傳",
+    "Your full name" : "您的全名",
+    "Unable to update full name" : "無法更新全名",
+    "No full name set" : "未設定全名",
+    "Email options" : "電郵地址選項",
+    "Primary email for password reset and notifications" : "用於密碼重設和通告信件的主要電郵地址",
+    "Remove primary email" : "刪除主要電郵地址",
+    "Delete email" : "刪除電郵地址",
+    "Unset as primary email" : "取消設定為主要電郵地址",
+    "This address is not confirmed" : "此地址尚未確認",
+    "Set as primary email" : "設為主要電郵地址",
+    "Your email address" : "您的電郵地址",
+    "Additional email address {index}" : "附加電郵地址 {index}",
+    "Unable to delete primary email address" : "無法刪除主電郵地址",
+    "Unable to update primary email address" : "無法更新主電郵地址",
+    "Unable to add additional email address" : "無法添加其他電郵地址",
+    "Unable to update additional email address" : "無法更新其他電郵地址",
+    "Unable to delete additional email address" : "無法刪除其他電郵地址",
+    "No email address set" : "未設定電郵地址",
+    "Additional emails" : "其他電郵地址",
+    "Your headline" : "您的標題",
+    "Unable to update headline" : "無法更新標題",
+    "Language" : "語言",
+    "Help translate" : "協助翻譯",
+    "Unable to update language" : "無法更新語言",
+    "No language set" : "未設定語言",
+    "Your organisation" : "您的機構",
+    "Unable to update organisation" : "無法更新機構",
+    "Edit your Profile visibility" : "編輯個人檔案能見度",
+    "Enable Profile" : "啟用簡介",
+    "Unable to update profile enabled state" : "無法更新個人資料啟用狀態",
+    "The more restrictive setting of either visibility or scope is respected on your Profile. For example, if visibility is set to \"Show to everyone\" and scope is set to \"Private\", \"Private\" is respected." : "將會遵循您個人檔案中「能見度」與「範圍」較嚴格的設定。舉例來說，當「能見度」設定為「對所有人顯示」，而「範圍」設定為「私人」時。將使用「私人」的設定。",
+    "{displayId}" : "{displayId}",
+    "Unable to update visibility of {displayId}" : "無法更新 {displayId} 的可見性",
+    "Your role" : "你的角色",
+    "Unable to update role" : "無法更新角色",
+    "Add" : "新增",
+    "Change scope level of {accountProperty}" : "更改 {accountProperty} 的範圍",
+    "Unable to update federation scope of the primary {accountProperty}" : "無法更新主要 {accountProperty} 的聯盟範圍",
+    "Unable to update federation scope of additional {accountProperty}" : "無法更新額外 {accountProperty} 的聯盟範圍",
     "You do not have permissions to see the details of this user" : "您沒有檢視此用戶詳細資料的權限",
     "Add new password" : "新增密碼",
     "Add new email address" : "新增電郵地址",
-    "Add user in group" : "在群組中新增用戶",
+    "Add user to group" : "在群組中新增用戶",
     "Set user as admin for" : "將用戶設定為管理員",
-    "Select user quota" : "選取用戶配額",
-    "No language set" : "未設定語言",
+    "Select user quota" : "選擇用戶配額",
     "Delete user" : "刪除用戶",
     "Wipe all devices" : "抹除所有裝置",
     "Disable user" : "停用用戶",
@@ -224,43 +282,41 @@ OC.L10N.register(
     "Remote wipe of devices" : "遠端抹除裝置",
     "Wipe {userid}'s devices" : "抹除 {userid} 的裝置",
     "Cancel" : "取消",
-    "Fully delete {userid}'s account including all their personal files, app data, etc." : "完全刪除 {userid} 的帳號，包含他們所有的個人檔案、應用程式資料等等。",
-    "Account deletion" : "帳號刪除",
-    "Delete {userid}'s account" : "刪除 {userid} 的帳號",
+    "Fully delete {userid}'s account including all their personal files, app data, etc." : "完全刪除 {userid} 的賬戶，包含他們所有的個人檔案、應用程式資料等等。",
+    "Account deletion" : "賬戶刪除",
+    "Delete {userid}'s account" : "刪除 {userid} 的賬戶",
     "Welcome mail sent!" : "已傳送歡迎郵件！",
     "Edit User" : "編輯用戶",
-    "Toggle user actions menu" : "切換用戶動作選單",
+    "Toggle user actions menu" : "切換用戶操作選單",
     "{size} used" : "已使用 {size}",
+    "New user" : "新用戶",
     "Will be autogenerated" : "將自動生成",
     "Display name" : "顯示名稱",
     "Email" : "電郵地址",
     "Default language" : "預設語言",
     "Add a new user" : "新增用戶",
-    "Close" : "關閉",
     "Group admin for" : "群組管理員",
     "Quota" : "容量限制",
-    "Language" : "語言",
-    "User backend" : "用戶資料後端",
+    "User backend" : "用戶後端系統",
     "Storage location" : "儲存位置",
     "Last login" : "最後登入",
     "No users in here" : "這裡沒有用戶",
-    "Default quota" : "預設儲存容量限制",
+    "Default quota" : "默認儲存容量限制",
     "Common languages" : "常用語言",
-    "All languages" : "全部語言",
+    "Other languages" : "其他語言",
     "Password change is disabled because the master key is disabled" : "已停用密碼變更，因為主控密鑰已停用",
-    "Passwordless authentication requires a secure connection." : "無密碼身份驗證需要安全連線。",
+    "Passwordless authentication requires a secure connection." : "無密碼身分驗證需要安全連線。",
     "Add WebAuthn device" : "新增 WebAuthn 裝置",
     "Please authorize your WebAuthn device." : "請驗證您的 WebAuthn 裝置。",
     "Name your device" : "請為您的裝置命名",
-    "Add" : "新增",
     "Adding your device …" : "正在新增您的裝置……",
     "Server error while trying to add WebAuthn device" : "嘗試新增 WebAuthn 裝置時發生伺服器錯誤",
     "Server error while trying to complete WebAuthn device registration" : "嘗試完成 WebAuthn 裝置註冊時發生伺服器錯誤。",
     "Unnamed device" : "未命名的裝置",
     "Passwordless Authentication" : "無密碼驗證",
-    "Set up your account for passwordless authentication following the FIDO2 standard." : "按照 FIDO2 標準設定您帳號的無密碼驗證",
+    "Set up your account for passwordless authentication following the FIDO2 standard." : "按照 FIDO2 標準設定您賬戶的無密碼驗證",
     "No devices configured." : "未設定裝置。",
-    "The following devices are configured for your account:" : "為您的帳號設定了以下裝置。",
+    "The following devices are configured for your account:" : "為您的賬戶設定了以下裝置。",
     "Your browser does not support WebAuthn." : "您的瀏覽器不支援 WebAuthn。",
     "Your apps" : "您的應用程式",
     "Active apps" : "已啟用應用程式",
@@ -269,72 +325,82 @@ OC.L10N.register(
     "App bundles" : "應用程式套裝",
     "Featured apps" : "精選應用程式",
     "{license}-licensed" : "以 {license} 授權",
-    "Details" : "詳細資料",
-    "Changelog" : "變更紀錄",
+    "Details" : "詳細資訊",
+    "Changelog" : "軟件更新紀錄",
     "by {author}\n{license}" : "作者為 {author}\n{license}",
-    "New user" : "新用戶",
     "Enter group name" : "輸入群組名稱",
     "Add group" : "新增群組",
-    "Everyone" : "所有人",
+    "Active users" : "活躍用戶",
     "Admins" : "管理員",
     "Disabled users" : "已停用用戶",
-    "Remove group" : "移除群組",
     "Default quota:" : "預設容量限制：",
-    "Select default quota" : "選取預設容量限制",
+    "Select default quota" : "選擇預設容量限制",
     "Show Languages" : "顯示語言",
     "Show last login" : "顯示上次登入時間",
-    "Show user backend" : "顯示使用者資料後端",
+    "Show user backend" : "顯示用戶資料後端",
     "Show storage path" : "顯示儲存路徑",
     "Send email to new user" : "傳送電子郵件給新用戶",
-    "You are about to remove the group {group}. The users will NOT be deleted." : "您將要移除群組 {group}。用戶將不會被刪除。",
-    "Please confirm the group removal " : "請確認移除群組",
+    "Address" : "地址",
+    "Avatar" : "頭像",
+    "About" : "關於",
+    "Full name" : "全名",
+    "Additional email" : "附加電郵地址",
+    "Headline" : "標題",
+    "Organisation" : "機構",
+    "Phone number" : "電話號碼",
+    "Profile" : "個人設定",
+    "Role" : "角色",
+    "Twitter" : "Twitter",
+    "Website" : "網站",
+    "Profile visibility" : "個人檔案能見度",
+    "Not available as this property is required for core functionality including file sharing and calendar invitations" : "無法使用，因為此屬性是核心功能（包括檔案分享和日曆邀請）所必需的。",
+    "Not available as publishing user specific data to the lookup server is not allowed, contact your system administrator if you have any questions" : "無法使用，因為不允許將用戶的特定資料發佈到查詢伺服器。如果有任何問題，請聯絡您的系統管理員。",
+    "Show to everyone" : "顯示给所有人",
+    "Show to logged in users only" : "僅顯示給登錄用戶",
+    "Hide" : "隱藏",
     "Download and enable" : "下載並啟用",
     "Enable" : "啟用",
     "Enable untested app" : "啟用未經測試的應用程式",
-    "The app will be downloaded from the app store" : "將會從應用程式商店下載這個應用程式",
+    "The app will be downloaded from the App Store" : "將會從 App Store 下載這個應用程式",
     "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "此應用程式未被標記為與您的 Nextcloud 版本相容。如果繼續，您仍可安裝應用程式。但請注意應用程式可能無法正常運作。",
     "Never" : "絕不",
     "An error occured during the request. Unable to proceed." : "請求時發生錯誤。無法繼續。",
     "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "應用程式已啟用但是需要更新。您將會在5秒內被重新導向至更新頁面。",
     "App update" : "應用程式更新",
-    "Error: This app can not be enabled because it makes the server unstable" : "錯誤：此應用程序無法啟用，因為它造成伺服器不穩定",
+    "Error: This app cannot be enabled because it makes the server unstable" : "錯誤：此應用程序無法啟用，因為它造成伺服器不穩定",
     "Administrator documentation" : "管理員使用手冊",
     "Documentation" : "使用手冊",
     "Forum" : "論壇",
-    "None" : "無",
     "Login" : "登入",
     "Plain" : "明文",
     "NT LAN Manager" : "NT LAN 管理程式",
     "SSL/TLS" : "SSL/TLS",
     "STARTTLS" : "STARTTLS",
-    "Email server" : "電郵伺服器",
     "Open documentation" : "開啟使用手冊",
     "It is important to set up this server to be able to send emails, like for password reset and notifications." : "設置此伺服器以使其能夠發送電郵以進行密碼重置，通知等。",
     "Send mode" : "傳送模式",
     "Encryption" : "加密",
     "Sendmail mode" : "Sendmail 模式",
     "From address" : "寄件地址",
-    "mail" : "電郵地址",
     "Authentication method" : "認證方式",
     "Authentication required" : "需要認證",
     "Server address" : "伺服器位址",
     "Port" : "連接埠",
-    "Credentials" : "身份驗證",
+    "Credentials" : "身分驗證",
     "SMTP Username" : "SMTP 用戶名稱",
     "SMTP Password" : "SMTP 密碼",
     "Save" : "儲存",
-    "Test email settings" : "測試電子郵件設定",
+    "Test and verify email settings" : "測試及驗證電子郵件設定",
     "Send email" : "傳送測試電郵",
-    "Security & setup warnings" : "安全及設定警告",
-    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "正確設定每樣東西對您的站台的安全性與效能來說非常重要。為了協助您，我們正在進行一些自動檢查。請參閱連結資訊以取得更多資訊。",
+    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "正確的配置對於您 Nextcloud 的安全性和性能很重要。 為此，我們正執行一些自動檢查。 有關更多信息，請參閱連結的說明書。",
     "All checks passed." : "所有檢查皆通過。",
     "There are some errors regarding your setup." : "您的設定有些錯誤。",
-    "There are some warnings regarding your setup." : "您的設定有些警告。",
+    "There are some warnings regarding your setup." : "有關您設置的警告。",
     "Checking for system and security issues." : "檢查系統與安全性問題。",
     "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "請再次確認<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">安裝手冊 ↗</a>，並在<a href=\"%2$s\">紀錄檔</a>中檢查是否有任何錯誤或警告。",
     "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "透過<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">我們的安全性掃描 ↗</a>檢查您 Nextcloud 的安全性。",
     "Version" : "版本",
-    "Two-Factor Authentication" : "雙因素驗證",
+    "Two-Factor Authentication" : "雙重認證",
     "Server-side encryption" : "伺服器端加密",
     "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "伺服器端加密可以加密所有上傳到此伺服器的檔案，但這會讓檔案操作時間增加，降低效能，請審慎評估後再啟用。",
     "Enable server-side encryption" : "啟用伺服器端加密",
@@ -347,10 +413,9 @@ OC.L10N.register(
     "Enable encryption" : "啟用加密",
     "No encryption module loaded, please enable an encryption module in the app menu." : "沒有載入加密模組，請您在應用程式選單中啟用加密模組",
     "Select default encryption module:" : "選擇預設的加密模組：",
-    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "您必須將您的加密密鑰從舊的加密 (ownCloud <= 8.0) 遷移到新的。請啟用「預設加密模組」並執行 'occ encryption:migrate'",
-    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "您必須將您的加密密鑰從舊的加密 (ownCloud <= 8.0) 遷移到新的。",
+    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "您必須將您的加密密鑰從舊的加密（ownCloud <= 8.0）遷移到新的。請啟用「預設加密模組」並執行 'occ encryption：migrate'",
+    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "您必須將您的加密密鑰從舊的加密（ownCloud <= 8.0）遷移到新的。",
     "Start migration" : "開始遷移",
-    "Background jobs" : "後台作業",
     "Last job execution ran %s. Something seems wrong." : "上次後台作業執行於 %s。似乎有點問題。",
     "Some jobs haven’t been executed since %s. Please consider increasing the execution frequency." : "從 %s 開始，有一些工作未執行。請考慮增加執行頻率。",
     "Some jobs didn’t execute since %s. Please consider switching to system cron." : "從 %s 開始，有一些工作未執行。請考慮切換為系統 cron。",
@@ -359,28 +424,34 @@ OC.L10N.register(
     "For optimal performance it's important to configure background jobs correctly. For bigger instances 'Cron' is the recommended setting. Please see the documentation for more information." : "為了獲得最佳的效能，設定後台作業非常重要，對於比較大的服務來說，建議使用 Cron 設定，請查閱說明文件以獲得更多資訊。",
     "Pick background job setting" : "挑選後台作業設定",
     "Execute one task with each page loaded." : "每個頁面載入時執行一個工作。",
-    "cron.php is registered at a webcron service to call cron.php every 5 minutes over HTTP." : "cron.php 在 webcron 服務中註冊，每5分鐘透過 HTTP 呼叫 cron.php。",
-    "Use system cron service to call the cron.php file every 5 minutes." : "使用系統 cron 每5分鐘呼叫 cron.php。",
-    "The cron.php needs to be executed by the system user \"%s\"." : "cron.php 必須由系統使用者「%s」執行。",
+    "cron.php is registered at a webcron service to call cron.php every 5 minutes over HTTP." : "cron.php 在 webcron 服務中註冊，每5分鐘透過 HTTP 執行 cron.php。",
+    "Use system cron service to call the cron.php file every 5 minutes." : "使用系統 cron 每5分鐘執行 cron.php。",
+    "The cron.php needs to be executed by the system user \"%s\"." : "cron.php 必須由系統用戶「%s」執行。",
     "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "要執行這個，您需要 PHP POSIX 擴充元件。請查閱 {linkstart}PHP 說明文件{linkend} 以取得更多資訊。",
+    "You need to enable the File sharing App." : "您需要啟用檔案分享應用程式。",
     "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "系統管理員可以微調分享行為。請查閱說明文件以獲得更多資訊。",
     "Allow apps to use the Share API" : "允許應用程式使用分享 API",
     "Set default expiration date for shares" : "設定分享的預設到期日",
-    "Expire after " : "將在此日期後過期: ",
-    "days" : "天",
+    "Expire after" : "將在之後到期",
+    "day(s)" : "天",
     "Enforce expiration date" : "強制設定到期日",
-    "Allow users to share via link" : "允許使用者透過連結分享",
+    "Set default expiration date for shares to other servers" : "設置分享到其他伺服器的默認分享到期日",
+    "Allow users to share via link and emails" : "允許用戶透過連結和電郵分享",
     "Allow public uploads" : "允許公開上傳",
     "Always ask for a password" : "要求輸入密碼",
     "Enforce password protection" : "強制密碼保護",
-    "Set default expiration date for link shares" : "設定連結分享的預設到期日",
+    "Set default expiration date" : "設定默認到期日",
+    "Exclude groups from creating link shares:" : "禁止以下群組創建連結分享：",
     "Allow resharing" : "允許轉分享",
     "Allow sharing with groups" : "允許與群組分享",
     "Restrict users to only share with users in their groups" : "限制用戶僅能與他們群組中的其他用戶分享",
     "Exclude groups from sharing" : "禁止特定群組分享檔案",
     "These groups will still be able to receive shares, but not to initiate them." : "這些群組仍然能接受其他人的分享，但是沒有辦法發起分享。",
-    "Allow username autocompletion in share dialog (if this is disabled the full username or email address needs to be entered)" : "在分享對話框中允許用戶名稱自動完成（如果停用此選項，則必須輸入完整的用戶名稱或電郵地址）",
-    "Restrict username autocompletion to users within the same groups" : "將使用戶名稱限制為僅相同群組的用戶可使用",
+    "Allow username autocompletion in share dialog" : "在共享對話框中允許用戶名自動完成",
+    "Allow username autocompletion to users within the same groups" : "允許對同一群組中的用戶自動完成用戶名",
+    "Allow username autocompletion to users based on phone number integration" : "允許基於電話號碼整合的用戶自動完成用戶名",
+    "If autocompletion \"same group\" and \"phone number integration\" are enabled a match in either is enough to show the user." : "如果啟用了自動完成功能“相同的群組”和“電話號碼整合”，則任何一個匹配都足以向用戶顯示。",
+    "Allow username autocompletion when entering the full name or email address (ignoring missing phonebook match and being in the same group)" : "輸入全名或電郵地址時，允許用戶名自動完成（忽略缺少的電話簿匹配項，並且位於同一群組中）",
     "Show disclaimer text on the public link upload page (only shown when the file list is hidden)" : "在公開的檔案連結和上傳頁面顯示免責聲明（僅在檔案列表隱藏的時候才會顯示）",
     "This text will be shown on the public link upload page when the file list is hidden." : "這段文字會在公開檔案上傳頁面檔案列表被隱藏的時候顯示。",
     "Default share permissions" : "預設分享權限",
@@ -391,54 +462,61 @@ OC.L10N.register(
     "Follow us on Mastodon" : "在 Mastodon 上追蹤我們",
     "Check out our blog" : "逛逛我們的部落格",
     "Subscribe to our newsletter" : "訂閱我們的電子報",
+    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "不支援 Nextcloud 的這個社群版本，且即時通知不可用。",
     "Profile picture" : "個人資料圖片",
+    "Change privacy level of profile picture" : "更改個人資料圖片的私隱級別",
     "Upload new" : "上傳新的",
     "Select from Files" : "從雲端檔案選擇",
     "Remove image" : "移除圖像",
     "png or jpg, max. 20 MB" : "png 或 jpg，最大 20 MB",
-    "Picture provided by original account" : "原始帳號提供的圖片",
+    "Picture provided by original account" : "原始賬戶提供的圖片",
     "Choose as profile picture" : "設定為個人資料圖片",
     "You are a member of the following groups:" : "你是下列群組的成員︰",
     "You are using <strong>%s</strong>" : "您已使用了 <strong>%s</strong> 的存儲空間",
-    "You are using <strong>%1$s</strong> of <strong>%2$s</strong> (<strong>%3$s %%</strong>)" : "您已使用了 <strong>%2$s</strong> 中的 <strong>%1$s</strong> (<strong>%3$s %%</strong>)",
-    "Full name" : "全名",
-    "No display name set" : "未設定顯示名稱",
-    "Your email address" : "您的電郵地址",
-    "No email address set" : "未設定電郵地址",
-    "For password reset and notifications" : "用於密碼重設和通告信件",
-    "Phone number" : "電話號碼",
+    "You are using <strong>%1$s</strong> of <strong>%2$s</strong> (<strong>%3$s %%</strong>)" : "您已使用了 <strong>%2$s</strong> 中的 <strong>%1$s</strong>（<strong>%3$s %%</strong>）",
+    "Change privacy level of phone number" : "更改電話號碼的私隱級別",
     "Your phone number" : "您的電話號碼",
-    "Address" : "地址",
+    "Change privacy level of address" : "更改地址的私隱級別",
     "Your postal address" : "您的郵遞地址",
-    "Website" : "網站",
-    "It can take up to 24 hours before the account is displayed as verified." : "該帳戶最多可能需要24小時才能顯示為已驗證。",
-    "Link https://…" : "連結 https://...",
-    "Twitter" : "Twitter",
-    "Twitter handle @…" : "Twitter 使用者名稱 @...",
-    "Help translate" : "協助翻譯",
+    "Change privacy level of website" : "更改網站的私隱級別",
+    "It can take up to 24 hours before the account is displayed as verified." : "該賬戶最多可能需要24小時才能顯示為已驗證。",
+    "Link https://…" : "連結 https://…",
+    "Change privacy level of Twitter profile" : "更改 Twitter proile 的私隱級別",
+    "Twitter handle @…" : "Twitter 用戶名稱 @...",
     "Locale" : "地區設定",
     "Current password" : "目前密碼",
     "New password" : "新密碼",
     "Change password" : "更改密碼",
-    "Use a second factor besides your password to increase security for your account." : "使用密碼以外的第二因素來增強您帳號的安全性。",
-    "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "如果您使用第三方應用程式來連線到 Nextcloud，請確保在啟用雙因素驗證前為每個應用程式設定應用程式密碼。",
-    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "發生錯誤。請您上傳 ASCII 編碼的 PEM 證書。",
-    "Valid until {date}" : "{date} 前有效",
-    "Local" : "本地",
-    "Only visible to local users" : "僅本地用戶可見",
-    "Only visible to you" : "僅對您可見",
-    "Contacts" : "聯絡人",
-    "Visible to local users and to trusted servers" : "僅本地使用者與信任的伺服器可見",
-    "Will be synced to a global and public address book" : "將會同步到全域公開的通訊錄",
-    "by" : "由",
-    "SSL Root Certificates" : "SSL 根憑證",
-    "Common Name" : "通用名",
-    "Valid until" : "到期日",
-    "Issued By" : "發行者：",
-    "Valid until %s" : "有效至 %s",
-    "Import root certificate" : "匯入根憑證",
-    "Execute one task with each page loaded" : "每個頁面載入時執行",
-    "Allow username autocompletion in share dialog. If this is disabled the full username or email address needs to be entered." : "允許使用者名稱自動完成在分享對話框，如果停用這個功能，必須輸入完整的使用者名稱或電子郵件地址。",
-    "Show disclaimer text on the public link upload page. (Only shown when the file list is hidden.)" : "在公開的檔案連結和上傳頁面顯示免責聲明。（只有在檔案清單隱藏的時候才會顯示。）"
+    "Use a second factor besides your password to increase security for your account." : "使用密碼以外的第二因數來增強您賬戶的安全性。",
+    "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "如果您使用第三方應用程式來連線到 Nextcloud，請確保在啟用雙重認證前為每個應用程式設定應用程式密碼。",
+    "Don't synchronize to servers" : "不要同步至伺服器",
+    "Trusted" : "受信任",
+    "Public" : "公開",
+    "installing and updating apps via the app store or Federated Cloud Sharing" : "透過應用程式中心或是聯盟式雲端分享來安裝、更新應用程式",
+    "You need to set your user email before being able to send test emails." : "您必須先設定您的用戶電子郵件，然後才能傳送測試郵件。",
+    "Revoking this token might prevent the wiping of your device if it hasn't started the wipe yet." : "如果還沒開始抹除，則撤銷此權杖可能會導致無法抹除您的裝置。",
+    "Nextcloud iOS app" : "Nextcloud iOS 應用程式",
+    "Nextcloud Android app" : "Nextcloud Android 應用程式",
+    "Nextcloud Talk for iOS" : "iOS 版 Nextcloud Talk",
+    "Nextcloud Talk for Android" : "Android 版 Nextcloud Talk",
+    "Add user in group" : "在群組中新增用戶",
+    "Close" : "關閉",
+    "All languages" : "全部語言",
+    "Everyone" : "所有人",
+    "The app will be downloaded from the app store" : "將會從應用程式商店下載這個應用程式",
+    "Error: This app can not be enabled because it makes the server unstable" : "錯誤：此應用程序無法啟用，因為它造成伺服器不穩定",
+    "mail" : "電郵地址",
+    "Test email settings" : "測試電子郵件設定",
+    "Expire after " : "將在此日期後過期： ",
+    "days" : "天",
+    "Allow users to share via link" : "允許用戶透過連結分享",
+    "Set default expiration date for link shares" : "設定連結分享的預設到期日",
+    "Allow username autocompletion in share dialog (if this is disabled the full username or email address needs to be entered)" : "在分享對話框中允許用戶名稱自動完成（如果停用此選項，則必須輸入完整的用戶名稱或電郵地址）",
+    "Restrict username autocompletion to users within the same groups" : "將使用戶名稱限制為僅相同群組的用戶可使用",
+    "No display name set" : "未設定顯示名稱",
+    "For password reset and notifications" : "用於密碼重設和通告信件",
+    "Change privacy level of full name" : "更改全名的私隱級別",
+    "Change privacy level of email" : "更改電郵地址的私隱級別",
+    "Set as primary mail" : "設為主要電郵地址"
 },
 "nplurals=1; plural=0;");
