@@ -3,6 +3,7 @@ OC.L10N.register(
     {
     "{version} is available. Get more information on how to update." : "{version} está disponível. Obtenha mais informações sobre como atualizar.",
     "Channel updated" : "Canal atualizado",
+    "Web updater is disabled" : "O updater da Web está desativado",
     "Update notifications" : "Notificações de atualização",
     "The update server could not be reached since %d days to check for new updates." : "O servidor de atualização não foi encontrado já há %d dias para verificar por novas atualizações.",
     "Please check the Nextcloud and server log files for errors." : "Verifique se há erros nos arquivos de log do servidor e do Nextcloud ",
@@ -12,11 +13,12 @@ OC.L10N.register(
     "Update notification" : "Notificação de atualização",
     "Displays update notifications for Nextcloud and provides the SSO for the updater." : "Exibe notificações de atualização para o Nextcloud e fornece o SSO para o atualizador.",
     "The version you are running is not maintained anymore. Please make sure to update to a supported version as soon as possible." : "A versão que você está executando não é mais mantida. Por favor, atualize para uma versão suportada o mais rápido possível.",
-    "Apps missing updates" : "Aplicativos faltando atualizações",
+    "Apps missing compatible version" : "Apps sem versão compatível ",
     "View in store" : "Ver na loja",
-    "Apps with available updates" : "Aplicativos com atualizações disponíveis",
+    "Apps with compatible version" : "Apps com versão compatível ",
     "Open updater" : "Abrir atualizador",
     "Download now" : "Baixar agora",
+    "Please use the command line updater to update." : "Por favor, use o updater da linha de comando para atualizar.",
     "What's new?" : "O que há de novo?",
     "The update check is not yet finished. Please refresh the page." : "A verificação de atualização ainda não acabou. Atualize a página.",
     "Your version is up to date." : "Sua versão está atualizada.",
@@ -24,16 +26,16 @@ OC.L10N.register(
     "Update channel:" : "Atualizar para:",
     "You can always update to a newer version. But you can never downgrade to a more stable version." : "Você sempre pode atualizar para uma versão mais recente, mas nunca pode voltar à uma versão mais estável.",
     "Notify members of the following groups about available updates:" : "Notificar membros dos seguintes grupos sobre atualizações disponíveis:",
-    "Only notification for app updates are available." : "Só está disponível notificação para atualizações de aplicativos.",
+    "Only notifications for app updates are available." : "Apenas notificações para atualizações de aplicativos estão disponíveis. ",
     "The selected update channel makes dedicated notifications for the server obsolete." : "A atualização selecionada fornece notificações dedicadas para o servidor desatualizado.",
     "The selected update channel does not support updates of the server." : "A atualização selecionada não fornece suporte a atualizações do servidor.",
     "A new version is available: <strong>{newVersionString}</strong>" : "Uma nova versão está disponível: <strong>{newVersionString}</strong>",
     "Note that after a new release the update only shows up after the first minor release or later. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found. Learn more about updates and release channels at {link}" : "Observe que depois de um novo lançamento, a atualização só aparece após o primeiro lançamento secundário ou posterior. Lançamos novas versões distribuídas ao longo do tempo para nossos usuários e às vezes pulamos uma versão quando problemas são encontrados. Saiba mais sobre atualizações e canais de lançamento em {link}",
     "Checked on {lastCheckedDate}" : "Verificado em {lastCheckedDate}",
-    "Checking apps for compatible updates" : "Verificando atualização dos aplicativos",
+    "Checking apps for compatible versions" : "Verificando aplicativos para versões compatíveis",
     "Please make sure your config.php does not set <samp>appstoreenabled</samp> to false." : "Certifique-se de que seu config.php não tenha configurado <samp>appstoreenabled</samp> para falso.",
-    "Could not connect to the appstore or the appstore returned no updates at all. Search manually for updates or make sure your server has access to the internet and can connect to the appstore." : "Não foi possível conectar a appstore ou não havia atualização. Procure manualmente por atualizações ou verifique se o servidor tem acesso à internet.",
-    "<strong>All</strong> apps have an update for this version available" : "<strong>Todos</strong> os aplicativos tem uma atualização disponível",
+    "Could not connect to the App Store or no updates have been returned at all. Search manually for updates or make sure your server has access to the internet and can connect to the App Store." : "Não foi possível conectar à App Store ou nenhuma atualização foi retornada. Pesquise manualmente por atualizações ou certifique-se de que seu servidor tenha acesso à Internet e possa se conectar à App Store.",
+    "<strong>All</strong> apps have a compatible version for this Nextcloud version available." : "<strong>Todos</strong> os aplicativos têm uma versão compatível para esta versão do Nextcloud disponível.",
     "View changelog" : "Visualizar registro de alterações",
     "Enterprise" : "Empresarial",
     "For enterprise use. Provides always the latest patch level, but will not update to the next major release immediately. That update happens once Nextcloud GmbH has done additional hardening and testing for large-scale and mission-critical deployments. This channel is only available to customers and provides the Nextcloud Enterprise package." : "Para uso empresarial. Fornece sempre o nível de patch mais recente, mas não será atualizado para a próxima versão principal imediatamente. Essa atualização acontece assim que a Nextcloud GmbH fizer mais ajustes e testes para implantações de larga escala e missão crítica. Este canal está disponível apenas para clientes do Nextcloud Enterprise.",
@@ -41,7 +43,16 @@ OC.L10N.register(
     "The most recent stable version. It is suited for regular use and will always update to the latest major version." : "A versão estável mais recente. É adequada para uso regular e será sempre atualizada para a versão principal mais recente.",
     "Beta" : "Beta",
     "A pre-release version only for testing new features, not for production environments." : "Uma versão de pré-lançamento para testar novos recursos, não indicada para produção.",
+    "_<strong>%n</strong> app has no compatible version for this Nextcloud version available._::_<strong>%n</strong> apps have no compatible version for this Nextcloud version available._" : ["<strong>%n</strong> aplicativo não têm versão compatível para esta versão do Nextcloud disponível.","<strong>%n</strong> aplicativos não têm versão compatível para esta versão do Nextcloud disponível."],
+    "Apps missing updates" : "Aplicativos faltando atualizações",
+    "Apps with available updates" : "Aplicativos com atualizações disponíveis",
+    "Note that after a new release it can take some time before it shows up here. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found." : "Observe que uma nova versão pode levar um tempo até aparecer aqui. Lançamos novas versões distribuídas ao longo do tempo para nossos usuários e às vezes pulamos uma versão quando problemas são encontrados.",
+    "Only notification for app updates are available." : "Só está disponível notificação para atualizações de aplicativos.",
+    "Checking apps for compatible updates" : "Verificando atualização dos aplicativos",
+    "Could not connect to the appstore or the appstore returned no updates at all. Search manually for updates or make sure your server has access to the internet and can connect to the appstore." : "Não foi possível conectar a appstore ou não havia atualização. Procure manualmente por atualizações ou verifique se o servidor tem acesso à internet.",
+    "<strong>All</strong> apps have an update for this version available" : "<strong>Todos</strong> os aplicativos tem uma atualização disponível",
     "_<strong>%n</strong> app has no update for this version available_::_<strong>%n</strong> apps have no update for this version available_" : ["<strong>%n</strong> aplicativo não tem atualização disponível","<strong>%n</strong> aplicativos tem uma atualização disponível"],
-    "Note that after a new release it can take some time before it shows up here. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found." : "Observe que uma nova versão pode levar um tempo até aparecer aqui. Lançamos novas versões distribuídas ao longo do tempo para nossos usuários e às vezes pulamos uma versão quando problemas são encontrados."
+    "<strong>All</strong> apps have a compatible version for this Nextcloud version available" : "<strong>Todos</strong> os aplicativos têm uma versão compatível para esta versão Nextcloud disponível",
+    "_<strong>%n</strong> app has no compatible version for this Nextcloud version available_::_<strong>%n</strong> apps have no compatible version for this Nextcloud version available_" : ["<strong>%n</strong> aplicativo não têm versão compatível para esta versão Nextcloud disponível ","<strong>%n</strong> aplicativos não têm versão compatível para esta versão Nextcloud disponível"]
 },
 "nplurals=2; plural=(n > 1);");
