@@ -180,6 +180,8 @@ OC.L10N.register(
     "Login form is disabled." : "ログインフォームは無効です。",
     "Edit Profile" : "プロフィールを編集",
     "The headline and about sections will show up here" : "見出しと概要セクションがここに表示されます",
+    "You have not added any info yet" : "まだ情報が追加されていません",
+    "{user} has not added any info yet" : "{user}が、まだ情報を追加していません",
     "Error opening the user status modal, try hard refreshing the page" : "ユーザーステータスモーダルを開くときにエラーが発生しました。ページを更新してみてください",
     "Reset search" : "検索をリセットする",
     "Search for {name} only" : "{name}のみを検索",
@@ -315,6 +317,8 @@ OC.L10N.register(
     "You chose SQLite as database." : "あなたはSQLiteをデータベースとして選択しました。",
     "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLiteは小規模もしくは開発用のインスタンスでのみ利用できます。プロダクション環境では他のデータベースをお勧めします。",
     "If you use clients for file syncing, the use of SQLite is highly discouraged." : "ファイルの同期にクライアントを使用している場合、SQLiteの使用はお勧めできません。",
+    "Install" : "インストール",
+    "Installing …" : "インストールしています…",
     "Need help?" : "ヘルプが必要ですか？",
     "See the documentation" : "ドキュメントを確認してください",
     "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Nextcloudを再インストールしようとしているようです。 しかし、CAN_INSTALLファイルがconfigディレクトリにありません。 続行するには、configフォルダーにCAN_INSTALLファイルを作成してください。",
