@@ -2,14 +2,17 @@ OC.L10N.register(
     "lib",
     {
     "Cannot write into \"config\" directory!" : "Impossibile scrivere nella cartella \"config\"!",
-    "This can usually be fixed by giving the webserver write access to the config directory" : "Ciò può essere normalmente corretto fornendo al server web accesso in scrittura alla cartella \"config\"",
-    "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "O, se preferisci mantenere il file config.php in sola lettura, imposta l'opzione \"config_is_read_only\" a true.",
+    "This can usually be fixed by giving the web server write access to the config directory." : "Ciò può essere corretto di solito fornendo al server web accesso in scrittura alla cartella config.",
+    "But, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "Ma, se preferisci mantenere il file config.php in sola lettura, imposta l'opzione \"config_is_read_only\" a true.",
     "See %s" : "Vedi %s",
-    "This can usually be fixed by giving the webserver write access to the config directory." : "Ciò può essere normalmente corretto fornendo al server web accesso in scrittura alla cartella \"config\".",
-    "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "O, se preferisci mantenere il file config.php in sola lettura, imposta l'opzione \"config_is_read_only\" a true. Vedi %s",
     "The files of the app %1$s were not replaced correctly. Make sure it is a version compatible with the server." : "I file dell'applicazione %1$s non sono stati sostituiti correttamente. Assicurati che sia una versione compatibile con il server.",
     "Sample configuration detected" : "Configurazione di esempio rilevata",
     "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "È stato rilevato che la configurazione di esempio è stata copiata. Ciò può compromettere la tua installazione e non è supportato. Leggi la documentazione prima di modificare il file config.php",
+    "%s email verification" : "Verifica email di %s",
+    "Email verification" : "Verifica email",
+    "Click the following button to confirm your email." : "Clicca il pulsante seguente per confermare la tua email.",
+    "Click the following link to confirm your email." : "Clicca il collegamento seguente per confermare la tua email.",
+    "Confirm your email" : "Conferma la tua email",
     "Other activities" : "Altre attività",
     "%1$s and %2$s" : "%1$s e %2$s",
     "%1$s, %2$s and %3$s" : "%1$s, %2$s e %3$s",
@@ -32,6 +35,7 @@ OC.L10N.register(
     "The following platforms are supported: %s" : "Le seguenti piattaforme sono supportate: %s",
     "Server version %s or higher is required." : "È richiesta la versione %s o successiva.",
     "Server version %s or lower is required." : "È richiesta la versione %s o precedente.",
+    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "L'utente connesso deve essere un admin, un sub admin o avere il permesso di accedere a questa impostazione",
     "Logged in user must be an admin or sub admin" : "L'utente che ha eseguito l'accesso deve essere un amministratore o sub-amministratore",
     "Logged in user must be an admin" : "L'utente che ha eseguito l'accesso deve essere un amministratore ",
     "Wiping of device %s has started" : "La cancellazione del dispositivo %s è iniziata",
@@ -50,6 +54,7 @@ OC.L10N.register(
     "Unknown filetype" : "Tipo di file sconosciuto",
     "Invalid image" : "Immagine non valida",
     "Avatar image is not square" : "L'immagine personale non è quadrata",
+    "View profile" : "Vedi profilo",
     "today" : "oggi",
     "tomorrow" : "domani",
     "yesterday" : "ieri",
@@ -72,6 +77,7 @@ OC.L10N.register(
     "Empty file" : "File vuoto",
     "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Il modulo con ID: %s non esiste. Abilitalo nelle impostazioni delle applicazioni o contatta il tuo amministratore.",
     "File already exists" : "Il file esiste già",
+    "Invalid path" : "Percorso non valido",
     "Failed to create file from template" : "Impossibile creare un file dal modello",
     "Templates" : "Modelli",
     "File name is a reserved word" : "Il nome del file è una parola riservata",
@@ -88,6 +94,21 @@ OC.L10N.register(
     "Settings" : "Impostazioni",
     "Log out" : "Esci",
     "Users" : "Utenti",
+    "Email" : "Email",
+    "Mail %s" : "Email a %s",
+    "Phone" : "Telefono",
+    "Call %s" : "Chiama %s",
+    "Twitter" : "Twitter",
+    "View %s on Twitter" : "Vedi %s su Twitter",
+    "Website" : "Sito web",
+    "Visit %s" : "Visita %s",
+    "Address" : "Indirizzo",
+    "Profile picture" : "Immagine di profilo",
+    "About" : "Informazioni",
+    "Full name" : "Nome completo",
+    "Headline" : "Titolo",
+    "Organisation" : "Organizzazione",
+    "Role" : "Ruolo",
     "Unknown user" : "Utente sconosciuto",
     "Additional settings" : "Impostazioni aggiuntive",
     "%s enter the database username and name." : "%s digita il nome utente e il nome del database.",
@@ -105,7 +126,7 @@ OC.L10N.register(
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Rimuovi l'impostazione di open_basedir nel tuo php.ini o passa alla versione a 64 bit di PHP.",
     "Set an admin username." : "Imposta un nome utente di amministrazione.",
     "Set an admin password." : "Imposta una password di amministrazione.",
-    "Can't create or write into the data directory %s" : "Impossibile creare o scrivere nella cartella dei dati %s",
+    "Cannot create or write into the data directory %s" : "Impossibile creare o scrivere nella cartella dei dati %s",
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Il motore di condivisione %s deve implementare l'interfaccia OCP\\Share_Backend",
     "Sharing backend %s not found" : "Motore di condivisione %s non trovato",
     "Sharing backend for %s not found" : "Motore di condivisione di %s non trovato",
@@ -115,11 +136,13 @@ OC.L10N.register(
     "Open »%s«" : "Apri «%s»",
     "%1$s via %2$s" : "%1$s tramite %2$s",
     "You are not allowed to share %s" : "Non ti è consentito condividere %s",
-    "Can’t increase permissions of %s" : "Impossibile aumentare i permessi di %s",
-    "Files can’t be shared with delete permissions" : "I file non possono essere condivisi con permessi di eliminazione",
-    "Files can’t be shared with create permissions" : "I file non possono essere condivisi con permessi di creazione",
+    "Cannot increase permissions of %s" : "Impossibile aumentare i permessi di %s",
+    "Files cannot be shared with delete permissions" : "I file non possono essere condivisi con permessi di eliminazione",
+    "Files cannot be shared with create permissions" : "I file non possono essere condivisi con permessi di creazione",
     "Expiration date is in the past" : "La data di scadenza è nel passato",
-    "Can’t set expiration date more than %s days in the future" : "Impossibile impostare la data di scadenza a più di %s giorni nel futuro",
+    "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["Impossibile impostare la data di scadenza a più di %n giorni nel futuro","Impossibile impostare la data di scadenza a più di %n giorni nel futuro"],
+    "Sharing is only allowed with group members" : "La condivisione è consentita solo con i membri del gruppo",
+    "Sharing %s failed, because this item is already shared with user %s" : "Condivisione di %s non riuscita, poiché l'oggetto è già condiviso con l'utente %s",
     "%1$s shared »%2$s« with you" : "%1$s ha condiviso «%2$s» con te",
     "%1$s shared »%2$s« with you." : "%1$s ha condiviso «%2$s» con te.",
     "Click the button below to open it." : "Fai clic sul pulsante sotto per aprirlo.",
@@ -184,39 +207,41 @@ OC.L10N.register(
     "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "L'applicazione \"%1$s\" non può essere installata poiché le seguenti dipendenze non sono soddisfatte: %2$s",
     "a safe home for all your data" : "un posto sicuro per tutti i tuoi dati",
     "File is currently busy, please try again later" : "Il file è attualmente occupato, riprova più tardi",
-    "Can't read file" : "Impossibile leggere il file",
+    "Cannot read file" : "Impossibile leggere il file",
     "Application is not enabled" : "L'applicazione  non è abilitata",
     "Authentication error" : "Errore di autenticazione",
     "Token expired. Please reload page." : "Token scaduto. Ricarica la pagina.",
     "No database drivers (sqlite, mysql, or postgresql) installed." : "Nessun driver di database (sqlite, mysql o postgresql) installato",
-    "Cannot write into \"config\" directory" : "Impossibile scrivere nella cartella \"config\"",
-    "This can usually be fixed by giving the webserver write access to the config directory. See %s" : "Ciò può essere normalmente corretto fornendo al server web accesso in scrittura alla cartella di configurazione. Vedi %s",
-    "Cannot write into \"apps\" directory" : "Impossibile scrivere nella cartella \"apps\"",
-    "This can usually be fixed by giving the webserver write access to the apps directory or disabling the appstore in the config file." : "Questo può essere normalmente corretto fornendo al server web accesso in scrittura alla cartella \"apps\" o disabilitando il negozio di applicazioni nel file di configurazione.",
-    "Cannot create \"data\" directory" : "Impossibile creare la cartella \"data\"",
-    "This can usually be fixed by giving the webserver write access to the root directory. See %s" : "Ciò può essere normalmente corretto fornendo al server web accesso in scrittura alla cartella radice. Vedi %s",
-    "Permissions can usually be fixed by giving the webserver write access to the root directory. See %s." : "I permessi possono essere normalmente corretti fornendo al server web accesso in scrittura alla cartella radice. Vedi %s.",
-    "Setting locale to %s failed" : "L'impostazione della localizzazione a %s non è riuscita",
-    "Please install one of these locales on your system and restart your webserver." : "Installa una delle seguenti localizzazioni sul tuo sistema e riavvia il server web.",
+    "Cannot write into \"config\" directory." : "Impossibile scrivere nella cartella \"config\".",
+    "This can usually be fixed by giving the web server write access to the config directory. See %s" : "Ciò può essere corretto di solito fornendo al server web accesso in scrittura alla cartella config. Vedi %s",
+    "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "O, se preferisci mantenere il file config.php in sola lettura, imposta l'opzione \"config_is_read_only\" a true. Vedi %s",
+    "Cannot write into \"apps\" directory." : "Impossibile scrivere nella cartella \"apps\".",
+    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Ciò può essere corretto di solito fornendo al server web accesso in scrittura alla cartella apps o disattivando il negozio delle applicazioni nel file di configurazione.",
+    "Cannot create \"data\" directory." : "Impossibile creare la cartella \"data\".",
+    "This can usually be fixed by giving the web server write access to the root directory. See %s" : "Ciò può essere corretto di solito fornendo al server web accesso in scrittura alla cartella radice. Vedi %s",
+    "Permissions can usually be fixed by giving the web server write access to the root directory. See %s." : "I permessi possono essere corretti di solito fornendo al server web accesso in scrittura alla cartella radice. Vedi %s.",
+    "Your data directory is not writable." : "La cartella dei dati non è scrivibile.",
+    "Setting locale to %s failed." : "L'impostazione della lingua in %s è fallita.",
+    "Please install one of these locales on your system and restart your web server." : "Installa una di queste lingue sul sistema e riavvia il server web.",
     "PHP module %s not installed." : "Il modulo PHP %s non è installato.",
     "Please ask your server administrator to install the module." : "Chiedi all'amministratore del tuo server di installare il modulo.",
     "PHP setting \"%s\" is not set to \"%s\"." : "L'impostazione \"%s\" di PHP non è configurata a \"%s\".",
     "Adjusting this setting in php.ini will make Nextcloud run again" : "Per eseguire nuovamente Nextcloud, modificare questa impostazione nel file php.ini",
-    "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload è impostata a \"%s\" invece del valore atteso \"0\"",
-    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "Per correggere questo problema, imposta <code>mbstring.func_overload</code> a <code>0</code> nel tuo php.ini",
+    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code> è impostato a <code>%s</code> invece del valore previsto <code>0</code>.",
+    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "Per correggere questo problema, imposta <code>mbstring.func_overload</code> a <code>0</code> nel tuo php.ini.",
     "libxml2 2.7.0 is at least required. Currently %s is installed." : "È richiesta almeno la versione 2.7.0 di libxml2. Quella attualmente installata è la %s.",
     "To fix this issue update your libxml2 version and restart your web server." : "Per risolvere questo problema, aggiorna la tua versione di libxml2 e riavvia il server web.",
     "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "Sembra che PHP sia configurato per rimuovere i blocchi di documentazione in linea. Ciò renderà inaccessibili diverse applicazioni principali.",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Ciò è causato probabilmente da una cache/acceleratore come Zend OPcache o eAccelerator.",
     "PHP modules have been installed, but they are still listed as missing?" : "Sono stati installati moduli PHP, ma sono elencati ancora come mancanti?",
     "Please ask your server administrator to restart the web server." : "Chiedi all'amministratore di riavviare il server web.",
-    "PostgreSQL >= 9 required" : "Richiesto PostgreSQL >= 9",
-    "Please upgrade your database version" : "Aggiorna la versione del tuo database",
-    "Your data directory is readable by other users" : "La cartella dei dati è leggibile dagli altri utenti",
+    "PostgreSQL >= 9 required." : "Richiesto PostgreSQL >= 9.",
+    "Please upgrade your database version." : "Aggiorna la versione del tuo database.",
+    "Your data directory is readable by other users." : "La cartella dei dati è leggibile dagli altri utenti.",
     "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Modifica i permessi in 0770 in modo tale che la cartella non sia leggibile dagli altri utenti.",
-    "Your data directory must be an absolute path" : "La cartella dei dati deve essere un percorso assoluto",
-    "Check the value of \"datadirectory\" in your configuration" : "Controlla il valore di \"datadirectory\" nella tua configurazione",
-    "Your data directory is invalid" : "La cartella dei dati non è valida",
+    "Your data directory must be an absolute path." : "La cartella dei dati deve essere un percorso assoluto.",
+    "Check the value of \"datadirectory\" in your configuration." : "Controlla il valore di \"datadirectory\" nella tua configurazione.",
+    "Your data directory is invalid." : "La cartella dei dati non è valida.",
     "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Assicurati che ci sia un file \".ocdata\" nella radice della cartella data.",
     "Action \"%s\" not supported or implemented." : "Azione \"%s\" non supportata o implementata.",
     "Authentication failed, wrong token or provider ID given" : "Autenticazione non riuscita, token o ID fornitore errato ",
@@ -229,8 +254,33 @@ OC.L10N.register(
     "Storage connection error. %s" : "Errore di connessione all'archiviazione. %s",
     "Storage is temporarily not available" : "L'archiviazione è temporaneamente non disponibile",
     "Storage connection timeout. %s" : "Timeout di connessione all'archiviazione. %s",
-    "Following databases are supported: %s" : "I seguenti database sono supportati: %s",
-    "Following platforms are supported: %s" : "Sono supportate le seguenti piattaforme: %s",
-    "Invalid Federated Cloud ID" : "ID di cloud federata non valido"
+    "This can usually be fixed by giving the webserver write access to the config directory" : "Ciò può essere normalmente corretto fornendo al server web accesso in scrittura alla cartella \"config\"",
+    "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "O, se preferisci mantenere il file config.php in sola lettura, imposta l'opzione \"config_is_read_only\" a true.",
+    "This can usually be fixed by giving the webserver write access to the config directory." : "Ciò può essere normalmente corretto fornendo al server web accesso in scrittura alla cartella \"config\".",
+    "Can't create or write into the data directory %s" : "Impossibile creare o scrivere nella cartella dei dati %s",
+    "Invalid Federated Cloud ID" : "ID di cloud federata non valido",
+    "Can’t increase permissions of %s" : "Impossibile aumentare i permessi di %s",
+    "Files can’t be shared with delete permissions" : "I file non possono essere condivisi con permessi di eliminazione",
+    "Files can’t be shared with create permissions" : "I file non possono essere condivisi con permessi di creazione",
+    "Can’t set expiration date more than %s days in the future" : "Impossibile impostare la data di scadenza a più di %s giorni nel futuro",
+    "Can't read file" : "Impossibile leggere il file",
+    "Cannot write into \"config\" directory" : "Impossibile scrivere nella cartella \"config\"",
+    "This can usually be fixed by giving the webserver write access to the config directory. See %s" : "Ciò può essere normalmente corretto fornendo al server web accesso in scrittura alla cartella di configurazione. Vedi %s",
+    "Cannot write into \"apps\" directory" : "Impossibile scrivere nella cartella \"apps\"",
+    "This can usually be fixed by giving the webserver write access to the apps directory or disabling the appstore in the config file." : "Questo può essere normalmente corretto fornendo al server web accesso in scrittura alla cartella \"apps\" o disabilitando il negozio delle applicazioni nel file di configurazione.",
+    "Cannot create \"data\" directory" : "Impossibile creare la cartella \"data\"",
+    "This can usually be fixed by giving the webserver write access to the root directory. See %s" : "Ciò può essere normalmente corretto fornendo al server web accesso in scrittura alla cartella radice. Vedi %s",
+    "Permissions can usually be fixed by giving the webserver write access to the root directory. See %s." : "I permessi possono essere normalmente corretti fornendo al server web accesso in scrittura alla cartella radice. Vedi %s.",
+    "Setting locale to %s failed" : "L'impostazione della localizzazione a %s non è riuscita",
+    "Please install one of these locales on your system and restart your webserver." : "Installa una delle seguenti localizzazioni sul tuo sistema e riavvia il server web.",
+    "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload è impostata a \"%s\" invece del valore atteso \"0\"",
+    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "Per correggere questo problema, imposta <code>mbstring.func_overload</code> a <code>0</code> nel tuo php.ini",
+    "PostgreSQL >= 9 required" : "Richiesto PostgreSQL >= 9",
+    "Please upgrade your database version" : "Aggiorna la versione del tuo database",
+    "Your data directory is readable by other users" : "La cartella dei dati è leggibile dagli altri utenti",
+    "Your data directory must be an absolute path" : "La cartella dei dati deve essere un percorso assoluto",
+    "Check the value of \"datadirectory\" in your configuration" : "Controlla il valore di \"datadirectory\" nella tua configurazione",
+    "Your data directory is invalid" : "La cartella dei dati non è valida",
+    "This can usually be fixed by giving the webserver write access to the apps directory or disabling the App Store in the config file." : "Questo può essere normalmente corretto fornendo al server web accesso in scrittura alla cartella \"apps\" o disabilitando il negozio delle applicazioni nel file di configurazione."
 },
 "nplurals=2; plural=(n != 1);");
