@@ -2,14 +2,18 @@ OC.L10N.register(
     "lib",
     {
     "Cannot write into \"config\" directory!" : "Não é possível gravar no diretório \"config\"!",
-    "This can usually be fixed by giving the webserver write access to the config directory" : "Isso geralmente pode ser corrigido dando o acesso de escritura ao webserver para o diretório de configuração",
+    "This can usually be fixed by giving the web server write access to the config directory." : "Isso geralmente pode ser corrigido dando ao servidor web acesso de gravação ao diretório de configuração.",
+    "But, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "Mas, se você preferir manter o arquivo config.php somente para leitura, defina a opção \"config_is_read_only\" como true nele. ",
     "See %s" : "Ver %s",
-    "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "Ou, se você preferir manter o arquivo config.php somente para leitura, defina a opção \"config_is_read_only\" como true.",
-    "This can usually be fixed by giving the webserver write access to the config directory. See %s" : "Normalmente isso pode ser resolvido dando ao webserver permissão de escritura no diretório config. Veja %s",
-    "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "Ou, se você preferir manter o arquivo config.php somente para leitura, defina a opção \"config_is_read_only\" como true. Veja %s",
-    "The files of the app %$1s were not replaced correctly. Make sure it is a version compatible with the server." : "Os arquivos do aplicativo %$1s não foram substituídos corretamente. Certifique-se de que é uma versão compatível com o servidor.",
+    "The files of the app %1$s were not replaced correctly. Make sure it is a version compatible with the server." : "Os arquivos do aplicativo %1$s não foram instalados corretamente. Certifique-se que é uma versão compatível com seu servidor.",
     "Sample configuration detected" : "Configuração de exemplo detectada",
     "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Foi detectado que a configuração de exemplo foi copiada. Isso pode terminar sua instalação e não é suportado. Por favor leia a documentação antes de realizar mudanças no config.php",
+    "%s email verification" : "%s e-mail de verificação",
+    "Email verification" : "E-mail de verificação",
+    "Click the following button to confirm your email." : "Clique no botão a seguir para confirmar seu e-mail.",
+    "Click the following link to confirm your email." : "Clique no link a seguir para confirmar seu e-mail.",
+    "Confirm your email" : "Confirme seu e-mail",
+    "Other activities" : "Outras atividades",
     "%1$s and %2$s" : "%1$s e %2$s",
     "%1$s, %2$s and %3$s" : "%1$s, %2$s e %3$s",
     "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s e %4$s",
@@ -17,22 +21,40 @@ OC.L10N.register(
     "Education Edition" : "Edição Educativa",
     "Enterprise bundle" : "Pacote Enterprise",
     "Groupware bundle" : "Pacote Groupware",
+    "Hub bundle" : "Pacote de hub",
     "Social sharing bundle" : "Pacote de compartilhamento social",
-    "PHP %s or higher is required." : "PHP %s ou superior é requerido.",
-    "PHP with a version lower than %s is required." : "É requerida uma versão PHP mais antiga que a %s .",
+    "PHP %s or higher is required." : "PHP %s ou superior é necessário.",
+    "PHP with a version lower than %s is required." : "É necessária uma versão PHP mais antiga que a %s.",
     "%sbit or higher PHP required." : "%sbit ou PHP maior é requerido.",
-    "Following databases are supported: %s" : "Os seguintes bancos de dados são suportados: %s",
+    "The following architectures are supported: %s" : "As seguintes plataformas são suportadas: %s",
+    "The following databases are supported: %s" : "Os seguintes bancos de dados são suportados: %s",
     "The command line tool %s could not be found" : "A ferramenta de linha de comando %s não pôde ser encontrada",
     "The library %s is not available." : "A biblioteca %s não está disponível.",
     "Library %1$s with a version higher than %2$s is required - available version %3$s." : "Uma biblioteca %1$s com uma versão maior que %2$s é requerida - versão disponível %3$s.",
     "Library %1$s with a version lower than %2$s is required - available version %3$s." : "Uma biblioteca %1$s com uma versão abaixo de%2$s é requerida - versão disponível %3$s.",
-    "Following platforms are supported: %s" : "As seguintes plataformas são suportadas: %s",
+    "The following platforms are supported: %s" : "As seguintes plataformas são suportadas: %s",
     "Server version %s or higher is required." : "É requerido um servidor da versão %s ou superior.",
     "Server version %s or lower is required." : "É requerido um servidor da versão %s ou abaixo.",
+    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "O usuário conectado deve ser um administrador, um subadministrador ou ter direito especial para acessar esta configuração",
+    "Logged in user must be an admin or sub admin" : "O usuário conectado deve ser um administrador ou subadministrador",
     "Logged in user must be an admin" : "O usuário conectado deve ser um administrador",
+    "Wiping of device %s has started" : "Limpeza do dispositivo %s iniciou",
+    "Wiping of device »%s« has started" : "A limpeza do dispositivo »%s« terminou",
+    "»%s« started remote wipe" : "»%s« iniciou a limpeza remota",
+    "Device or application »%s« has started the remote wipe process. You will receive another email once the process has finished" : "O dispositivo ou aplicativo »%s« iniciou o processo de limpeza remota. Você receberá outro e-mail assim que terminar",
+    "Wiping of device %s has finished" : "Limpeza do dispositivo %s terminou",
+    "Wiping of device »%s« has finished" : "Limpeza do dispositivo »%s« terminou",
+    "»%s« finished remote wipe" : "»%s« terminou a limpeza remota",
+    "Device or application »%s« has finished the remote wipe process." : "O dispositivo ou aplicativo »%s« terminou o processo de limpeza remota.",
+    "Remote wipe started" : "Limpeza remota iniciada",
+    "A remote wipe was started on device %s" : "Uma limpeza remota iniciou no dispositivo %s",
+    "Remote wipe finished" : "Limpeza remota terminada",
+    "The remote wipe on %s has finished" : "A limpeza remota em %s terminou",
+    "Authentication" : "Autenticação",
     "Unknown filetype" : "Tipo de arquivo desconhecido",
     "Invalid image" : "Imagem inválida",
     "Avatar image is not square" : "A imagem do avatar não é quadrada",
+    "View profile" : "Visualizar perfil",
     "today" : "hoje",
     "tomorrow" : "amanhã",
     "yesterday" : "ontem",
@@ -41,18 +63,23 @@ OC.L10N.register(
     "next month" : "Mês que vem",
     "last month" : "último mês",
     "_in %n month_::_in %n months_" : ["em %n mês","em %n meses"],
-    "_%n month ago_::_%n months ago_" : ["há %n mês atrás","há %n meses atrás"],
+    "_%n month ago_::_%n months ago_" : ["há %n mês atrás","há %n meses"],
     "next year" : "ano que vem",
     "last year" : "último ano",
     "_in %n year_::_in %n years_" : ["em %n ano","em %n anos"],
     "_%n year ago_::_%n years ago_" : ["%n ano atrás","%n anos atrás"],
     "_in %n hour_::_in %n hours_" : ["em %n hora","em %n horas"],
-    "_%n hour ago_::_%n hours ago_" : ["há %n hora atrás","há %n horas atrás"],
+    "_%n hour ago_::_%n hours ago_" : ["há %n hora atrás","há %n horas"],
     "_in %n minute_::_in %n minutes_" : ["em %n minuto","em %n minutos"],
-    "_%n minute ago_::_%n minutes ago_" : ["há %n minuto atrás","há %n minutos atrás"],
+    "_%n minute ago_::_%n minutes ago_" : ["há %n minuto atrás","há %n minutos"],
     "in a few seconds" : "Em alguns segundos",
     "seconds ago" : "segundos atrás",
+    "Empty file" : "Arquivo vazio",
     "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "O módulo com a ID: %s não existe. Por favor, habilite-o nas configurações de seu aplicativo ou contacte o administrador.",
+    "File already exists" : "O arquivo já existe",
+    "Invalid path" : "Diretório inválido",
+    "Failed to create file from template" : "Falha ao criar arquivo do modelo ",
+    "Templates" : "Modelos ",
     "File name is a reserved word" : "O nome do arquivo é uma palavra reservada",
     "File name contains at least one invalid character" : "O nome do arquivo contém pelo menos um caracter inválido",
     "File name is too long" : "O nome do arquivo é muito longo",
@@ -61,80 +88,61 @@ OC.L10N.register(
     "App \"%s\" cannot be installed because appinfo file cannot be read." : "O aplicativo \"%s\" não pode ser instalado pois o arquivo appinfo não pôde ser lido.",
     "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "O aplicativo \"%s\" não pode ser instalado pois não é compatível com a versão do servidor.",
     "__language_name__" : "Português Brasileiro",
-    "This is an automatically sent email, please do not reply." : "Este é um e-mail enviado automaticamente. Por favor, não responda.",
+    "This is an automatically sent email, please do not reply." : "Este e-mail é enviado automaticamente. Por favor, não responda.",
     "Help" : "Ajuda",
     "Apps" : "Aplicativos",
     "Settings" : "Configurações",
     "Log out" : "Sair",
     "Users" : "Usuários",
+    "Email" : "E-mail",
+    "Mail %s" : "E-Mail %s",
+    "Phone" : "Fone",
+    "Call %s" : "Chamar %s",
+    "Twitter" : "Twitter",
+    "View %s on Twitter" : "Visualizar %s no Twitter",
+    "Website" : "Website",
+    "Visit %s" : "Visitar %s",
+    "Address" : "Endereço",
+    "Profile picture" : "Foto do perfil",
+    "About" : "Sobre",
+    "Full name" : "Nome completo ",
+    "Headline" : "Título ",
+    "Organisation" : "Organização",
+    "Role" : "Função",
     "Unknown user" : "Usuário desconhecido",
-    "Create" : "Criar",
-    "Change" : "Mudar",
-    "Delete" : "Excluir",
-    "Share" : "Compartilhar",
-    "Overview" : "Visão Geral",
-    "Basic settings" : "Configurações básicas",
-    "Sharing" : "Compartilhamento",
-    "Security" : "Segurança",
-    "Groupware" : "Groupware",
     "Additional settings" : "Configurações adicionais",
-    "Personal info" : "Informação Pessoal",
-    "Mobile & desktop" : "Móvel & desktop",
-    "Unlimited" : "Ilimitado",
-    "Verifying" : "Verificando",
-    "Verifying …" : "Verificando...",
-    "Verify" : "Verificar",
     "%s enter the database username and name." : "%s insira o nome de usuário e o nome do banco de dados.",
     "%s enter the database username." : "%s insira o nome de usuário do banco de dados.",
     "%s enter the database name." : "%s insira o nome do banco de dados.",
     "%s you may not use dots in the database name" : "%s você não pode usar pontos no nome do banco de dados",
+    "MySQL username and/or password not valid" : "Nome de usuário e/ou senha do MySQL inválidos",
+    "You need to enter details of an existing account." : "Você necessita entrar detalhes de uma conta existente.",
     "Oracle connection could not be established" : "Conexão Oracle não pôde ser estabelecida",
     "Oracle username and/or password not valid" : "Nome de usuário e/ou senha Oracle inválidos",
     "PostgreSQL username and/or password not valid" : "Nome de usuário e/ou senha PostgreSQL inválidos",
-    "You need to enter details of an existing account." : "Você necessita entrar detalhes de uma conta existente.",
     "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X não é suportado e %s não funcionará corretamente nesta plataforma. Use-o por sua conta e risco!",
     "For the best results, please consider using a GNU/Linux server instead." : "Para obter melhores resultados, por favor considere o uso de um servidor GNU/Linux em seu lugar.",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Aparentemente a instância %s está rodando em um ambiente PHP de 32 bits e o open_basedir foi configurado no php.ini. Isto pode gerar problemas com arquivos maiores que 4GB e é altamente não recomendável.",
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Por favor, remova a configuração de open_basedir de seu php.ini ou mude o PHP para 64bit.",
     "Set an admin username." : "Defina um nome do usuário administrador.",
     "Set an admin password." : "Defina uma senha para o administrador.",
-    "Can't create or write into the data directory %s" : "Não foi possível criar ou gravar no diretório de dados %s",
-    "Invalid Federated Cloud ID" : "ID inválida de Nuvem Federada",
-    "Sharing %s failed, because the backend does not allow shares from type %i" : "O compartilhamento %s falhou pois a plataforma de serviço não permite ações de tipo %i",
-    "Sharing %s failed, because the file does not exist" : "Compartilhamento %s falhou pois o arquivo não existe",
-    "You are not allowed to share %s" : "Você não tem permissão para compartilhar %s",
-    "Sharing %s failed, because you can not share with yourself" : "O compartilhamento %s falhou pois você não pode compartilhar com você mesmo",
-    "Sharing %1$s failed, because the user %2$s does not exist" : "O compartilhamento %1$s falhou, porque o usuário %2$s não existe",
-    "Sharing %1$s failed, because the user %2$s is not a member of any groups that %3$s is a member of" : "O compartilhamento %1$s falhou, porque o usuário %2$s não é membro de nenhum grupo que %3$s é",
-    "Sharing %1$s failed, because this item is already shared with %2$s" : "O compartilhamento %1$s falhou, porque o item já está compartilhado com %2$s",
-    "Sharing %1$s failed, because this item is already shared with user %2$s" : "O compartilhamento %1$s falhou, porque este item já está compartilhando com o usuário %2$s",
-    "Sharing %1$s failed, because the group %2$s does not exist" : "O compartilhamento %1$s falhou, porque o grupo %2$s não existe",
-    "Sharing %1$s failed, because %2$s is not a member of the group %3$s" : "O compartilhamento %1$s falhou, porque %2$s não é membro do grupo %3$s",
-    "You need to provide a password to create a public link, only protected links are allowed" : "Você precisa fornecer uma senha para criar um link público, apenas links protegidos são permitidos",
-    "Sharing %s failed, because sharing with links is not allowed" : "O compartilhamento %s falhou pois compartilhamento com links não é permitido",
-    "Not allowed to create a federated share with the same user" : "Não é permitido criar um compartilhamento associado com o mesmo usuário",
-    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable." : "O compartilhamento%1$s falhou, não pude encontrar %2$s, talvez o servidor esteja inacessível.",
-    "Share type %1$s is not valid for %2$s" : "O tipo de compartilhamento %1$s é inválido para %2$s",
-    "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "Não foi possível definir a data de expiração. Os compartilhamentos não podem expirar mais tarde que %s depois de terem sido compartilhados",
-    "Cannot set expiration date. Expiration date is in the past" : "Não foi possível definir a data de expiração pois ela está no passado",
+    "Cannot create or write into the data directory %s" : "Não foi possível criar ou escrever no diretório de dados %s",
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "A plataforma de compartilhamento %s deve implementar a interface OCP\\Share_Backend",
     "Sharing backend %s not found" : "Plataforma de serviço de compartilhamento %s não encontrada",
     "Sharing backend for %s not found" : "Plataforma  de compartilhamento para %s não foi encontrada",
-    "Sharing failed, because the user %s is the original sharer" : "O compartilhamento falhou pois o usuário %s é o compartilhador original",
-    "Sharing %1$s failed, because the permissions exceed permissions granted to %2$s" : "O compartilhamento %1$s falhou, porque as permissões excedem aquelas concedidas à %2$s",
-    "Sharing %s failed, because resharing is not allowed" : "O compartilhamento %s falhou pois recompartilhamentos não são permitidos",
-    "Sharing %1$s failed, because the sharing backend for %2$s could not find its source" : "O compartilhamento %1$s falhou, Talvez a infraestrutura de compartilhamento para %2$s não pode encontrar sua fonte",
-    "Sharing %s failed, because the file could not be found in the file cache" : "O compartilhamento %s falhou pois o arquivo não pôde ser encontrado no cache de arquivos",
     "%1$s shared »%2$s« with you and wants to add:" : "%1$s compartilhou »%2$s« com você e quer adicionar:",
     "%1$s shared »%2$s« with you and wants to add" : "%1$s compartilhou »%2$s« com você e quer adicionar",
     "»%s« added a note to a file shared with you" : "»%s« adicionou uma anotação num arquivo compartilhado com você",
     "Open »%s«" : "Abrir »%s«",
     "%1$s via %2$s" : "%1$s via %2$s",
-    "Can’t increase permissions of %s" : "Não posso aumentar as permissões de %s",
-    "Files can’t be shared with delete permissions" : "Os arquivos não podem ser compartilhados com permissões de exclusão",
-    "Files can’t be shared with create permissions" : "Os arquivos não podem ser compartilhados com permissões de criação",
+    "You are not allowed to share %s" : "Você não tem permissão para compartilhar %s",
+    "Cannot increase permissions of %s" : "Não foi possível aumentar as permissões de %s",
+    "Files cannot be shared with delete permissions" : "Arquivos não podem ser compartilhados com permissões de exclusão",
+    "Files cannot be shared with create permissions" : "Arquivos não podem ser compartilhados com permissões de criação",
     "Expiration date is in the past" : "Data de expiração está no passado",
-    "Can’t set expiration date more than %s days in the future" : "Não é possível definir a expiração mais do que %s dias no futuro",
+    "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["Não foi possível definir a data de expiração superior que %n dias no futuro","Não foi possível definir a data de expiração superior que %n dias no futuro"],
+    "Sharing is only allowed with group members" : "O compartilhamento só é permitido com membros do grupo ",
+    "Sharing %s failed, because this item is already shared with user %s" : "Compartilhamento %s falhou, porque este item já está compartilhado com o usuário %s",
     "%1$s shared »%2$s« with you" : "%1$s compartilhou »%2$s« com você",
     "%1$s shared »%2$s« with you." : "%1$s compartilhou »%2$s« com você.",
     "Click the button below to open it." : "Clique no botão abaixo para abri-lo.",
@@ -185,10 +193,12 @@ OC.L10N.register(
     "Oct." : "Out.",
     "Nov." : "Nov.",
     "Dec." : "Dez.",
+    "The user limit has been reached and the user was not created." : "O limite de usuários foi atingido e o usuário não foi criado.",
     "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Somente os seguintes caracteres são permitidos em um nome de usuário: \"a-z\", \"A-Z\", \"0-9\", e \"_.@-'\"",
     "A valid username must be provided" : "Um nome de usuário válido deve ser fornecido",
     "Username contains whitespace at the beginning or at the end" : "O nome de usuário contém espaço em branco no início ou no fim",
     "Username must not consist of dots only" : "Nome do usuário não pode consistir de pontos somente",
+    "Username is invalid because files already exist for this user" : "O nome de usuário é inválido porque já exstem arquivos para este usuário",
     "A valid password must be provided" : "Uma senha válida deve ser fornecida",
     "The username is already being used" : "Este nome de usuário já está em uso",
     "Could not create user" : "Não foi possível criar o usuário",
@@ -197,38 +207,41 @@ OC.L10N.register(
     "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "O aplicativo \"%1$s\" não pode ser instalado devido à estas dependências: %2$s",
     "a safe home for all your data" : "Um lar seguro para todos os seus dados",
     "File is currently busy, please try again later" : "O arquivo está ocupado, tente novamente mais tarde",
-    "Can't read file" : "Não foi possível ler arquivo",
+    "Cannot read file" : "Não foi possível ler o arquivo",
     "Application is not enabled" : "O aplicativo não está habilitado",
     "Authentication error" : "Erro de autenticação",
     "Token expired. Please reload page." : "O token expirou. Por favor recarregue a página.",
     "No database drivers (sqlite, mysql, or postgresql) installed." : "Nenhum driver  de banco de dados (sqlite, mysql ou postgresql) instalado.",
-    "Cannot write into \"config\" directory" : "Não foi possível gravar no diretório \"config\"",
-    "Cannot write into \"apps\" directory" : "Não foi possível gravar no diretório \"apps\"",
-    "This can usually be fixed by giving the webserver write access to the apps directory or disabling the appstore in the config file. See %s" : "Normalmente isso pode ser resolvido dando ao webserver permissão de escrita no diretório apps ou desabilitando a appstore no arquivo de configuração. Veja %s",
-    "Cannot create \"data\" directory" : "Não foi possível criar o diretório \"data\"",
-    "This can usually be fixed by giving the webserver write access to the root directory. See %s" : "Normalmente isso pode ser resolvido dando ao webserver permissão de escrita no diretório raiz. Veja %s",
-    "Permissions can usually be fixed by giving the webserver write access to the root directory. See %s." : "As permissões normalmente podem ser corrigidas dando permissão de escrita do diretório raiz para o servidor web. Veja %s.",
-    "Setting locale to %s failed" : "Falha ao configurar localização para %s",
-    "Please install one of these locales on your system and restart your webserver." : "Por favor, defina uma dessas localizações em seu sistema e reinicie o seu servidor web.",
-    "Please ask your server administrator to install the module." : "Por favor, peça ao seu administrador do servidor para instalar o módulo.",
+    "Cannot write into \"config\" directory." : "Não é possível gravar no diretório \"config\".",
+    "This can usually be fixed by giving the web server write access to the config directory. See %s" : "Isso geralmente pode ser corrigido dando ao servidor web acesso de gravação ao diretório de configuração. Ver %s",
+    "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "Ou, se você preferir manter o arquivo config.php somente para leitura, defina a opção \"config_is_read_only\" como true. Veja %s",
+    "Cannot write into \"apps\" directory." : "Não é possível gravar no diretório \"apps\".",
+    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Isso geralmente pode ser corrigido dando ao servidor web acesso de gravação ao diretório de aplicativos ou desabilitando a App Store no arquivo de configuração.",
+    "Cannot create \"data\" directory." : "Não é possível criar o diretório \"dados\".",
+    "This can usually be fixed by giving the web server write access to the root directory. See %s" : "Isso geralmente pode ser corrigido dando ao servidor web acesso de gravação ao diretório raiz. Ver %s",
+    "Permissions can usually be fixed by giving the web server write access to the root directory. See %s." : "As permissões geralmente podem ser corrigidas dando ao servidor web acesso de gravação ao diretório raiz. Ver %s.",
+    "Your data directory is not writable." : "Seu diretório de dados não é gravável.",
+    "Setting locale to %s failed." : "Falha ao definir a localidade para %s .",
+    "Please install one of these locales on your system and restart your web server." : "Instale um dessas localidades em seu sistema e reinicie seu servidor web.",
     "PHP module %s not installed." : "Módulo PHP %s não instalado.",
+    "Please ask your server administrator to install the module." : "Por favor, peça ao seu administrador do servidor para instalar o módulo.",
     "PHP setting \"%s\" is not set to \"%s\"." : "Configuração PHP \"%s\" não está configurado para \"%s\".",
     "Adjusting this setting in php.ini will make Nextcloud run again" : "Ajustar a configuração no php.ini fará com que o Nextcloud execute novamente",
-    "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload está definido para \"%s\" ao invés do valor esperado \"0\"",
-    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "Para corrigir esse problema defina <code>mbstring.func_overload</code> para <code>0</code> em seu php.ini",
-    "libxml2 2.7.0 is at least required. Currently %s is installed." : "A libxml2 2.7.0 é a versão mínima requerida. Atualmente a versão %s está instalada.",
+    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code> está configurado para <code>%s</code> em vez do valor esperado <code>0</code>.",
+    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "Para corrigir este conjunto de problemas <code>mbstring.func_overload</code> para <code>0</code> no seu php.ini.",
+    "libxml2 2.7.0 is at least required. Currently %s is installed." : "A libxml2 2.7.0 é a versão mínima necessária. Atualmente a versão %s está instalada.",
     "To fix this issue update your libxml2 version and restart your web server." : "Para corrigir este problema, atualize a versão da sua libxml2 e reinicie seu servidor web.",
     "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP aparentemente está configurado para retirar blocos doc inline. Isso fará com que vários aplicativos do núcleo fiquem inacessíveis.",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Isso provavelmente é causado por um cache/acelerador, como Zend OPcache ou eAccelerator.",
     "PHP modules have been installed, but they are still listed as missing?" : "Módulos do PHP foram instalados, mas eles ainda estão listados como faltantes?",
     "Please ask your server administrator to restart the web server." : "Por favor peça ao administrador do servidor para reiniciar o servidor web.",
-    "PostgreSQL >= 9 required" : "PostgreSQL >= 9 requirido",
-    "Please upgrade your database version" : "Por favor atualize sua versão do banco de dados",
+    "PostgreSQL >= 9 required." : "PostgreSQL >= 9 é necessário.",
+    "Please upgrade your database version." : "Por favor, atualize a versão do seu banco de dados.",
+    "Your data directory is readable by other users." : "Seu diretório de dados pode ser lido por outros usuários.",
     "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Por favor altere as permissões para 0770 para que o diretório não possa ser lido por outros usuários.",
-    "Your data directory is readable by other users" : "O diretório de dados está legível para outros usuários",
-    "Your data directory must be an absolute path" : "O diretório de dados deve ser um caminho absoluto",
-    "Check the value of \"datadirectory\" in your configuration" : "Verifique o valor do \"datadirectory\" na sua configuração",
-    "Your data directory is invalid" : "Seu diretório de dados é inválido",
+    "Your data directory must be an absolute path." : "Seu diretório de dados deve ser um caminho absoluto.",
+    "Check the value of \"datadirectory\" in your configuration." : "Verifique o valor de \"datadirectory\" em sua configuração.",
+    "Your data directory is invalid." : "Seu diretório de dados é inválido.",
     "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Assegure-se que exista um arquivo chamado \".ocdata\" na raiz do diretório \"data\".",
     "Action \"%s\" not supported or implemented." : "Ação \"%s\" não suportada ou implementada.",
     "Authentication failed, wrong token or provider ID given" : "Falha na autenticação, token ou ID do provedor errados",
@@ -240,42 +253,34 @@ OC.L10N.register(
     "Storage incomplete configuration. %s" : "Configuração incompleta do armazenamento. %s",
     "Storage connection error. %s" : "Erro na conexão de armazenamento. %s",
     "Storage is temporarily not available" : "Armazenamento temporariamente indisponível",
-    "Storage connection timeout. %s" : "Esgotado o tempo de conexão ao armazenamento. %s",
-    "Library %s with a version higher than %s is required - available version %s." : "É requerida uma biblioteca %s com uma versão maior que %s - versão disponível %s.",
-    "Library %s with a version lower than %s is required - available version %s." : "É requerida uma biblioteca %s com uma versão menor que %s - versão disponível %s.",
-    "Personal" : "Pessoal",
-    "Admin" : "Admin",
-    "APCu" : "APCu",
-    "Redis" : "Redis",
-    "Encryption" : "Criptografia",
-    "Tips & tricks" : "Dicas & truques",
-    "DB Error: \"%s\"" : "Erro no BD: \"%s\"",
-    "Offending command was: \"%s\"" : "Comando incorreto foi: \"%s\"",
-    "Offending command was: \"%s\", name: %s, password: %s" : "Comando incorreto foi: \"%s\", nome: %s, senha: %s",
-    "Sharing %s failed, because the user %s does not exist" : "O compartilhamento %s falhou pois o usuário %s não existe",
-    "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "O compartilhamento %s falhou pois o usuário %s não é membro de nenhum grupo que o usuário %s pertença",
-    "Sharing %s failed, because this item is already shared with %s" : "O compartilhamento %s falhou pois este ítem já está compartilhado com %s",
-    "Sharing %s failed, because this item is already shared with user %s" : "O compartilhamento de %s falhou pois esse item já é compartilhada com o usuário %s",
-    "Sharing %s failed, because the group %s does not exist" : "O compartilhamento %s falhou pois o grupo %s não existe",
-    "Sharing %s failed, because %s is not a member of the group %s" : "O compartilhamento %s falhou, pois %s não é membro do grupo %s",
-    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "O compartilhamento %s falhou pois não foi possível encontrar %s. Talvez o servidor esteja inacessível.",
-    "Share type %s is not valid for %s" : "O tipo de compartilhamento %s não é válido para %s",
-    "Setting permissions for %s failed, because the permissions exceed permissions granted to %s" : "Falha ao definir permissões para %s, porque as permissões excedem as possíveis para %s",
-    "Setting permissions for %s failed, because the item was not found" : "Falha ao definir permissões para %s, porque o item não foi encontrado",
-    "Cannot clear expiration date. Shares are required to have an expiration date." : "Não foi possível remover a data de expiração. Compartilhamentos tem que ter uma data de expiração.",
-    "Sharing %s failed, because the permissions exceed permissions granted to %s" : "Compartilhamento %s falhou pois as permissões excedem as permissões concedidas a %s",
-    "Sharing %s failed, because the sharing backend for %s could not find its source" : "O compartilhamento %s falhou pois a plataforma de serviço de compartilhamento para %s não conseguiu encontrar a sua fonte",
-    "Cannot increase permissions of %s" : "Não foi possível aumentar as permissões de %s",
-    "Files can't be shared with delete permissions" : "Arquivos não podem ser compartilhados com permissões de exclusão",
-    "Files can't be shared with create permissions" : "Arquivos não podem ser compartilhados com permissões de criação",
-    "Cannot set expiration date more than %s days in the future" : "Não foi possível definir uma data maior que %s dias no futuro",
-    "%s shared »%s« with you" : "%s compartilhou »%s« com você",
-    "%s shared »%s« with you." : "%s compartilhou »%s« com você.",
-    "%s via %s" : "%s via %s",
-    "No app name specified" : "Nenhum nome de aplicativo especificado",
-    "App '%s' could not be installed!" : "Aplicativo '%s' não pôde ser instalado!",
-    "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "O aplicativo \"%s\" não pode ser instalado pois as seguintes dependências não foram cumpridas: %s",
-    "Sync clients" : "Clientes de sincronização",
-    "ID \"%s\" already used by cloud federation provider \"%s\"" : "ID \"%s\" já é usada pelo provedor de nuvem federada \"%s\""
+    "Storage connection timeout. %s" : "Atingido o tempo limite de conexão ao armazenamento. %s",
+    "This can usually be fixed by giving the webserver write access to the config directory" : "Isso geralmente pode ser corrigido dando o acesso de escritura ao webserver para o diretório de configuração",
+    "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "Ou, se você preferir manter o arquivo config.php somente para leitura, defina a opção \"config_is_read_only\" como true.",
+    "This can usually be fixed by giving the webserver write access to the config directory." : "Geralmente, isso pode ser corrigido concedendo ao servidor web acesso de gravação ao diretório de configuração.",
+    "Can't create or write into the data directory %s" : "Não foi possível criar ou gravar no diretório de dados %s",
+    "Invalid Federated Cloud ID" : "ID inválida de Nuvem Federada",
+    "Can’t increase permissions of %s" : "Não posso aumentar as permissões de %s",
+    "Files can’t be shared with delete permissions" : "Os arquivos não podem ser compartilhados com permissões de exclusão",
+    "Files can’t be shared with create permissions" : "Os arquivos não podem ser compartilhados com permissões de criação",
+    "Can’t set expiration date more than %s days in the future" : "Não é possível definir a expiração mais do que %s dias no futuro",
+    "Can't read file" : "Não foi possível ler arquivo",
+    "Cannot write into \"config\" directory" : "Não foi possível gravar no diretório \"config\"",
+    "This can usually be fixed by giving the webserver write access to the config directory. See %s" : "Normalmente isso pode ser resolvido dando ao webserver permissão de escritura no diretório config. Veja %s",
+    "Cannot write into \"apps\" directory" : "Não foi possível gravar no diretório \"apps\"",
+    "This can usually be fixed by giving the webserver write access to the apps directory or disabling the appstore in the config file." : "Geralmente, isso pode ser corrigido concedendo ao servidor web acesso de gravação ao diretório de aplicativos ou desativando a loja de aplicativos no arquivo de configuração.",
+    "Cannot create \"data\" directory" : "Não foi possível criar o diretório \"data\"",
+    "This can usually be fixed by giving the webserver write access to the root directory. See %s" : "Normalmente isso pode ser resolvido dando ao webserver permissão de escrita no diretório raiz. Veja %s",
+    "Permissions can usually be fixed by giving the webserver write access to the root directory. See %s." : "As permissões normalmente podem ser corrigidas dando permissão de escrita do diretório raiz para o servidor web. Veja %s.",
+    "Setting locale to %s failed" : "Falha ao configurar localização para %s",
+    "Please install one of these locales on your system and restart your webserver." : "Por favor, defina uma dessas localizações em seu sistema e reinicie o seu servidor web.",
+    "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload está definido para \"%s\" ao invés do valor esperado \"0\"",
+    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "Para corrigir esse problema defina <code>mbstring.func_overload</code> para <code>0</code> em seu php.ini",
+    "PostgreSQL >= 9 required" : "PostgreSQL >= 9 requirido",
+    "Please upgrade your database version" : "Por favor atualize sua versão do banco de dados",
+    "Your data directory is readable by other users" : "O diretório de dados está legível para outros usuários",
+    "Your data directory must be an absolute path" : "O diretório de dados deve ser um caminho absoluto",
+    "Check the value of \"datadirectory\" in your configuration" : "Verifique o valor do \"datadirectory\" na sua configuração",
+    "Your data directory is invalid" : "Seu diretório de dados é inválido",
+    "This can usually be fixed by giving the webserver write access to the apps directory or disabling the App Store in the config file." : "Isso geralmente pode ser corrigido fornecendo ao servidor da web acesso de gravação ao diretório de aplicativos ou desativando a App Store no arquivo de configuração."
 },
 "nplurals=2; plural=(n > 1);");
