@@ -2,7 +2,6 @@ OC.L10N.register(
     "lib",
     {
     "Cannot write into \"config\" directory!" : "Nu se poate scrie în folderul \"config\"!",
-    "This can usually be fixed by giving the webserver write access to the config directory" : "Aceasta se poate repara de obicei prin permiterea accesului de scriere la dosarul de configurare al serverului Web",
     "See %s" : "Vezi %s",
     "Sample configuration detected" : "A fost detectată o configurație exemplu",
     "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "S-a detectat copierea configurației exemplu. Acest lucru poate duce la oprirea instanței tale și nu este suportat. Te rugăm să citești documentația înainte de a face modificări în fișierul config.php",
@@ -13,10 +12,9 @@ OC.L10N.register(
     "PHP %s or higher is required." : "Versiunea PHP %s sau mai mare este necesară.",
     "PHP with a version lower than %s is required." : "Este necesară o versiune PHP mai mică decât %s",
     "%sbit or higher PHP required." : "Este necesar PHP %sbit sau mai mare.",
-    "Following databases are supported: %s" : "Următoarele baze de date sunt suportate: %s",
     "The command line tool %s could not be found" : "Unealta în linie de comandă %s nu a fost găsită",
     "The library %s is not available." : "Biblioteca %s nu este disponibilă.",
-    "Following platforms are supported: %s" : "Sunt suportate următoarele platforme: %s",
+    "Authentication" : "Autentificare",
     "Unknown filetype" : "Tip fișier necunoscut",
     "Invalid image" : "Imagine invalidă",
     "today" : "astăzi",
@@ -43,11 +41,7 @@ OC.L10N.register(
     "Log out" : "Ieșire",
     "Users" : "Utilizatori",
     "Unknown user" : "Utilizator necunoscut",
-    "Basic settings" : "Setări de bază",
-    "Sharing" : "Partajare",
-    "Security" : "Securitate",
     "Additional settings" : "Setări adiționale",
-    "Personal info" : "Informații personale",
     "%s enter the database username and name." : "%s introdu numele de utilizator și parola pentru baza de date.",
     "%s enter the database username." : "%s introdu utilizatorul bazei de date.",
     "%s enter the database name." : "%s introduceți numele bazei de date",
@@ -57,10 +51,13 @@ OC.L10N.register(
     "For the best results, please consider using a GNU/Linux server instead." : "Pentru cele mai bune rezultate, ia în calcul folosirea unui server care rulează un sistem de operare GNU/Linux.",
     "Set an admin username." : "Setează un nume de administrator.",
     "Set an admin password." : "Setează o parolă de administrator.",
-    "Invalid Federated Cloud ID" : "ID invalid cloud federalizat",
+    "»%s« added a note to a file shared with you" : "%s« a adaugat un comentariu la un fișier partajat cu tine",
+    "Open »%s«" : "Deschide »%s«",
+    "%1$s via %2$s" : "%1$sprin %2$s",
     "You are not allowed to share %s" : "Nu există permisiunea de partajare %s",
-    "Files can’t be shared with delete permissions" : "Fișierele nu pot fi partajate cu permisiuni de ștergere",
     "Expiration date is in the past" : "Data expirării este în trecut",
+    "%1$s shared »%2$s« with you." : "%1$sa partajat »%2$s« cu tine.",
+    "Click the button below to open it." : "Apasă pe butonul de jos pentru a deschide.",
     "Could not find category \"%s\"" : "Cloud nu a gasit categoria \"%s\"",
     "Sunday" : "Duminică",
     "Monday" : "Luni",
@@ -118,17 +115,16 @@ OC.L10N.register(
     "Application is not enabled" : "Aplicația nu este activată",
     "Authentication error" : "Eroare la autentificare",
     "Token expired. Please reload page." : "Token expirat. Te rugăm să reîncarci pagina.",
-    "Cannot write into \"config\" directory" : "Nu se poate scrie în folderul \"config\"",
-    "Cannot write into \"apps\" directory" : "Nu se poate scrie în folderul \"apps\"",
     "PHP module %s not installed." : "Modulul PHP %s nu este instalat.",
     "PHP setting \"%s\" is not set to \"%s\"." : "Setarea PHP \"%s\" nu este setată la \"%s\".",
     "PHP modules have been installed, but they are still listed as missing?" : "Modulele PHP au fost instalate, dar apar ca lipsind?",
+    "Storage is temporarily not available" : "Spațiu de stocare este indisponibil temporar",
+    "This can usually be fixed by giving the webserver write access to the config directory" : "Aceasta se poate repara de obicei prin permiterea accesului de scriere la dosarul de configurare al serverului Web",
+    "Invalid Federated Cloud ID" : "ID invalid cloud federalizat",
+    "Files can’t be shared with delete permissions" : "Fișierele nu pot fi partajate cu permisiuni de ștergere",
+    "Cannot write into \"config\" directory" : "Nu se poate scrie în folderul \"config\"",
+    "Cannot write into \"apps\" directory" : "Nu se poate scrie în folderul \"apps\"",
     "PostgreSQL >= 9 required" : "Este necesară versiunea 9 sau mai mare a PostgreSQL",
-    "Please upgrade your database version" : "Actualizați baza de date la o versiune mai nouă",
-    "Verifying …" : "Se verifică ...",
-    "Verify" : "Verifică",
-    "Sharing %s failed, because the file does not exist" : "Partajarea %s a eșuat deoarece fișierul nu există",
-    "Sharing %s failed, because you can not share with yourself" : "Partajarea %s a eșuat deoarece nu-l poți partaja cu tine însuți",
-    "Not allowed to create a federated share with the same user" : "Nu este permisă crearea unei partajări federalizate cu acelaşi utilizator"
+    "Please upgrade your database version" : "Actualizați baza de date la o versiune mai nouă"
 },
 "nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
